@define-color blue_1 #99c1f1;
@define-color blue_2 #62a0ea;
@define-color blue_3 #3584e4;
@define-color blue_4 #1c71d8;
@define-color blue_5 #1a5fb4;
@define-color green_1 #8ff0a4;
@define-color green_2 #57e389;
@define-color green_3 #33d17a;
@define-color green_4 #2ec27e;
@define-color green_5 #26a269;
@define-color yellow_1 #f9f06b;
@define-color yellow_2 #f8e45c;
@define-color yellow_3 #f6d32d;
@define-color yellow_4 #f5c211;
@define-color yellow_5 #e5a50a;
@define-color orange_1 #ffbe6f;
@define-color orange_2 #ffa348;
@define-color orange_3 #ff7800;
@define-color orange_4 #e66100;
@define-color orange_5 #c64600;
@define-color red_1 #f66151;
@define-color red_2 #ed333b;
@define-color red_3 #e01b24;
@define-color red_4 #c01c28;
@define-color red_5 #a51d2d;
@define-color purple_1 #dc8add;
@define-color purple_2 #c061cb;
@define-color purple_3 #9141ac;
@define-color purple_4 #813d9c;
@define-color purple_5 #613583;
@define-color brown_1 #cdab8f;
@define-color brown_2 #b5835a;
@define-color brown_3 #986a44;
@define-color brown_4 #865e3c;
@define-color brown_5 #63452c;
@define-color light_1 #ffffff;
@define-color light_2 #f6f5f4;
@define-color light_3 #deddda;
@define-color light_4 #c0bfbc;
@define-color light_5 #9a9996;
@define-color dark_1 #77767b;
@define-color dark_2 #5e5c64;
@define-color dark_3 #3d3846;
@define-color dark_4 #241f31;
@define-color dark_5 #000000;
/* GTK NAMED COLORS
   ----------------
   use responsibly! */
@define-color accent_bg_color #5271ad;
@define-color accent_fg_color #ffffff;
@define-color accent_color #5271ad;
@define-color destructive_bg_color #c35b65;
@define-color destructive_fg_color #ffffff;
@define-color destructive_color #c35b65;
@define-color success_bg_color #82ac5d;
@define-color success_fg_color #ffffff;
@define-color success_color #82ac5d;
@define-color warning_bg_color #d0846c;
@define-color warning_fg_color #ffffff;
@define-color warning_color #d0846c;
@define-color error_bg_color #c35b65;
@define-color error_fg_color #ffffff;
@define-color error_color #c35b65;
@define-color window_bg_color rgba(12, 20, 48, 0.52);
@define-color window_fg_color #dce4f5;
@define-color view_bg_color rgba(8, 14, 36, 0.42);
@define-color view_fg_color #dce4f5;
@define-color headerbar_bg_color rgba(10, 18, 45, 0.55);
@define-color headerbar_fg_color rgba(230, 238, 255, 0.95);
@define-color headerbar_border_color rgba(255, 255, 255, 0.13);
@define-color headerbar_backdrop_color rgba(6, 12, 30, 0.34);
@define-color headerbar_shade_color mix(black,#2e3440,0.25);
@define-color headerbar_darker_shade_color mix(black,#2e3440,0.25);
@define-color sidebar_bg_color rgba(8, 13, 38, 0.48);
@define-color sidebar_fg_color rgba(210, 222, 248, 0.9);
@define-color sidebar_backdrop_color rgba(8, 13, 38, 0.48);
@define-color sidebar_shade_color rgba(0, 0, 0, 0.25);
@define-color sidebar_border_color alpha(rgba(210, 222, 248, 0.9),0.08);
@define-color secondary_sidebar_bg_color rgba(8, 14, 36, 0.42);
@define-color secondary_sidebar_fg_color #dce4f5;
@define-color secondary_sidebar_backdrop_color rgba(12, 20, 48, 0.52);
@define-color secondary_sidebar_shade_color rgba(0, 0, 0, 0.25);
@define-color secondary_sidebar_border_color rgba(255, 255, 255, 0.13);
@define-color card_bg_color rgba(8, 14, 36, 0.42);
@define-color card_fg_color #dce4f5;
@define-color card_shade_color rgba(255, 255, 255, 0.13);
@define-color dialog_bg_color rgba(10, 16, 42, 0.65);
@define-color dialog_fg_color #dce4f5;
@define-color popover_bg_color rgba(10, 18, 46, 0.6);
@define-color popover_fg_color #dce4f5;
@define-color popover_shade_color rgba(0, 0, 0, 0.25);
@define-color thumbnail_bg_color mix(rgba(8, 14, 36, 0.42),rgba(12, 20, 48, 0.52),0.5);
@define-color thumbnail_fg_color #dce4f5;
@define-color shade_color rgba(255, 255, 255, 0.13);
@define-color scrollbar_outline_color rgba(255, 255, 255, 0.13);
/* This stylesheet is generated, DO NOT EDIT */
window.background.csd > dialog-host > widget > widget > box > leaflet list.navigation-sidebar {
  background-image: linear-gradient(to left, rgba(0, 0, 0, 0.06), transparent 6px);
  background-color: rgba(8, 13, 38, 0.48);
  box-shadow: none;
  border: none;
}

window.background.csd > dialog-host > widget > widget > box > leaflet > headerbar.titlebar.tweak-titlebar-left, window.background.csd > contents > leaflet.unfolded > box > headerbar,
window.background.csd > widget > leaflet.unfolded > box > headerbar {
  background-image: linear-gradient(to left, rgba(0, 0, 0, 0.06), transparent 6px);
  background-color: rgba(8, 13, 38, 0.48);
  border: none;
}

window.background.csd > dialog-host > widget > widget > box > leaflet > headerbar.titlebar.tweak-titlebar-right, window.background.csd > contents > leaflet.unfolded > box > stack > widget > box > widget > headerbar,
window.background.csd > contents > leaflet.unfolded > box > stack > widget > overlay > leaflet.folded > box > headerbar,
window.background.csd > widget > leaflet.unfolded > box > stack > widget > box > widget > headerbar,
window.background.csd > widget > leaflet.unfolded > box > stack > widget > overlay > leaflet.folded > box > headerbar {
  background-image: none;
  background-color: rgba(8, 14, 36, 0.42);
  border: none;
}

window.background.csd > dialog-host > widget > widget > box > leaflet > box > searchbar > revealer > box, window.background.csd > contents > leaflet.unfolded > box > searchbar > revealer > box,
window.background.csd > widget > leaflet.unfolded > box > searchbar > revealer > box {
  background-color: rgba(8, 13, 38, 0.48);
  border-color: mix(black,#2b303b,0.25);
}

window.background.csd > dialog-host > widget > widget > box > leaflet > separator, window.background > contents > toastoverlay > leaflet > box + separator,
window.background > widget > toastoverlay > leaflet > box + separator, .titlebar:not(headerbar) > separator {
  background-image: image(mix(black,#2e3440,0.25));
  background-color: transparent;
  border-right: none;
}

popover.emoji-picker emoji:focus, popover.emoji-picker emoji:hover,
calendar > grid > label.day-number:selected, columnview.view:selected,
treeview.view:selected, gridview > child:selected, flowbox > flowboxchild:selected, dialog-host > dialog.view sheet:selected:focus, iconview:selected:focus, .view:selected:focus {
  background-color: #5271ad;
  color: #ffffff;
}

popover.emoji-picker emoji:disabled:focus, popover.emoji-picker emoji:disabled:hover,
calendar > grid > label.day-number:disabled:selected, columnview.view:disabled:selected,
treeview.view:disabled:selected, gridview > child:disabled:selected, flowbox > flowboxchild:disabled:selected, dialog-host > dialog.view sheet:disabled:selected:focus, iconview:disabled:selected:focus, .view:disabled:selected:focus {
  color: mix(#ffffff,#5271ad,0.5);
}

spinbutton > text > selection, entry > text > selection, label > selection, textview > text selection:focus, textview > text selection {
  color: #e8edf8;
  background-color: alpha(#5271ad,0.25);
}

.linked:not(.vertical) > dropdown > box > button.combo:dir(ltr), .linked:not(.vertical) > dropdown > box > button.combo:dir(rtl), .linked:not(.vertical) > combobox > box > button.combo:dir(ltr), .linked:not(.vertical) > combobox > box > button.combo:dir(rtl), .linked > menubutton:not(:only-child) > button {
  border-radius: 0;
  border-right-style: none;
}

spinbutton:not(.vertical) > button, spinbutton:not(.vertical) > text, .linked:not(.vertical) > button, .linked:not(.vertical) > entry, .linked:not(.vertical) > entry:focus-within {
  border-radius: 0;
  border-right-style: none;
}

spinbutton:not(.vertical) > button:first-child, spinbutton:not(.vertical) > text:first-child, .linked:not(.vertical) > button:first-child, .linked:not(.vertical) > entry:first-child {
  border-top-left-radius: 6px;
  border-bottom-left-radius: 6px;
}

spinbutton:not(.vertical) > button:last-child, spinbutton:not(.vertical) > text:last-child, .linked:not(.vertical) > button:last-child, .linked:not(.vertical) > entry:last-child {
  border-top-right-radius: 6px;
  border-bottom-right-radius: 6px;
  border-right-style: solid;
}

spinbutton:not(.vertical) > button:only-child, spinbutton:not(.vertical) > text:only-child, .linked:not(.vertical) > button:only-child, .linked:not(.vertical) > entry:only-child {
  border-radius: 6px;
  border-style: solid;
}

spinbutton.vertical > button, spinbutton.vertical > text, .linked.vertical > button, .linked.vertical > entry, .linked.vertical > entry:focus-within {
  border-radius: 0;
  border-bottom-style: none;
}

spinbutton.vertical > button:first-child, spinbutton.vertical > text:first-child, .linked.vertical > button:first-child, .linked.vertical > entry:first-child {
  border-top-left-radius: 6px;
  border-top-right-radius: 6px;
}

spinbutton.vertical > button:last-child, spinbutton.vertical > text:last-child, .linked.vertical > button:last-child, .linked.vertical > entry:last-child {
  border-bottom-left-radius: 6px;
  border-bottom-right-radius: 6px;
  border-bottom-style: solid;
}

spinbutton.vertical > button:only-child, spinbutton.vertical > text:only-child, .linked.vertical > button:only-child, .linked.vertical > entry:only-child {
  border-radius: 6px;
  border-style: solid;
}

.app-notification button, button.link, button.link:hover, button.link:active, button.link:checked, modelbutton.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}

.floating-bar > button.circular.flat, infobar.info > revealer > box button, infobar.info:hover > revealer > box button, infobar.info:backdrop > revealer > box button, infobar.question > revealer > box button, infobar.question:hover > revealer > box button, infobar.question:backdrop > revealer > box button, infobar.warning > revealer > box button, infobar.warning:hover > revealer > box button, infobar.warning:backdrop > revealer > box button, infobar.error > revealer > box button, infobar.error:hover > revealer > box button, infobar.error:backdrop > revealer > box button, .selection-mode headerbar button, headerbar.selection-mode button, .entry-tag > button, #NautilusQueryEditor #NautilusQueryEditorTag > button, #NautilusQueryEditor .nautilus-query-editor-tag > button, .nautilus-query-editor #NautilusQueryEditorTag > button, .nautilus-query-editor .nautilus-query-editor-tag > button {
  color: #ffffff;
  background-color: transparent;
  border-color: alpha(#ffffff,0.5);
  background-image: none;
  box-shadow: none;
}

.floating-bar > button.flat.circular, infobar.info > revealer > box button.flat, infobar.question > revealer > box button.flat, infobar.warning > revealer > box button.flat, infobar.error > revealer > box button.flat, .selection-mode headerbar button.flat, headerbar.selection-mode button.flat, .entry-tag > button.flat, #NautilusQueryEditor #NautilusQueryEditorTag > button.flat, #NautilusQueryEditor .nautilus-query-editor-tag > button.flat, .nautilus-query-editor #NautilusQueryEditorTag > button.flat, .nautilus-query-editor .nautilus-query-editor-tag > button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  color: #ffffff;
  background-color: transparent;
  background-image: none;
}

.floating-bar > button.flat.circular:disabled, infobar.info > revealer > box button.flat:disabled, infobar.question > revealer > box button.flat:disabled, infobar.warning > revealer > box button.flat:disabled, infobar.error > revealer > box button.flat:disabled, .selection-mode headerbar button.flat:disabled, headerbar.selection-mode button.flat:disabled, .entry-tag > button.flat:disabled, #NautilusQueryEditor #NautilusQueryEditorTag > button.flat:disabled, #NautilusQueryEditor .nautilus-query-editor-tag > button.flat:disabled, .nautilus-query-editor #NautilusQueryEditorTag > button.flat:disabled, .nautilus-query-editor .nautilus-query-editor-tag > button.flat:disabled {
  color: alpha(#ffffff,0.4);
}

.floating-bar > button.circular.flat:hover, infobar.info > revealer > box button:hover, infobar.question > revealer > box button:hover, infobar.warning > revealer > box button:hover, infobar.error > revealer > box button:hover, .selection-mode headerbar button:hover, headerbar.selection-mode button:hover, .entry-tag > button:hover, #NautilusQueryEditor #NautilusQueryEditorTag > button:hover, #NautilusQueryEditor .nautilus-query-editor-tag > button:hover, .nautilus-query-editor #NautilusQueryEditorTag > button:hover, .nautilus-query-editor .nautilus-query-editor-tag > button:hover {
  color: #ffffff;
  background-color: alpha(#ffffff,0.2);
  border-color: alpha(#ffffff,0.5);
  box-shadow: none;
}

.floating-bar > button.circular.flat:active, infobar.info > revealer > box button:active, infobar.question > revealer > box button:active, infobar.warning > revealer > box button:active, infobar.error > revealer > box button:active, .selection-mode headerbar button:active, headerbar.selection-mode button:active, .entry-tag > button:active, #NautilusQueryEditor #NautilusQueryEditorTag > button:active, #NautilusQueryEditor .nautilus-query-editor-tag > button:active, .nautilus-query-editor #NautilusQueryEditorTag > button:active, .nautilus-query-editor .nautilus-query-editor-tag > button:active, .floating-bar > button.circular.flat:checked, infobar.info > revealer > box button:checked, infobar.question > revealer > box button:checked, infobar.warning > revealer > box button:checked, infobar.error > revealer > box button:checked, .selection-mode headerbar button:checked, headerbar.selection-mode button:checked, .entry-tag > button:checked, #NautilusQueryEditor #NautilusQueryEditorTag > button:checked, #NautilusQueryEditor .nautilus-query-editor-tag > button:checked, .nautilus-query-editor #NautilusQueryEditorTag > button:checked, .nautilus-query-editor .nautilus-query-editor-tag > button:checked {
  color: #ffffff;
  background-color: alpha(#ffffff,0.4);
  border-color: alpha(#ffffff,0.5);
  box-shadow: none;
}

.floating-bar > button.circular.flat:disabled, infobar.info > revealer > box button:disabled, infobar.question > revealer > box button:disabled, infobar.warning > revealer > box button:disabled, infobar.error > revealer > box button:disabled, .selection-mode headerbar button:disabled, headerbar.selection-mode button:disabled, .entry-tag > button:disabled, #NautilusQueryEditor #NautilusQueryEditorTag > button:disabled, #NautilusQueryEditor .nautilus-query-editor-tag > button:disabled, .nautilus-query-editor #NautilusQueryEditorTag > button:disabled, .nautilus-query-editor .nautilus-query-editor-tag > button:disabled {
  color: alpha(#ffffff,0.5);
  background-color: transparent;
  border-color: alpha(#ffffff,0.4);
  box-shadow: none;
}

.floating-bar > button.circular.flat:disabled:active, infobar.info > revealer > box button:disabled:active, infobar.question > revealer > box button:disabled:active, infobar.warning > revealer > box button:disabled:active, infobar.error > revealer > box button:disabled:active, .selection-mode headerbar button:disabled:active, headerbar.selection-mode button:disabled:active, .entry-tag > button:disabled:active, #NautilusQueryEditor #NautilusQueryEditorTag > button:disabled:active, #NautilusQueryEditor .nautilus-query-editor-tag > button:disabled:active, .nautilus-query-editor #NautilusQueryEditorTag > button:disabled:active, .nautilus-query-editor .nautilus-query-editor-tag > button:disabled:active, .floating-bar > button.circular.flat:disabled:checked, infobar.info > revealer > box button:disabled:checked, infobar.question > revealer > box button:disabled:checked, infobar.warning > revealer > box button:disabled:checked, infobar.error > revealer > box button:disabled:checked, .selection-mode headerbar button:disabled:checked, headerbar.selection-mode button:disabled:checked, .entry-tag > button:disabled:checked, #NautilusQueryEditor #NautilusQueryEditorTag > button:disabled:checked, #NautilusQueryEditor .nautilus-query-editor-tag > button:disabled:checked, .nautilus-query-editor #NautilusQueryEditorTag > button:disabled:checked, .nautilus-query-editor .nautilus-query-editor-tag > button:disabled:checked {
  color: #5271ad;
  background-color: alpha(#ffffff,0.5);
  border-color: alpha(#ffffff,0.4);
}

.background {
  color: #e8edf8;
}

.background, .background.view {
  background-color: rgba(8, 14, 36, 0.42);
}

.background:backdrop {
  background-color: rgba(6, 10, 28, 0.36);
}

dnd {
  color: #e8edf8;
}

.normal-icons {
  -gtk-icon-size: 16px;
}

.large-icons {
  -gtk-icon-size: 32px;
}

spinner:disabled,
arrow:disabled,
scrollbar:disabled,
check:disabled,
radio:disabled,
treeview.expander:disabled {
  -gtk-icon-filter: opacity(0.5);
}

dialog-host > dialog.view sheet, iconview, .view {
  color: #dce4f5;
  background-color: rgba(8, 14, 36, 0.42);
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

dialog-host > dialog.view sheet:selected, iconview:selected, .view:selected {
  color: #ffffff;
  background-color: #5271ad;
  transition: all 350ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

textview {
  background-color: rgba(8, 14, 36, 0.42);
}

textview > text {
  background-color: rgba(8, 14, 36, 0.42);
}

textview border {
  color: mix(rgba(12, 20, 48, 0.52),rgba(8, 14, 36, 0.42),0.5);
}

textview:drop(active) {
  caret-color: #d0846c;
}

iconview, iconview:hover, iconview:selected {
  border-radius: 6px;
}

.content-view > rubberband, columnview.view > rubberband,
treeview.view > rubberband, flowbox > rubberband,
rubberband,
gridview > rubberband {
  border: 1px solid #425a8a;
  background-color: rgba(66, 90, 138, 0.25);
}

flowbox > flowboxchild {
  padding: 3px;
  border-radius: 6px;
}

flowbox > flowboxchild:selected {
  outline-offset: -2px;
}

flowbox.search-bar {
  border-bottom: 1px solid mix(black,#2e3440,0.25);
}

gridview > child {
  padding: 3px;
}

gridview > child:selected {
  outline-color: #394f79;
}

coverflow cover {
  color: #dce4f5;
  background-color: rgba(8, 14, 36, 0.42);
  border: 1px solid black;
}

headerbar .subtitle, label.separator, .dim-label, row.expander image.expander-row-arrow, row.property > box.header > box.title > .title, row.expander.property box > list > row > box.header > box.title > .title, row label.subtitle, entry > text:disabled,
entry > text > placeholder {
  opacity: 0.55;
  text-shadow: none;
}

label.separator {
  color: #e8edf8;
}

label:disabled {
  opacity: 1;
  filter: none;
  color: rgba(160, 180, 220, 0.4);
}

label:disabled selection {
  color: rgba(160, 180, 220, 0.4);
}

.accent {
  color: #5271ad;
}

.success {
  color: #82ac5d;
}

.warning {
  color: #d0846c;
}

.error {
  color: #c35b65;
}

window.assistant .sidebar {
  background-color: rgba(8, 14, 36, 0.42);
}

window.assistant.csd .sidebar {
  border-top-style: none;
}

window.assistant .sidebar > label {
  padding: 6px 12px;
}

window.assistant .sidebar > label.highlight {
  background-color: #5271ad;
  color: #ffffff;
}

dialog-host > dialog.osd:not(progressbar):not(button):not(menubutton):not(splitbutton) sheet, toast, .osd popover > arrow,
.osd popover > contents, popover.touch-selection > arrow,
popover.touch-selection > contents, popover.magnifier > arrow,
popover.magnifier > contents, .osd {
  color: rgba(225, 232, 252, 0.95);
  background-color: rgba(5, 10, 30, 0.72);
  border-radius: 12px;
}

.osd {
  border: none;
  background-clip: padding-box;
  padding: 6px;
  margin: 6px;
  box-shadow: 0 2px 3px 0 rgba(0, 0, 0, 0.2), 0 3px 5px 0 rgba(0, 0, 0, 0.15), inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 0 0 1px black;
}

.osd.circular {
  border-radius: 100%;
}

.osd-box {
  background-color: alpha(rgba(8, 14, 36, 0.42),0.85);
  border-radius: 12px;
  padding: 6px;
}

@keyframes spin {
  to {
    transform: rotate(1turn);
  }
}

spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
}

spinner:checked {
  opacity: 1;
  animation: spin 1s linear infinite;
}

spinner:checked:disabled {
  opacity: 0.5;
}

.large-title {
  font-weight: 300;
  font-size: 24pt;
}

.title-1 {
  font-weight: 800;
  font-size: 20pt;
}

.title-2 {
  font-weight: 800;
  font-size: 15pt;
}

.title-3 {
  font-weight: 700;
  font-size: 15pt;
}

.title-4 {
  font-weight: 700;
  font-size: 13pt;
}

.heading, row.button .title {
  font-weight: 700;
  font-size: 11pt;
}

.body {
  font-weight: 400;
  font-size: 11pt;
}

.caption {
  font-weight: 400;
  font-size: 9pt;
}

.caption-heading {
  font-weight: 700;
  font-size: 9pt;
}

.numeric {
  font-feature-settings: "tnum";
}

spinbutton > text, .linked > entry:not(:only-child) {
  color: #dce4f5;
  background-color: rgba(255, 255, 255, 0.07);
  box-shadow: inset 0 0 0 2px transparent;
  border: none;
}

spinbutton > text:focus-within, .linked > entry:focus-within:not(:only-child) {
  color: #dce4f5;
  background-color: rgba(255, 255, 255, 0.07);
  box-shadow: inset 0 0 0 2px alpha(mix(white,#5271ad,0.75),0.75);
  transition-duration: 300ms;
}

spinbutton > text:disabled, .linked > entry:disabled:not(:only-child) {
  color: rgba(160, 180, 220, 0.4);
  background-color: rgba(255, 255, 255, 0.02);
}

entry {
  color: #dce4f5;
  background-color: rgba(255, 255, 255, 0.07);
  box-shadow: inset 0 0 0 2px transparent;
}

entry:hover {
  color: #dce4f5;
  background-color: rgba(255, 255, 255, 0.07);
  box-shadow: inset 0 0 0 1px alpha(rgba(255, 255, 255, 0.13),0.05), inset 0 0 0 2px transparent;
  transition-duration: 200ms;
}

entry:focus-within {
  color: #dce4f5;
  background-color: rgba(255, 255, 255, 0.07);
  box-shadow: inset 0 0 0 2px alpha(mix(white,#5271ad,0.75),0.75);
  transition-duration: 300ms;
}

entry:disabled {
  color: rgba(160, 180, 220, 0.4);
  background-color: rgba(255, 255, 255, 0.02);
}

entry {
  min-height: 24px;
  padding: 2px 8px;
  border-radius: 6px;
  border: none;
  caret-color: currentColor;
  transition: all 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  animation-timing-function: ease-in-out;
}

entry.search {
  border-radius: 9999px;
}

entry > image {
  color: rgba(200, 215, 240, 0.85);
}

entry.flat:focus-within, entry.flat:backdrop, entry.flat:disabled, entry.flat:backdrop:disabled, entry.flat {
  min-height: 0;
  background-image: none;
  border-color: transparent;
  border-radius: 0;
}

entry:focus-within > placeholder {
  opacity: 0;
}

entry.warning {
  color: #d0846c;
  background-color: mix(#d0846c,transparent,0.4);
}

entry.warning image {
  color: #d0846c;
}

entry.warning:focus-within {
  color: #ffffff;
  background-color: #d0846c;
  box-shadow: none;
  outline: none;
}

entry.warning:focus-within image {
  color: #ffffff;
}

entry.warning text > selection {
  color: #d0846c;
  background-color: #ffffff;
}

entry.error {
  color: #c35b65;
  background-color: mix(#c35b65,transparent,0.4);
}

entry.error image {
  color: #c35b65;
}

entry.error:focus-within {
  color: #ffffff;
  background-color: #c35b65;
  box-shadow: none;
  outline: none;
}

entry.error:focus-within image {
  color: #ffffff;
}

entry.error text > selection {
  color: #c35b65;
  background-color: #ffffff;
}

entry.success {
  color: #82ac5d;
  background-color: mix(#82ac5d,transparent,0.4);
}

entry.success image {
  color: #82ac5d;
}

entry.success:focus-within {
  color: #ffffff;
  background-color: #82ac5d;
  box-shadow: none;
  outline: none;
}

entry.success:focus-within image {
  color: #ffffff;
}

entry.success text > selection {
  color: #82ac5d;
  background-color: #ffffff;
}

entry.search-missing {
  color: #c35b65;
  background-color: mix(#c35b65,transparent,0.4);
}

entry.search-missing image {
  color: #c35b65;
}

entry.search-missing:focus-within {
  color: #ffffff;
  background-color: #c35b65;
  box-shadow: none;
  outline: none;
}

entry.search-missing:focus-within image {
  color: #ffffff;
}

entry.search-missing text > selection {
  color: #c35b65;
  background-color: #ffffff;
}

entry:drop(active):focus, entry:drop(active) {
  border-color: #d0846c;
  box-shadow: none;
  border-image: none;
}

.osd entry {
  color: rgba(225, 232, 252, 0.95);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(81, 92, 114, 0.96);
  border-image: none;
}

.osd entry image, .osd entry image:hover {
  color: inherit;
}

.osd entry:focus {
  color: #ffffff;
  background-color: #5271ad;
  border-color: mix(black,#5271ad,0.94);
  border-image: none;
}

.osd entry:disabled {
  color: rgba(34, 39, 48, 0.35);
  background-color: alpha(rgba(81, 92, 114, 0.96),0.8);
  border-image: none;
}

.osd entry selection:focus, .osd entry selection {
  color: #5271ad;
  background-color: #ffffff;
}

entry > progress {
  margin: 0 -6px;
  border-radius: 0;
  border-width: 0 0 2px;
  border-color: #5271ad;
  border-style: solid;
  background-image: none;
  background-color: transparent;
  box-shadow: none;
}

entry progress > trough > progress {
  background-color: transparent;
  background-image: none;
  border-radius: 0;
  border-width: 0 0 2px;
  border-color: #5271ad;
  border-style: solid;
  box-shadow: none;
}

.linked:not(.vertical) > entry, .linked:not(.vertical) > entry:focus-within {
  min-height: 20px;
}

.linked:not(.vertical) > entry + button.combo {
  padding-left: 0;
}

.linked.vertical > entry + button.combo {
  padding: 0;
}

.entry-tag, #NautilusQueryEditor #NautilusQueryEditorTag, #NautilusQueryEditor .nautilus-query-editor-tag, .nautilus-query-editor #NautilusQueryEditorTag, .nautilus-query-editor .nautilus-query-editor-tag {
  margin: 0;
  min-height: 16px;
  border-radius: 9999px;
  box-shadow: none;
  background-color: #4c7bd9;
  color: #ffffff;
  border: none;
  padding: 2px;
}

.entry-tag:hover, #NautilusQueryEditor #NautilusQueryEditorTag:hover, #NautilusQueryEditor .nautilus-query-editor-tag:hover, .nautilus-query-editor #NautilusQueryEditorTag:hover, .nautilus-query-editor .nautilus-query-editor-tag:hover {
  box-shadow: 0 2px 3px 0 rgba(0, 0, 0, 0.2), 0 3px 5px 0 rgba(0, 0, 0, 0.15);
}

:dir(ltr) .entry-tag, :dir(ltr) #NautilusQueryEditor #NautilusQueryEditorTag, #NautilusQueryEditor :dir(ltr) #NautilusQueryEditorTag, :dir(ltr) #NautilusQueryEditor .nautilus-query-editor-tag, #NautilusQueryEditor :dir(ltr) .nautilus-query-editor-tag, :dir(ltr) .nautilus-query-editor #NautilusQueryEditorTag, .nautilus-query-editor :dir(ltr) #NautilusQueryEditorTag, :dir(ltr) .nautilus-query-editor .nautilus-query-editor-tag, .nautilus-query-editor :dir(ltr) .nautilus-query-editor-tag {
  margin-left: 3px;
  margin-right: 0;
}

:dir(rtl) .entry-tag, :dir(rtl) #NautilusQueryEditor #NautilusQueryEditorTag, #NautilusQueryEditor :dir(rtl) #NautilusQueryEditorTag, :dir(rtl) #NautilusQueryEditor .nautilus-query-editor-tag, #NautilusQueryEditor :dir(rtl) .nautilus-query-editor-tag, :dir(rtl) .nautilus-query-editor #NautilusQueryEditorTag, .nautilus-query-editor :dir(rtl) #NautilusQueryEditorTag, :dir(rtl) .nautilus-query-editor .nautilus-query-editor-tag, .nautilus-query-editor :dir(rtl) .nautilus-query-editor-tag {
  margin-left: 0;
  margin-right: 3px;
}

.entry-tag > button, #NautilusQueryEditor #NautilusQueryEditorTag > button, #NautilusQueryEditor .nautilus-query-editor-tag > button, .nautilus-query-editor #NautilusQueryEditorTag > button, .nautilus-query-editor .nautilus-query-editor-tag > button {
  min-height: 20px;
  min-width: 20px;
  padding: 0;
  border-radius: 9999px;
}

treeview entry:focus-within:dir(rtl), treeview entry:focus-within:dir(ltr) {
  background-color: rgba(8, 14, 36, 0.42);
  transition-property: color, background;
}

treeview entry.flat, treeview entry {
  border-radius: 0;
  background-image: none;
  background-color: rgba(8, 14, 36, 0.42);
}

treeview entry.flat:focus-within, treeview entry:focus-within {
  border-color: #5271ad;
}

editablelabel > stack > text {
  color: #dce4f5;
  background-color: rgba(255, 255, 255, 0.07);
  box-shadow: inset 0 0 0 2px transparent;
}

@keyframes needs_attention {
  from {
    background-image: radial-gradient(farthest-side, #869cc6 0%, #869cc6 0%);
  }
  to {
    background-image: radial-gradient(farthest-side, #869cc6 95%, #869cc6);
  }
}

stacksidebar row.needs-attention > label, stackswitcher > button.needs-attention > label, stackswitcher > button.needs-attention > image {
  animation: needs_attention 150ms ease-in;
  background-image: radial-gradient(farthest-side, #869cc6 96%, #869cc6);
  background-size: 6px 6px, 6px 6px;
  background-repeat: no-repeat;
  background-position: right 3px, right 2px;
}

stacksidebar row.needs-attention > label:backdrop, stackswitcher > button.needs-attention > label:backdrop, stackswitcher > button.needs-attention > image:backdrop {
  background-size: 6px 6px, 0 0;
}

stacksidebar row.needs-attention > label:dir(rtl), stackswitcher > button.needs-attention > label:dir(rtl), stackswitcher > button.needs-attention > image:dir(rtl) {
  background-position: left 3px, left 2px;
}

button.opaque {
  box-shadow: none;
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.osd button.opaque:focus:focus-visible {
  outline-color: rgba(255, 255, 255, 0.15);
}

button.opaque:hover {
  background-image: image(alpha(currentColor,0.1));
}

button.keyboard-activating.opaque, button.opaque:active {
  background-image: image(rgba(0, 0, 0, 0.2));
}

button.opaque:checked {
  background-image: image(rgba(0, 0, 0, 0.15));
}

button.opaque:checked:hover {
  background-image: image(rgba(0, 0, 0, 0.05));
}

button.opaque:checked.keyboard-activating, button.opaque:checked:active {
  background-image: image(rgba(0, 0, 0, 0.3));
}

row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, headerbar popover button, button {
  color: rgba(200, 215, 240, 0.85);
  background-color: rgba(255, 255, 255, 0.07);
  box-shadow: none;
  border: none;
}

row.spin spinbutton > button.image-button.up:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:hover {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.12);
}

row.spin spinbutton > button.image-button.up:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:active, row.spin spinbutton > button.keyboard-activating.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.keyboard-activating.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.keyboard-activating.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.keyboard-activating.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.keyboard-activating.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.keyboard-activating.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button.keyboard-activating {
  color: #e8edf8;
  background-color: rgba(136, 170, 255, 0.22);
}

row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:disabled {
  color: rgba(160, 180, 220, 0.4);
  background-color: rgba(255, 255, 255, 0.03);
  box-shadow: none;
}

row.spin spinbutton > button.image-button.up:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:checked {
  color: #ffffff;
  background-color: #5271ad;
}

row.spin spinbutton > button.image-button.up:checked:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child,
row.spin spinbutton > button.image-button.down:checked:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:checked:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:checked:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button:checked:disabled {
  color: alpha(#ffffff,0.35);
  background-color: alpha(#5271ad,0.25);
}

tabbar tabbox > tab button.tab-close-button, panelstatusbar > menubutton > button,
panelstatusbar > paneltogglebutton button, datechooser button.circular.day, .scale-popup button, popover.menu box.circular-buttons button.circular.image-button.model, popover.menu box.inline-buttons button.image-button.model, .toolbar > button, splitbutton.suggested-action > button, splitbutton.suggested-action > menubutton > button, splitbutton.destructive-action > button, splitbutton.destructive-action > menubutton > button, splitbutton.opaque > button, splitbutton.opaque > menubutton > button, splitbutton.flat > button,
splitbutton.flat > menubutton > button, menubutton.suggested-action > button, menubutton.destructive-action > button, menubutton.opaque > button, menubutton.flat > button, button.flat {
  color: rgba(200, 215, 240, 0.85);
  border: none;
  background-color: transparent;
  box-shadow: none;
}

tabbar tabbox > tab button.tab-close-button:hover, panelstatusbar > menubutton > button:hover,
panelstatusbar > paneltogglebutton button:hover, datechooser button.circular.day:hover, .scale-popup button:hover, popover.menu box.circular-buttons button.circular.image-button.model:hover, popover.menu box.inline-buttons button.image-button.model:hover, .toolbar > button:hover, splitbutton.suggested-action > button:hover, splitbutton.suggested-action > menubutton > button:hover, splitbutton.destructive-action > button:hover, splitbutton.destructive-action > menubutton > button:hover, splitbutton.opaque > button:hover, splitbutton.opaque > menubutton > button:hover, splitbutton.flat > button:hover,
splitbutton.flat > menubutton > button:hover, menubutton.suggested-action > button:hover, menubutton.destructive-action > button:hover, menubutton.opaque > button:hover, menubutton.flat > button:hover, button.flat:hover {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.12);
}

tabbar tabbox > tab button.tab-close-button:active, panelstatusbar > menubutton > button:active,
panelstatusbar > paneltogglebutton button:active, datechooser button.circular.day:active, .scale-popup button:active, popover.menu box.circular-buttons button.circular.image-button.model:active, popover.menu box.inline-buttons button.image-button.model:active, .toolbar > button:active, splitbutton.suggested-action > button:active, splitbutton.suggested-action > menubutton > button:active, splitbutton.destructive-action > button:active, splitbutton.destructive-action > menubutton > button:active, splitbutton.opaque > button:active, splitbutton.opaque > menubutton > button:active, splitbutton.flat > button:active,
splitbutton.flat > menubutton > button:active, menubutton.suggested-action > button:active, menubutton.destructive-action > button:active, menubutton.opaque > button:active, menubutton.flat > button:active, button.flat:active, tabbar tabbox > tab button.keyboard-activating.tab-close-button, panelstatusbar > menubutton > button.keyboard-activating,
panelstatusbar > paneltogglebutton button.keyboard-activating, datechooser button.keyboard-activating.circular.day, .scale-popup button.keyboard-activating, popover.menu box.circular-buttons button.keyboard-activating.circular.image-button.model, popover.menu box.inline-buttons button.keyboard-activating.image-button.model, .toolbar > button.keyboard-activating, splitbutton.suggested-action > button.keyboard-activating, splitbutton.suggested-action > menubutton > button.keyboard-activating, splitbutton.destructive-action > button.keyboard-activating, splitbutton.destructive-action > menubutton > button.keyboard-activating, splitbutton.opaque > button.keyboard-activating, splitbutton.opaque > menubutton > button.keyboard-activating, splitbutton.flat > button.keyboard-activating,
splitbutton.flat > menubutton > button.keyboard-activating, menubutton.suggested-action > button.keyboard-activating, menubutton.destructive-action > button.keyboard-activating, menubutton.opaque > button.keyboard-activating, menubutton.flat > button.keyboard-activating, button.keyboard-activating.flat {
  color: #e8edf8;
  background-color: rgba(136, 170, 255, 0.22);
}

tabbar tabbox > tab button.tab-close-button:checked, panelstatusbar > menubutton > button:checked,
panelstatusbar > paneltogglebutton button:checked, datechooser button.circular.day:checked, .scale-popup button:checked, popover.menu box.circular-buttons button.circular.image-button.model:checked, popover.menu box.inline-buttons button.image-button.model:checked, .toolbar > button:checked, splitbutton.suggested-action > button:checked, splitbutton.suggested-action > menubutton > button:checked, splitbutton.destructive-action > button:checked, splitbutton.destructive-action > menubutton > button:checked, splitbutton.opaque > button:checked, splitbutton.opaque > menubutton > button:checked, splitbutton.flat > button:checked,
splitbutton.flat > menubutton > button:checked, menubutton.suggested-action > button:checked, menubutton.destructive-action > button:checked, menubutton.opaque > button:checked, menubutton.flat > button:checked, button.flat:checked {
  color: #e8edf8;
  background-color: rgba(136, 170, 255, 0.18);
}

tabbar tabbox > tab button.tab-close-button:disabled, panelstatusbar > menubutton > button:disabled,
panelstatusbar > paneltogglebutton button:disabled, datechooser button.circular.day:disabled, .scale-popup button:disabled, popover.menu box.circular-buttons button.circular.image-button.model:disabled, popover.menu box.inline-buttons button.image-button.model:disabled, .toolbar > button:disabled, splitbutton.suggested-action > button:disabled, splitbutton.suggested-action > menubutton > button:disabled, splitbutton.destructive-action > button:disabled, splitbutton.destructive-action > menubutton > button:disabled, splitbutton.opaque > button:disabled, splitbutton.opaque > menubutton > button:disabled, splitbutton.flat > button:disabled,
splitbutton.flat > menubutton > button:disabled, menubutton.suggested-action > button:disabled, menubutton.destructive-action > button:disabled, menubutton.opaque > button:disabled, menubutton.flat > button:disabled, button.flat:disabled {
  color: rgba(160, 180, 220, 0.4);
  background-color: transparent;
}

tabbar tabbox > tab button.tab-close-button:checked:disabled, panelstatusbar > menubutton > button:checked:disabled,
panelstatusbar > paneltogglebutton button:checked:disabled, datechooser button.circular.day:checked:disabled, .scale-popup button:checked:disabled, popover.menu box.circular-buttons button.circular.image-button.model:checked:disabled, popover.menu box.inline-buttons button.image-button.model:checked:disabled, .toolbar > button:checked:disabled, splitbutton.suggested-action > button:checked:disabled, splitbutton.suggested-action > menubutton > button:checked:disabled, splitbutton.destructive-action > button:checked:disabled, splitbutton.destructive-action > menubutton > button:checked:disabled, splitbutton.opaque > button:checked:disabled, splitbutton.opaque > menubutton > button:checked:disabled, splitbutton.flat > button:checked:disabled,
splitbutton.flat > menubutton > button:checked:disabled, menubutton.suggested-action > button:checked:disabled, menubutton.destructive-action > button:checked:disabled, menubutton.opaque > button:checked:disabled, menubutton.flat > button:checked:disabled, button.flat:checked:disabled {
  color: rgba(160, 180, 220, 0.4);
  background-color: rgba(255, 255, 255, 0.12);
}

button {
  min-height: 24px;
  min-width: 24px;
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border-radius: 6px;
  padding: 2px 6px;
  background-clip: padding-box;
}

button:hover {
  -gtk-icon-filter: brightness(1.2);
}

button:checked {
  transition-duration: 200ms;
}

button:checked:not(:disabled) label:disabled {
  color: inherit;
  opacity: 0.6;
}

button separator {
  margin: 3px 1px;
}

button.flat {
  min-height: 24px;
}

button.flat:hover {
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-duration: 350ms;
}

button.flat:hover:active {
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

button.flat.toggle.popup {
  min-width: 20px;
}

button.opaque {
  color: mix(rgba(12, 20, 48, 0.52),rgba(8, 14, 36, 0.42),0.2);
  color: #e8edf8;
}

button.image-button {
  min-height: 24px;
  padding-left: 6px;
  padding-right: 6px;
}

button.text-button {
  min-height: 24px;
  padding-left: 12px;
  padding-right: 12px;
}

button.text-button.image-button, button.image-text-button {
  min-height: 24px;
  padding-left: 6px;
  padding-right: 6px;
}

button.text-button.image-button > box,
button.text-button.image-button > box > box, button.image-text-button > box,
button.image-text-button > box > box {
  border-spacing: 4px;
}

button.text-button.image-button > box > label,
button.text-button.image-button > box > box > label, button.image-text-button > box > label,
button.image-text-button > box > box > label {
  padding-left: 2px;
  padding-right: 2px;
}

button.text-button.image-button label:first-child, button.image-text-button label:first-child {
  padding-left: 8px;
  padding-right: 3px;
}

button.text-button.image-button label:last-child, button.image-text-button label:last-child {
  padding-right: 8px;
  padding-left: 3px;
}

button.text-button.image-button label:only-child, button.image-text-button label:only-child {
  padding-left: 8px;
  padding-right: 8px;
}

button.text-button.image-button.popup, button.image-text-button.popup {
  padding-right: 6px;
  padding-left: 6px;
}

button.suggested-action, button.destructive-action {
  padding-left: 12px;
  padding-right: 12px;
}

button.arrow-button {
  padding-left: 9px;
  padding-right: 9px;
}

button.arrow-button > box {
  border-spacing: 4px;
}

button.arrow-button.text-button > box {
  border-spacing: 4px;
}

button.font separator {
  background-color: transparent;
  background-image: none;
}

button.font > box {
  border-spacing: 6px;
}

button.font > box > box > label {
  font-weight: bold;
}

stackswitcher button.circular, .app-notification button.image-button:not(.text-button), row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, row button.circular, menubutton.circular > button, button.circular, button.close {
  border-radius: 9999px;
  padding: 0;
  min-height: 28px;
  min-width: 28px;
}

.app-notification button.image-button:not(.text-button) label, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child label, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child label, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child label,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) label,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child label,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child label, menubutton.circular > button label, button.circular label, button.close label {
  padding: 0;
}

menubutton.pill > button, button.pill {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
  border-radius: 9999px;
}

menubutton.pill > button.text-button, menubutton.pill > button.image-text-button, button.pill.text-button, button.pill.image-text-button {
  padding-left: 18px;
  padding-right: 18px;
}

button.card {
  background-color: alpha(currentColor,0.05);
  background-clip: padding-box;
  font-weight: inherit;
  padding: 6px;
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

button.card:hover {
  background-image: image(alpha(currentColor,0.03));
}

button.card.keyboard-activating, button.card:active {
  background-image: image(alpha(currentColor,0.08));
}

button.card:checked {
  background-color: alpha(currentColor,0.05);
  background-image: image(alpha(currentColor,0.1));
}

button.card:checked:hover {
  background-image: image(alpha(currentColor,0.13));
}

button.card:checked.keyboard-activating, button.card:checked:active {
  background-image: image(alpha(currentColor,0.19));
}

button.card:checked.has-open-popup {
  background-image: image(alpha(currentColor,0.13));
}

button.card:drop(active) {
  color: #d0846c;
  box-shadow: inset 0 0 0 1px #d0846c;
}

button.accent {
  background-color: alpha(currentColor,0.05);
  color: #e8edf8;
}

button.accent:hover {
  background-color: alpha(currentColor,0.03);
}

button.accent:active {
  background-color: alpha(currentColor,0.08);
}

button.accent:checked {
  color: #5271ad;
  background-color: alpha(#5271ad,0.1);
}

button.accent:checked:hover {
  background-color: alpha(#5271ad,0.13);
}

button.accent:checked:active {
  background-color: alpha(#5271ad,0.19);
}

button:drop(active) {
  color: #d0846c;
  border-color: #d0846c;
  box-shadow: inset 0 0 0 1px #d0846c;
}

button.osd {
  color: white;
  background-color: rgba(0, 0, 0, 0.65);
  border: none;
  box-shadow: none;
}

button.osd.image-button {
  padding: 3px;
  min-height: 28px;
  min-width: 28px;
}

button.osd.image-button.remove-button {
  padding: 0;
}

button.osd:hover {
  color: white;
  background-color: rgba(0, 0, 0, 0.75);
  box-shadow: none;
}

button.osd.keyboard-activating, button.osd:active, button.osd:checked {
  color: white;
  background-color: rgba(0, 0, 0, 0.85);
}

button.osd:disabled {
  opacity: 0.35;
}

toast button, popover.touch-selection button, popover.magnifier button, menubutton.osd > button, .osd button {
  color: rgba(225, 232, 252, 0.95);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.08);
  box-shadow: none;
}

toast button:hover, popover.touch-selection button:hover, popover.magnifier button:hover, .osd button:hover {
  color: rgba(225, 232, 252, 0.95);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.16);
  box-shadow: none;
}

toast button.keyboard-activating, popover.touch-selection button.keyboard-activating, popover.magnifier button.keyboard-activating, toast button:active, popover.touch-selection button:active, popover.magnifier button:active, toast button:checked, popover.touch-selection button:checked, popover.magnifier button:checked, .osd button.keyboard-activating, .osd button:active, .osd button:checked {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.25);
  background-image: none;
  box-shadow: none;
  background-clip: padding-box;
}

toast button:disabled, popover.touch-selection button:disabled, popover.magnifier button:disabled, .osd button:disabled {
  color: rgba(34, 39, 48, 0.35);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.03);
  box-shadow: none;
}

toast button.flat, popover.touch-selection button.flat, popover.magnifier button.flat, .osd button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  box-shadow: none;
}

toast button.flat:hover, popover.touch-selection button.flat:hover, popover.magnifier button.flat:hover, .osd button.flat:hover {
  color: rgba(225, 232, 252, 0.95);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.16);
  box-shadow: none;
}

toast button.flat:disabled, popover.touch-selection button.flat:disabled, popover.magnifier button.flat:disabled, .osd button.flat:disabled {
  color: rgba(34, 39, 48, 0.35);
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.03);
  box-shadow: none;
  background-image: none;
}

toast button.flat:active, popover.touch-selection button.flat:active, popover.magnifier button.flat:active, toast button.flat:checked, popover.touch-selection button.flat:checked, popover.magnifier button.flat:checked, .osd button.flat:active, .osd button.flat:checked {
  color: #ffffff;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: rgba(255, 255, 255, 0.25);
  background-image: none;
  box-shadow: none;
  background-clip: padding-box;
}

.osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child), .osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active) + button:not(:checked):not(:active) {
  box-shadow: none;
}

button.suggested-action {
  color: #ffffff;
  background-color: #4c7bd9;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), inset 0 -1px rgba(255, 255, 255, 0.03);
  border-color: rgba(0, 0, 0, 0.22);
}

button.suggested-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  color: #4c7bd9;
}

button.suggested-action:hover {
  color: #ffffff;
  background-color: #618bdd;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), inset 0 -1px rgba(255, 255, 255, 0.03);
  border-color: rgba(0, 0, 0, 0.22);
}

button.suggested-action:active, button.suggested-action:checked {
  color: #ffffff;
  background-color: #376bd5;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), inset 0 -1px rgba(255, 255, 255, 0.03);
  border-color: rgba(0, 0, 0, 0.22);
  box-shadow: none;
}

button.suggested-action.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  color: rgba(160, 180, 220, 0.4);
}

button.suggested-action:disabled {
  color: rgba(160, 180, 220, 0.4);
  background-color: rgba(255, 255, 255, 0.03);
  box-shadow: none;
}

button.destructive-action {
  color: #ffffff;
  background-color: #c35b65;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), inset 0 -1px rgba(255, 255, 255, 0.03);
  border-color: rgba(0, 0, 0, 0.22);
}

button.destructive-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  color: #c35b65;
}

button.destructive-action:hover {
  color: #ffffff;
  background-color: #ca6e77;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), inset 0 -1px rgba(255, 255, 255, 0.03);
  border-color: rgba(0, 0, 0, 0.22);
}

button.destructive-action:active, button.destructive-action:checked {
  color: #ffffff;
  background-color: #bc4853;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), inset 0 -1px rgba(255, 255, 255, 0.03);
  border-color: rgba(0, 0, 0, 0.22);
  box-shadow: none;
}

button.destructive-action.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  color: rgba(160, 180, 220, 0.4);
}

button.destructive-action:disabled {
  color: rgba(160, 180, 220, 0.4);
  background-color: rgba(255, 255, 255, 0.03);
  box-shadow: none;
}

stackswitcher > button {
  outline-offset: -3px;
}

stackswitcher > button > label {
  padding-left: 6px;
  padding-right: 6px;
}

stackswitcher > button > image {
  padding-left: 6px;
  padding-right: 6px;
}

stackswitcher > button.text-button {
  padding-left: 10px;
  padding-right: 10px;
}

stackswitcher > button.image-button {
  padding-left: 2px;
  padding-right: 2px;
}

stackswitcher > button.needs-attention:active > label, stackswitcher > button.needs-attention:active > image, stackswitcher > button.needs-attention:checked > label, stackswitcher > button.needs-attention:checked > image {
  animation: none;
  background-image: none;
}

button.font separator, button.file separator {
  background-color: transparent;
}

menubutton {
  margin: 0;
}

menubutton.osd {
  background: none;
  color: inherit;
}

menubutton.popup > button.arrow-button.image-button, menubutton.popup > button.toggle:not(.image-button) {
  padding-left: 12px;
  padding-right: 12px;
}

menubutton.suggested-action {
  background-color: #4c7bd9;
  color: white;
}

menubutton.destructive-action {
  background-color: #c35b65;
  color: white;
}

menubutton.opaque {
  color: mix(rgba(12, 20, 48, 0.52),rgba(8, 14, 36, 0.42),0.2);
  color: #e8edf8;
}

menubutton.suggested-action, menubutton.destructive-action, menubutton.opaque {
  border-radius: 6px;
}

menubutton.suggested-action.circular, menubutton.suggested-action.pill, menubutton.destructive-action.circular, menubutton.destructive-action.pill, menubutton.opaque.circular, menubutton.opaque.pill {
  border-radius: 9999px;
}

menubutton.suggested-action > button, menubutton.suggested-action > button:checked, menubutton.destructive-action > button, menubutton.destructive-action > button:checked, menubutton.opaque > button, menubutton.opaque > button:checked {
  background-color: transparent;
  color: inherit;
}

menubutton.image-button > button {
  min-width: 24px;
  padding-left: 6px;
  padding-right: 6px;
}

menubutton arrow {
  min-height: 16px;
  min-width: 16px;
}

menubutton arrow.none {
  -gtk-icon-source: -gtk-icontheme("open-menu-symbolic");
}

menubutton arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

menubutton arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

menubutton arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

menubutton arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

.linked > menubutton:first-child > button {
  border-top-left-radius: 6px;
  border-bottom-left-radius: 6px;
}

.linked > menubutton:last-child > button {
  border-top-right-radius: 6px;
  border-bottom-right-radius: 6px;
}

splitbutton {
  border-radius: 6px;
}

splitbutton, splitbutton > separator {
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-property: background;
}

splitbutton > separator {
  margin-top: 6px;
  margin-bottom: 6px;
  background: none;
}

splitbutton > menubutton > button, splitbutton.image-button > button {
  min-width: 24px;
  padding-left: 6px;
  padding-right: 6px;
}

splitbutton.text-button.image-button > button, splitbutton.image-text-button > button {
  padding-left: 9px;
  padding-right: 9px;
}

splitbutton.text-button.image-button > button > box, splitbutton.image-text-button > button > box {
  border-spacing: 6px;
}

splitbutton > button:not(:only-child):not(:first-child):not(:last-child),
splitbutton > menubutton:not(:only-child):not(:first-child):not(:last-child) > button {
  border-radius: 0;
}

splitbutton > button:dir(ltr),
splitbutton > menubutton > button:dir(rtl) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  margin-right: -1px;
}

splitbutton > button:dir(rtl),
splitbutton > menubutton > button:dir(ltr) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  margin-left: -1px;
}

splitbutton.flat > separator {
  background: rgba(255, 255, 255, 0.13);
}

splitbutton.flat:hover, splitbutton.flat:active, splitbutton.flat:checked {
  background: alpha(currentColor,0.07);
}

splitbutton.flat:hover > separator, splitbutton.flat:active > separator, splitbutton.flat:checked > separator {
  background: none;
}

splitbutton.flat:focus-within:focus-visible > separator {
  background: none;
}

splitbutton.flat > button,
splitbutton.flat > menubutton > button {
  border-radius: 6px;
}

splitbutton.suggested-action {
  background-color: #4c7bd9;
  color: white;
}

splitbutton.destructive-action {
  background-color: #c35b65;
  color: white;
}

splitbutton.opaque {
  color: mix(rgba(12, 20, 48, 0.52),rgba(8, 14, 36, 0.42),0.2);
  color: #e8edf8;
}

splitbutton.suggested-action > button, splitbutton.suggested-action > button:checked, splitbutton.suggested-action > menubutton > button, splitbutton.suggested-action > menubutton > button:checked, splitbutton.destructive-action > button, splitbutton.destructive-action > button:checked, splitbutton.destructive-action > menubutton > button, splitbutton.destructive-action > menubutton > button:checked, splitbutton.opaque > button, splitbutton.opaque > button:checked, splitbutton.opaque > menubutton > button, splitbutton.opaque > menubutton > button:checked {
  color: inherit;
  background-color: transparent;
}

splitbutton.suggested-action > menubutton > button:dir(ltr), splitbutton.destructive-action > menubutton > button:dir(ltr), splitbutton.opaque > menubutton > button:dir(ltr) {
  box-shadow: inset 1px 0 rgba(255, 255, 255, 0.13);
}

splitbutton.suggested-action > menubutton > button:dir(rtl), splitbutton.destructive-action > menubutton > button:dir(rtl), splitbutton.opaque > menubutton > button:dir(rtl) {
  box-shadow: inset -1px 0 rgba(255, 255, 255, 0.13);
}

splitbutton > menubutton > button > arrow.none {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

buttoncontent {
  border-spacing: 6px;
}

buttoncontent > label {
  font-weight: bold;
}

buttoncontent > label:dir(ltr) {
  padding-right: 2px;
}

buttoncontent > label:dir(rtl) {
  padding-left: 2px;
}

.arrow-button > box > buttoncontent > label:dir(ltr), splitbutton > button > buttoncontent > label:dir(ltr) {
  padding-right: 0;
}

.arrow-button > box > buttoncontent > label:dir(rtl), splitbutton > button > buttoncontent > label:dir(rtl) {
  padding-left: 0;
}

.linked:not(.vertical):not(.path-bar) > entry:focus-within:not(:only-child) {
  box-shadow: inset 0 0 0 2px alpha(mix(white,#5271ad,0.75),0.75);
}

.linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) {
  box-shadow: inset 0 0 0 2px #d0846c;
}

.linked:not(.vertical):not(.path-bar) > entry.warning:focus-within:not(:only-child) {
  box-shadow: inset 0 0 0 2px #d0846c;
}

.linked:not(.vertical):not(.path-bar) > entry.error:focus-within:not(:only-child) {
  box-shadow: inset 0 0 0 2px #c35b65;
}

.linked:not(.vertical):not(.path-bar) > button + button {
  border-left-style: none;
}

.linked:not(.vertical).path-bar > button + button {
  border-left-style: none;
}

.linked.vertical > entry:focus-within:not(:only-child) {
  box-shadow: inset 0 0 0 2px alpha(mix(white,#5271ad,0.75),0.75);
}

.linked.vertical > entry:drop(active):not(:only-child) {
  box-shadow: inset 0 0 0 2px #d0846c;
}

.linked.vertical > entry.warning:focus-within:not(:only-child) {
  box-shadow: inset 0 0 0 2px #d0846c;
}

.linked.vertical > entry.error:focus-within:not(:only-child) {
  box-shadow: inset 0 0 0 2px #c35b65;
}

.linked.vertical > button + button {
  border-top-style: none;
}

modelbutton.flat {
  transition: all 100ms cubic-bezier(0, 0, 0.2, 1);
  min-height: 26px;
  padding-left: 8px;
  padding-right: 8px;
  outline-offset: -3px;
  border-radius: 6px;
}

modelbutton.flat:hover {
  background-color: alpha(currentColor,0.1);
  transition-duration: 50ms;
}

modelbutton.flat:active, modelbutton.flat:active arrow, modelbutton.flat:selected, modelbutton.flat:selected arrow {
  background-color: #5271ad;
  color: #ffffff;
  transition: none;
  animation: none;
}

modelbutton.flat:checked {
  color: #e8edf8;
}

modelbutton.flat:disabled {
  color: rgba(160, 180, 220, 0.4);
}

modelbutton.flat check:last-child,
modelbutton.flat radio:last-child {
  margin-left: 8px;
}

modelbutton.flat check:first-child,
modelbutton.flat radio:first-child {
  margin-right: 8px;
}

modelbutton.flat arrow.left, modelbutton.flat arrow.right {
  background-color: transparent;
  background-image: none;
  min-width: 16px;
  min-height: 16px;
  transition: none;
  color: rgba(200, 215, 240, 0.85);
  opacity: 1;
}

modelbutton.flat arrow.left:hover, modelbutton.flat arrow.left:selected, modelbutton.flat arrow.left:focus, modelbutton.flat arrow.right:hover, modelbutton.flat arrow.right:selected, modelbutton.flat arrow.right:focus {
  background-color: transparent;
  background-image: none;
  transition: none;
  color: #ffffff;
}

modelbutton.flat arrow.left.left, modelbutton.flat arrow.right.left {
  -gtk-icon-source: -gtk-icontheme("go-previous-symbolic");
}

modelbutton.flat arrow.left.right, modelbutton.flat arrow.right.right {
  -gtk-icon-source: -gtk-icontheme("go-next-symbolic");
}


link,
button.link {
  color: #5e81ac;
  text-decoration: underline;
  font-weight: inherit;
}


link:visited,
button.link:visited {
  color: #a7afbf;
}


link:hover,
button.link:hover {
  color: #6c8eb9;
}


link:active,
button.link:active {
  color: #5e81ac;
}


link:disabled,
button.link:disabled {
  color: alpha(currentColor,0.35);
}

infobar.info > revealer > box link, infobar.info:hover > revealer > box link, infobar.info:backdrop > revealer > box link, infobar.question > revealer > box link, infobar.question:hover > revealer > box link, infobar.question:backdrop > revealer > box link, infobar.warning > revealer > box link, infobar.warning:hover > revealer > box link, infobar.warning:backdrop > revealer > box link, infobar.error > revealer > box link, infobar.error:hover > revealer > box link, infobar.error:backdrop > revealer > box link, .selection-mode headerbar .subtitle:link, headerbar.selection-mode .subtitle:link,
link:selected,
button.link:selected {
  color: mix(#ffffff,#5271ad,0.2);
}

button.link > label {
  text-decoration-line: underline;
}

spinbutton {
  background: none;
  min-height: 28px;
  color: #e8edf8;
  font-feature-settings: "tnum";
}

spinbutton:drop(active) {
  box-shadow: none;
}

spinbutton:disabled {
  color: rgba(160, 180, 220, 0.4);
}

spinbutton:focus-within {
  outline: none;
}

spinbutton > text {
  padding: 6px;
  background-clip: padding-box;
}

spinbutton > text:focus-within {
  outline: none;
  box-shadow: inset 0 0 0 2px alpha(mix(white,#5271ad,0.75),0.75);
}

spinbutton > text:drop(active) {
  outline: none;
  box-shadow: inset 0 0 0 2px #d0846c;
}

spinbutton:not(.vertical) {
  padding: 0;
  border-spacing: 0;
}

spinbutton:not(.vertical) > text {
  padding-top: 2px;
  padding-bottom: 2px;
  min-width: 28px;
  min-height: 24px;
}

spinbutton:not(.vertical) > button {
  min-height: 28px;
  min-width: 28px;
  padding: 0;
}

spinbutton:not(.vertical):dir(ltr) > text, spinbutton:not(.vertical):dir(rtl) > button.up {
  border-radius: 6px 0 0 6px;
}

spinbutton.vertical > button, spinbutton.vertical > text {
  padding-left: 4px;
  padding-right: 4px;
  min-width: 0;
}

spinbutton.vertical > button.up {
  border-radius: 6px 6px 0 0;
}

treeview spinbutton:not(.vertical), row spinbutton:not(.vertical) {
  min-height: 0;
  padding: 0 3px;
  border-style: none;
  border-radius: 6px;
  background-color: alpha(#e8edf8,0.08);
}

treeview spinbutton:not(.vertical):focus, treeview spinbutton:not(.vertical):hover, treeview spinbutton:not(.vertical):selected, row spinbutton:not(.vertical):focus, row spinbutton:not(.vertical):hover, row spinbutton:not(.vertical):selected {
  background-color: alpha(#e8edf8,0.12);
}

treeview spinbutton:not(.vertical):focus-within, row spinbutton:not(.vertical):focus-within {
  box-shadow: inset 0 0 0 2px alpha(mix(white,#5271ad,0.75),0.75);
  transition: box-shadow 150ms cubic-bezier(0, 0, 0.2, 1);
}

treeview spinbutton:not(.vertical) > text, treeview spinbutton:not(.vertical) > text:hover, treeview spinbutton:not(.vertical) > text:focus, row spinbutton:not(.vertical) > text, row spinbutton:not(.vertical) > text:hover, row spinbutton:not(.vertical) > text:focus {
  background: none;
  border: none;
  box-shadow: none;
}

treeview spinbutton:not(.vertical) > button.up,
treeview spinbutton:not(.vertical) > button.down, row spinbutton:not(.vertical) > button.up,
row spinbutton:not(.vertical) > button.down {
  border: none;
  border-color: transparent;
  box-shadow: none;
  border-radius: 100px;
  min-height: 22px;
  min-width: 22px;
  padding: 0;
  margin: 4px 2px;
  background-color: transparent;
}

treeview spinbutton:not(.vertical) > button.up:hover,
treeview spinbutton:not(.vertical) > button.down:hover, row spinbutton:not(.vertical) > button.up:hover,
row spinbutton:not(.vertical) > button.down:hover {
  background-color: alpha(#e8edf8,0.1);
}

treeview spinbutton:not(.vertical) > button.up:active,
treeview spinbutton:not(.vertical) > button.down:active, row spinbutton:not(.vertical) > button.up:active,
row spinbutton:not(.vertical) > button.down:active {
  background-color: alpha(#e8edf8,0.15);
  color: #e8edf8;
}

treeview spinbutton:not(.vertical) > button:hover:not(:active),
treeview spinbutton:not(.vertical) > button:hover + button, row spinbutton:not(.vertical) > button:hover:not(:active),
row spinbutton:not(.vertical) > button:hover + button {
  box-shadow: none;
}

treeview spinbutton:not(.vertical) > button:disabled + button:not(:disabled):not(:active):not(:checked):not(:hover),
treeview spinbutton:not(.vertical) > button:not(:disabled):not(:active):not(:checked):not(:hover) + button:disabled, row spinbutton:not(.vertical) > button:disabled + button:not(:disabled):not(:active):not(:checked):not(:hover),
row spinbutton:not(.vertical) > button:not(:disabled):not(:active):not(:checked):not(:hover) + button:disabled {
  box-shadow: none;
}

treeview spinbutton:not(.vertical) > text:focus + button, row spinbutton:not(.vertical) > text:focus + button {
  border-left-color: transparent;
}

treeview spinbutton:not(.vertical) > text:drop(active) + button, row spinbutton:not(.vertical) > text:drop(active) + button {
  border-left-color: transparent;
}

dropdown > button > box {
  border-spacing: 6px;
}

dropdown,
combobox {
  min-height: 24px;
}

dropdown button.combo,
combobox button.combo {
  min-width: 0;
  min-height: 24px;
  padding-left: 12px;
  padding-right: 12px;
}

dropdown > popover.menu > contents modelbutton,
combobox > popover.menu > contents modelbutton {
  padding-left: 10px;
  padding-right: 10px;
}

dropdown button.combo arrow,
combobox button.combo arrow {
  color: #e8edf8;
  background-color: rgba(136, 170, 255, 0.22);
  -gtk-icon-source: -gtk-scaled(url("assets/combobox-arrow-dark.png"), url("assets/combobox-arrow-dark@2.png"));
  min-height: 16px;
  min-width: 16px;
  padding: 0;
  margin: 4px -6px 4px 0;
  border-radius: 9999px;
  border: none;
}

dropdown button.combo:disabled arrow,
dropdown button.combo:backdrop arrow,
combobox button.combo:disabled arrow,
combobox button.combo:backdrop arrow {
  color: rgba(200, 215, 240, 0.85);
  background-color: rgba(255, 255, 255, 0.07);
  box-shadow: none;
  border: none;
}

dropdown button.combo:checked,
combobox button.combo:checked {
  transition: none;
}

dropdown:drop(active) button.combo,
combobox:drop(active) button.combo {
  color: #d0846c;
  border-color: #d0846c;
  box-shadow: none;
}

dropdown popover,
combobox popover {
  margin-top: 3px;
  padding: 0;
}

dropdown popover .dropdown-searchbar,
combobox popover .dropdown-searchbar {
  padding: 6px;
  border-bottom: 1px solid rgba(255, 255, 255, 0.13);
}

dropdown .linked:not(.vertical) > entry + button.combo arrow, .linked:not(.vertical) > dropdown > box > button.combo arrow,
combobox .linked:not(.vertical) > entry + button.combo arrow, .linked:not(.vertical) > combobox > box > button.combo arrow {
  background-color: transparent;
  box-shadow: none;
  margin: 2px -10px 2px 0;
  -gtk-icon-source: -gtk-scaled(url("assets/combobox-arrow-dark.png"), url("assets/combobox-arrow-dark@2.png"));
}

dropdown .linked:not(.vertical) > entry + button.combo:checked arrow, dropdown .linked:not(.vertical) > entry + button.combo:active arrow, .linked:not(.vertical) > dropdown > box > button.combo:checked arrow, .linked:not(.vertical) > dropdown > box > button.combo:active arrow,
combobox .linked:not(.vertical) > entry + button.combo:checked arrow,
combobox .linked:not(.vertical) > entry + button.combo:active arrow, .linked:not(.vertical) > combobox > box > button.combo:checked arrow, .linked:not(.vertical) > combobox > box > button.combo:active arrow {
  border-radius: 0;
  background-color: transparent;
  -gtk-icon-source: -gtk-scaled(url("assets/combobox-arrow-dark.png"), url("assets/combobox-arrow-dark@2.png"));
}

.linked:not(.vertical) > dropdown:first-child > box > button.combo, .linked:not(.vertical) > combobox:first-child > box > button.combo {
  border-top-left-radius: 6px;
  border-bottom-left-radius: 6px;
}

.linked:not(.vertical) > dropdown:last-child > box > button.combo, .linked:not(.vertical) > combobox:last-child > box > button.combo {
  border-top-right-radius: 6px;
  border-bottom-right-radius: 6px;
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

.linked:not(.vertical) > dropdown:only-child > box > button.combo, .linked:not(.vertical) > combobox:only-child > box > button.combo {
  border-radius: 6px;
}

.linked.vertical > dropdown:first-child > box > button.combo, .linked.vertical > combobox:first-child > box > button.combo {
  border-top-left-radius: 6px;
  border-top-right-radius: 6px;
}

.linked.vertical > dropdown:last-child > box > button.combo, .linked.vertical > combobox:last-child > box > button.combo {
  border-bottom-left-radius: 6px;
  border-bottom-right-radius: 6px;
}

.linked.vertical > dropdown:only-child > box > button.combo, .linked.vertical > combobox:only-child > box > button.combo {
  border-radius: 6px;
}

.toolbar {
  padding: 6px;
  border-spacing: 6px;
  background-color: transparent;
  color: #dce4f5;
}

.toolbar separator {
  background: none;
}

.toolbar.horizontal separator {
  margin: 0 6px;
}

.toolbar.vertical separator {
  margin: 6px 0;
}

.osd .toolbar {
  background-color: transparent;
}

.toolbar.osd {
  padding: 6px;
  border: none;
  border-radius: 12px;
  background-color: rgba(5, 10, 30, 0.72);
  box-shadow: 0 2px 3px 0 rgba(0, 0, 0, 0.2), 0 3px 5px 0 rgba(0, 0, 0, 0.15), inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 0 0 1px rgba(0, 0, 0, 0.75);
}

.toolbar.osd scalebutton {
  margin: 0;
}

searchbar > revealer > box {
  padding: 6px;
  border-spacing: 6px;
}

searchbar:not(.inline) > revealer > box {
  border-style: solid;
  border-color: rgba(255, 255, 255, 0.1);
  background-color: rgba(10, 18, 45, 0.55);
  border-width: 0 0 1px;
  box-shadow: none;
  color: rgba(230, 238, 255, 0.95);
}

searchbar button.flat, searchbar .close {
  min-width: 18px;
  min-height: 18px;
  padding: 4px;
  border-radius: 50%;
}

.top-bar searchbar:not(.inline) > revealer > box, .bottom-bar searchbar:not(.inline) > revealer > box {
  background-color: transparent;
}

actionbar > revealer > box {
  padding: 9px;
  border-spacing: 6px;
  border-top: 1px solid rgba(255, 255, 255, 0.13);
  background-color: rgba(0, 0, 0, 0.06);
  box-shadow: none;
  color: #dce4f5;
}

actionbar > revealer > box button {
  border-radius: 9999px;
}

actionbar > revealer > box button.image-button {
  padding: 3px;
}

actionbar > revealer > box, actionbar > revealer > box > box.start, actionbar > revealer > box > box.end {
  border-spacing: 6px;
}

actionbar > revealer > box:backdrop {
  background-color: transparent;
}

actionbar > revealer > box:backdrop > * {
  filter: opacity(0.5);
}

toolbarview > .bottom-bar actionbar > revealer > box {
  background-color: transparent;
  color: inherit;
  box-shadow: none;
  padding: 6px;
}

toolbarview > .bottom-bar actionbar > revealer > box:backdrop {
  background-color: transparent;
  transition: none;
}

toolbarview > .bottom-bar actionbar > revealer > box:backdrop > * {
  filter: none;
  transition: none;
}

headerbar separator.titlebutton {
  min-width: 0;
  min-height: 0;
  background-color: transparent;
  border: none;
}

headerbar separator.titlebutton:backdrop {
  opacity: 0.65;
}

headerbar entry {
  color: rgba(230, 238, 255, 0.95);
  border-radius: 9999px;
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.03), rgba(255, 255, 255, 0.02));
  box-shadow: 0 3px 8px rgba(0, 0, 0, 0.15), inset 1px 1px 1px -1px rgba(255, 255, 255, 0.1), inset -1px -1px 1px -1px rgba(255, 255, 255, 0.1), inset 0 0 0 2px transparent;
  border: none;
}

headerbar entry image, headerbar entry image:hover {
  color: inherit;
}

headerbar entry:backdrop {
  opacity: 0.65;
  background-color: alpha(rgba(230, 238, 255, 0.95),0.05);
  background-image: none;
  border: none;
  box-shadow: none;
}

headerbar entry:hover {
  color: rgba(230, 238, 255, 0.95);
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.05), rgba(255, 255, 255, 0.03));
  box-shadow: 0 5px 12px rgba(0, 0, 0, 0.2), inset 1px 1px 1px -1px rgba(255, 255, 255, 0.1), inset -1px -1px 1px -1px rgba(255, 255, 255, 0.1), inset 0 0 0 2px transparent;
  transition-duration: 200ms;
}

headerbar entry:focus {
  color: rgba(230, 238, 255, 0.95);
  background-image: none;
  background-color: rgba(255, 255, 255, 0.07);
  box-shadow: 0 5px 12px rgba(0, 0, 0, 0.2), inset 0 0 0 2px alpha(mix(white,#5271ad,0.75),0.75);
}

headerbar entry:disabled {
  opacity: 1;
  color: alpha(rgba(230, 238, 255, 0.95),0.35);
  background-color: alpha(rgba(255, 255, 255, 0.07),0.02);
  background-image: none;
  box-shadow: none;
}

headerbar entry selection:focus {
  background-color: #5271ad;
  color: #ffffff;
}

headerbar entry progress {
  border-color: #5271ad;
  background-image: none;
  background-color: transparent;
}

headerbar entry.warning {
  color: #ffffff;
  border-color: rgba(255, 255, 255, 0.12);
  color: mix(#d0846c,rgba(10, 18, 45, 0.55),0.4);
}

headerbar entry.warning:focus {
  color: #ffffff;
  background-color: #d0846c;
}

headerbar entry.warning selection {
  background-color: #ffffff;
  color: #d0846c;
}

headerbar entry.error {
  color: #ffffff;
  border-color: rgba(255, 255, 255, 0.12);
  color: mix(#c35b65,rgba(10, 18, 45, 0.55),0.4);
}

headerbar entry.error:focus {
  color: #ffffff;
  background-color: #c35b65;
}

headerbar entry.error selection {
  background-color: #ffffff;
  color: #c35b65;
}

headerbar menubutton.flat > button:not(.flat), headerbar button {
  color: rgba(230, 238, 255, 0.95);
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.03), rgba(255, 255, 255, 0.02));
  box-shadow: 0 6px 20px rgba(0, 0, 0, 0.15), inset 1px 2px 1px -1px rgba(255, 255, 255, 0.08), inset -1px -1px 1px 0 rgba(255, 255, 255, 0.08);
  border: none;
}

headerbar menubutton.flat > button:backdrop:not(.flat), headerbar button:backdrop {
  opacity: 0.65;
  background-color: alpha(rgba(230, 238, 255, 0.95),0.05);
  background-image: none;
  border: none;
  box-shadow: none;
}

headerbar menubutton.flat > button:hover:not(.flat), headerbar button:hover {
  color: rgba(230, 238, 255, 0.95);
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.05), rgba(255, 255, 255, 0.03));
  box-shadow: 0 8px 26px rgba(0, 0, 0, 0.2), inset 1px 2px 1px -1px rgba(255, 255, 255, 0.08), inset -1px -1px 1px 0 rgba(255, 255, 255, 0.08);
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

headerbar menubutton.flat > button:active:not(.flat), headerbar button:active {
  color: rgba(230, 238, 255, 0.95);
  background-color: alpha(rgba(230, 238, 255, 0.95),0.25);
  background-image: none;
  box-shadow: none;
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-duration: 300ms;
}

headerbar menubutton.flat > button:checked:not(.flat), headerbar button:checked {
  color: rgba(230, 238, 255, 0.95);
  background-color: alpha(rgba(230, 238, 255, 0.95),0.12);
  background-image: none;
  box-shadow: none;
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-duration: 300ms;
}

headerbar menubutton.flat > button:checked:hover:not(.flat), headerbar button:checked:hover {
  background-image: none;
}

headerbar menubutton.flat > button:disabled:not(.flat), headerbar button:disabled {
  color: alpha(rgba(230, 238, 255, 0.95),0.35);
  background-image: none;
  background-color: transparent;
  box-shadow: none;
}

headerbar menubutton.flat > button:disabled:checked:not(.flat), headerbar button:disabled:checked {
  color: alpha(rgba(230, 238, 255, 0.95),0.35);
  background-image: none;
  background-color: transparent;
  box-shadow: none;
}

.sidebar-pane headerbar button, headerbar > windowhandle > box viewswitcher > button.toggle, #NautilusPathBar > menubutton > button, #NautilusPathBar > menubutton.flat.popup > button, .nautilus-pathbar > menubutton > button, .nautilus-pathbar > menubutton.flat.popup > button, #NautilusPathBar #NautilusPathButton, #NautilusPathBar .nautilus-path-button, .nautilus-pathbar #NautilusPathButton, .nautilus-pathbar .nautilus-path-button, #NautilusQueryEditor > menubutton > button, .nautilus-query-editor > menubutton > button, .nautilus-window headerbar > windowhandle > box > widget > box.start > stack > widget > box > button,
.nautilus-window headerbar > windowhandle > box > widget > box.start > box > stack > widget > box > button,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > stack > widget > box > button, headerbar stackswitcher > button, headerbar splitbutton > button,
headerbar splitbutton > button button,
headerbar splitbutton > menubutton > button, headerbar entry button, window.background.csd > dialog-host > widget > widget > box > leaflet > headerbar.titlebar.tweak-titlebar-left button:not(.close):not(.maximize):not(.minimize), window.background.csd > contents > leaflet.unfolded > box > headerbar button:not(.close):not(.maximize):not(.minimize),
window.background.csd > widget > leaflet.unfolded > box > headerbar button:not(.close):not(.maximize):not(.minimize) {
  color: rgba(230, 238, 255, 0.95);
  background-color: transparent;
  background-image: none;
  border: none;
  box-shadow: none;
}

.sidebar-pane headerbar button:backdrop, headerbar > windowhandle > box viewswitcher > button.toggle:backdrop, #NautilusPathBar > menubutton > button:backdrop, #NautilusPathBar > menubutton.flat.popup > button:backdrop, .nautilus-pathbar > menubutton > button:backdrop, .nautilus-pathbar > menubutton.flat.popup > button:backdrop, #NautilusPathBar #NautilusPathButton:backdrop, #NautilusPathBar .nautilus-path-button:backdrop, .nautilus-pathbar #NautilusPathButton:backdrop, .nautilus-pathbar .nautilus-path-button:backdrop, #NautilusQueryEditor > menubutton > button:backdrop, .nautilus-query-editor > menubutton > button:backdrop, .nautilus-window headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:backdrop,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:backdrop, headerbar stackswitcher > button:backdrop, headerbar splitbutton > button:backdrop,
headerbar splitbutton > button button:backdrop,
headerbar splitbutton > menubutton > button:backdrop, headerbar entry button:backdrop, window.background.csd > dialog-host > widget > widget > box > leaflet > headerbar.titlebar.tweak-titlebar-left button:backdrop:not(.close):not(.maximize):not(.minimize), window.background.csd > contents > leaflet.unfolded > box > headerbar button:backdrop:not(.close):not(.maximize):not(.minimize),
window.background.csd > widget > leaflet.unfolded > box > headerbar button:backdrop:not(.close):not(.maximize):not(.minimize) {
  opacity: 0.65;
  background-color: transparent;
  background-image: none;
  border: none;
  box-shadow: none;
}

.sidebar-pane headerbar button:hover, headerbar > windowhandle > box viewswitcher > button.toggle:hover, #NautilusPathBar > menubutton > button:hover, #NautilusPathBar > menubutton.flat.popup > button:hover, .nautilus-pathbar > menubutton > button:hover, .nautilus-pathbar > menubutton.flat.popup > button:hover, #NautilusPathBar #NautilusPathButton:hover, #NautilusPathBar .nautilus-path-button:hover, .nautilus-pathbar #NautilusPathButton:hover, .nautilus-pathbar .nautilus-path-button:hover, #NautilusQueryEditor > menubutton > button:hover, .nautilus-query-editor > menubutton > button:hover, .nautilus-window headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:hover,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:hover, headerbar stackswitcher > button:hover, headerbar splitbutton > button:hover,
headerbar splitbutton > button button:hover,
headerbar splitbutton > menubutton > button:hover, headerbar entry button:hover, window.background.csd > dialog-host > widget > widget > box > leaflet > headerbar.titlebar.tweak-titlebar-left button:hover:not(.close):not(.maximize):not(.minimize), window.background.csd > contents > leaflet.unfolded > box > headerbar button:hover:not(.close):not(.maximize):not(.minimize),
window.background.csd > widget > leaflet.unfolded > box > headerbar button:hover:not(.close):not(.maximize):not(.minimize) {
  color: rgba(230, 238, 255, 0.95);
  background-color: alpha(rgba(230, 238, 255, 0.95),0.1);
  background-image: none;
  box-shadow: none;
}

.sidebar-pane headerbar button:active, headerbar > windowhandle > box viewswitcher > button.toggle:active, #NautilusPathBar > menubutton > button:active, #NautilusPathBar > menubutton.flat.popup > button:active, .nautilus-pathbar > menubutton > button:active, .nautilus-pathbar > menubutton.flat.popup > button:active, #NautilusPathBar #NautilusPathButton:active, #NautilusPathBar .nautilus-path-button:active, .nautilus-pathbar #NautilusPathButton:active, .nautilus-pathbar .nautilus-path-button:active, #NautilusQueryEditor > menubutton > button:active, .nautilus-query-editor > menubutton > button:active, .nautilus-window headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:active,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:active, headerbar stackswitcher > button:active, headerbar splitbutton > button:active,
headerbar splitbutton > button button:active,
headerbar splitbutton > menubutton > button:active, headerbar entry button:active, window.background.csd > dialog-host > widget > widget > box > leaflet > headerbar.titlebar.tweak-titlebar-left button:active:not(.close):not(.maximize):not(.minimize), window.background.csd > contents > leaflet.unfolded > box > headerbar button:active:not(.close):not(.maximize):not(.minimize),
window.background.csd > widget > leaflet.unfolded > box > headerbar button:active:not(.close):not(.maximize):not(.minimize) {
  color: rgba(230, 238, 255, 0.95);
  background-color: alpha(rgba(230, 238, 255, 0.95),0.25);
  background-image: none;
  box-shadow: none;
}

.sidebar-pane headerbar button:checked, headerbar > windowhandle > box viewswitcher > button.toggle:checked, #NautilusPathBar > menubutton > button:checked, #NautilusPathBar > menubutton.flat.popup > button:checked, .nautilus-pathbar > menubutton > button:checked, .nautilus-pathbar > menubutton.flat.popup > button:checked, #NautilusPathBar #NautilusPathButton:checked, #NautilusPathBar .nautilus-path-button:checked, .nautilus-pathbar #NautilusPathButton:checked, .nautilus-pathbar .nautilus-path-button:checked, #NautilusQueryEditor > menubutton > button:checked, .nautilus-query-editor > menubutton > button:checked, .nautilus-window headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:checked,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:checked, headerbar stackswitcher > button:checked, headerbar splitbutton > button:checked,
headerbar splitbutton > button button:checked,
headerbar splitbutton > menubutton > button:checked, headerbar entry button:checked, window.background.csd > dialog-host > widget > widget > box > leaflet > headerbar.titlebar.tweak-titlebar-left button:checked:not(.close):not(.maximize):not(.minimize), window.background.csd > contents > leaflet.unfolded > box > headerbar button:checked:not(.close):not(.maximize):not(.minimize),
window.background.csd > widget > leaflet.unfolded > box > headerbar button:checked:not(.close):not(.maximize):not(.minimize) {
  color: rgba(230, 238, 255, 0.95);
  background-color: alpha(rgba(230, 238, 255, 0.95),0.15);
  background-image: none;
  box-shadow: none;
}

.sidebar-pane headerbar button:disabled, headerbar > windowhandle > box viewswitcher > button.toggle:disabled, #NautilusPathBar > menubutton > button:disabled, #NautilusPathBar > menubutton.flat.popup > button:disabled, .nautilus-pathbar > menubutton > button:disabled, .nautilus-pathbar > menubutton.flat.popup > button:disabled, #NautilusPathBar #NautilusPathButton:disabled, #NautilusPathBar .nautilus-path-button:disabled, .nautilus-pathbar #NautilusPathButton:disabled, .nautilus-pathbar .nautilus-path-button:disabled, #NautilusQueryEditor > menubutton > button:disabled, .nautilus-query-editor > menubutton > button:disabled, .nautilus-window headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:disabled,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:disabled, headerbar stackswitcher > button:disabled, headerbar splitbutton > button:disabled,
headerbar splitbutton > button button:disabled,
headerbar splitbutton > menubutton > button:disabled, headerbar entry button:disabled, window.background.csd > dialog-host > widget > widget > box > leaflet > headerbar.titlebar.tweak-titlebar-left button:disabled:not(.close):not(.maximize):not(.minimize), window.background.csd > contents > leaflet.unfolded > box > headerbar button:disabled:not(.close):not(.maximize):not(.minimize),
window.background.csd > widget > leaflet.unfolded > box > headerbar button:disabled:not(.close):not(.maximize):not(.minimize) {
  color: alpha(rgba(230, 238, 255, 0.95),0.35);
  background-image: none;
  background-color: transparent;
  box-shadow: none;
}

.sidebar-pane headerbar button:disabled:checked, headerbar > windowhandle > box viewswitcher > button.toggle:disabled:checked, #NautilusPathBar > menubutton > button:disabled:checked, #NautilusPathBar > menubutton.flat.popup > button:disabled:checked, .nautilus-pathbar > menubutton > button:disabled:checked, .nautilus-pathbar > menubutton.flat.popup > button:disabled:checked, #NautilusPathBar #NautilusPathButton:disabled:checked, #NautilusPathBar .nautilus-path-button:disabled:checked, .nautilus-pathbar #NautilusPathButton:disabled:checked, .nautilus-pathbar .nautilus-path-button:disabled:checked, #NautilusQueryEditor > menubutton > button:disabled:checked, .nautilus-query-editor > menubutton > button:disabled:checked, .nautilus-window headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:disabled:checked,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > stack > widget > box > button:disabled:checked, headerbar stackswitcher > button:disabled:checked, headerbar splitbutton > button:disabled:checked,
headerbar splitbutton > button button:disabled:checked,
headerbar splitbutton > menubutton > button:disabled:checked, headerbar entry button:disabled:checked, window.background.csd > dialog-host > widget > widget > box > leaflet > headerbar.titlebar.tweak-titlebar-left button:disabled:checked:not(.close):not(.maximize):not(.minimize), window.background.csd > contents > leaflet.unfolded > box > headerbar button:disabled:checked:not(.close):not(.maximize):not(.minimize),
window.background.csd > widget > leaflet.unfolded > box > headerbar button:disabled:checked:not(.close):not(.maximize):not(.minimize) {
  color: alpha(rgba(230, 238, 255, 0.95),0.35);
  background-image: none;
  background-color: alpha(rgba(230, 238, 255, 0.95),0.06);
  box-shadow: none;
}

headerbar {
  min-height: 48px;
  padding: 0;
  margin: 0;
  color: rgba(230, 238, 255, 0.95);
  background-color: rgba(10, 18, 45, 0.55);
  border-bottom: 1px solid mix(black,#2e3440,0.25);
  box-shadow: none;
}

headerbar:backdrop {
  opacity: 1;
  transition: 150ms ease-out;
  color: mix(rgba(230, 238, 255, 0.95),rgba(6, 12, 30, 0.34),0.3);
  background-color: rgba(6, 12, 30, 0.34);
  border-color: mix(black,#2e3440,0.55);
  box-shadow: none;
}

headerbar.flat, headerbar.flat:backdrop {
  border: none;
  background: none;
}

headerbar .title {
  padding: 0 12px;
}

headerbar .subtitle {
  font-size: smaller;
  padding: 0 12px;
  margin-top: -3px;
}

headerbar > windowhandle > box {
  padding: 6px;
}

headerbar > windowhandle > box,
headerbar > windowhandle > box > box.start,
headerbar > windowhandle > box > box.end {
  border-spacing: 6px;
}

headerbar > windowhandle > box > box.start:dir(ltr),
headerbar > windowhandle > box > box.end:dir(rtl), headerbar > windowhandle > box > widget > box.start:dir(ltr),
headerbar > windowhandle > box > widget > box.end:dir(rtl) {
  margin-right: 6px;
}

headerbar > windowhandle > box > box.start:dir(rtl),
headerbar > windowhandle > box > box.end:dir(ltr), headerbar > windowhandle > box > widget > box.start:dir(rtl),
headerbar > windowhandle > box > widget > box.end:dir(ltr) {
  margin-left: 6px;
}

headerbar entry {
  border-spacing: 6px;
  min-height: 30px;
  min-width: 30px;
  padding: 3px 12px;
  border-radius: 9999px;
}

headerbar entry.location-entry {
  padding: 3px;
}

headerbar entry.location-entry > text {
  margin-left: 9px;
  margin-right: 9px;
}

headerbar entry.location-entry > progress {
  margin-left: 6px;
  margin-right: 6px;
}

headerbar entry button {
  min-height: 24px;
  min-width: 24px;
  border-radius: 9999px;
}

headerbar entry button, headerbar entry button.image-button {
  padding: 3px;
}

headerbar entry button.text-button {
  padding: 3px 12px;
}

headerbar entry button.text-button.image-button, headerbar entry button.image-text-button {
  padding: 3px 9px;
}

headerbar button {
  border-radius: 9999px;
}

headerbar button, headerbar button.image-button {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
}

headerbar button.text-button {
  min-height: 24px;
  min-width: 24px;
  padding: 6px 15px;
}

headerbar button.text-button.image-button, headerbar button.image-text-button {
  min-height: 24px;
  min-width: 24px;
  padding: 6px 12px;
}

headerbar button.star {
  min-width: 24px;
  padding: 2px;
  padding: 6px;
  border-radius: 9999px;
}

headerbar splitbutton {
  border-radius: 9999px;
  padding: 3px;
  color: rgba(230, 238, 255, 0.95);
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.03), rgba(255, 255, 255, 0.02));
  box-shadow: 0 6px 20px rgba(0, 0, 0, 0.15), inset 1px 2px 1px -1px rgba(255, 255, 255, 0.08), inset -1px -1px 1px 0 rgba(255, 255, 255, 0.08);
  border: none;
}

headerbar splitbutton:backdrop {
  background-color: alpha(rgba(230, 238, 255, 0.95),0.05);
  background-image: none;
  border: none;
  box-shadow: none;
}

headerbar splitbutton > separator {
  background-color: rgba(255, 255, 255, 0.13);
  min-width: 1px;
  margin: 6px 2px;
}

headerbar splitbutton > button,
headerbar splitbutton > button.image-button,
headerbar splitbutton > menubutton > button,
headerbar splitbutton > menubutton.popup > button, headerbar splitbutton.image-button > menubutton.popup > button.toggle:not(.image-button), headerbar splitbutton.image-button > button, headerbar splitbutton.text-button.image-button > button, headerbar splitbutton.image-text-button > button {
  min-height: 24px;
  min-width: 24px;
  padding: 3px;
}

headerbar splitbutton > button button {
  min-height: 24px;
  min-width: 24px;
  padding: 0;
}

headerbar splitbutton > button:not(:only-child):not(:first-child):not(:last-child),
headerbar splitbutton > menubutton:not(:only-child):not(:first-child):not(:last-child) > button {
  border-radius: 9999px;
}

headerbar splitbutton > button:dir(ltr),
headerbar splitbutton > menubutton > button:dir(rtl) {
  border-top-right-radius: 9999px;
  border-bottom-right-radius: 9999px;
  margin-right: 0;
}

headerbar splitbutton > button:dir(rtl),
headerbar splitbutton > menubutton > button:dir(ltr) {
  border-top-left-radius: 9999px;
  border-bottom-left-radius: 9999px;
  margin-left: 0;
}

headerbar stackswitcher {
  border-radius: 9999px;
  padding: 3px;
  color: rgba(230, 238, 255, 0.95);
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.03), rgba(255, 255, 255, 0.02));
  box-shadow: 0 6px 20px rgba(0, 0, 0, 0.15), inset 1px 2px 1px -1px rgba(255, 255, 255, 0.08), inset -1px -1px 1px 0 rgba(255, 255, 255, 0.08);
  border: none;
}

headerbar stackswitcher:backdrop {
  background-color: alpha(rgba(230, 238, 255, 0.95),0.05);
  background-image: none;
  border: none;
  box-shadow: none;
}

headerbar stackswitcher > button {
  font-weight: 500;
  min-width: 24px;
  min-height: 24px;
  padding: 3px;
}

headerbar stackswitcher > button.text-button {
  min-width: 24px;
  padding: 3px 15px;
}

headerbar stackswitcher > button:not(:first-child) {
  border-width: 0 0 0 1px;
  border-style: none solid none none;
  border-image: linear-gradient(to bottom, transparent 16%, rgba(255, 255, 255, 0.1) 16%, rgba(255, 255, 255, 0.1) 84%, transparent 84%) 0 0 0 1/0 0 0 1px stretch;
}

headerbar stackswitcher > button:hover, headerbar stackswitcher > button:active, headerbar stackswitcher > button:checked {
  border-image: none;
}

headerbar stackswitcher.linked:not(.vertical) > button, headerbar stackswitcher.linked:not(.vertical) > button:first-child, headerbar stackswitcher.linked:not(.vertical) > button:last-child {
  border-radius: 9999px;
}

headerbar stackswitcher > button:hover + button,
headerbar stackswitcher > button:active + button,
headerbar stackswitcher > button:checked + button {
  border-image: none;
}

headerbar popover entry {
  min-height: 24px;
  padding: 2px 8px;
  border-radius: 6px;
}

headerbar popover entry, headerbar popover entry:hover, headerbar popover entry:focus-within {
  box-shadow: none;
  background-image: none;
}

headerbar popover button {
  min-height: 24px;
  min-width: 24px;
  border-radius: 6px;
  padding: 2px 6px;
}

headerbar popover button, headerbar popover button:hover, headerbar popover button:active, headerbar popover button:checked {
  box-shadow: none;
  background-image: none;
}

headerbar switch:backdrop {
  opacity: 0.75;
}

headerbar.titlebar headerbar:not(.titlebar) {
  background: none;
  box-shadow: none;
}

headerbar windowhandle box.linked > button {
  background-color: alpha(currentColor,0.05);
}

headerbar windowhandle box.linked > button:hover {
  background-color: alpha(currentColor,0.1);
}

headerbar windowhandle box.linked > button:active {
  background-color: alpha(currentColor,0.16);
}

headerbar windowhandle box.linked > button:checked {
  background-color: alpha(currentColor,0.12);
}

.selection-mode headerbar, headerbar.selection-mode {
  color: #ffffff;
  background-color: mix(white,#5271ad,0.75);
  box-shadow: none;
  background-image: none;
  text-shadow: none;
  border-color: mix(black,mix(white,#5271ad,0.75),0.94);
}

.selection-mode headerbar:backdrop, headerbar.selection-mode:backdrop {
  background-color: mix(white,#5271ad,0.75);
  color: alpha(#ffffff,0.6);
  border-color: mix(black,mix(white,#5271ad,0.75),0.94);
}

.selection-mode headerbar button, headerbar.selection-mode button {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}

.selection-mode headerbar .selection-menu, headerbar.selection-mode .selection-menu {
  box-shadow: none;
  padding-left: 10px;
  padding-right: 10px;
}

.selection-mode headerbar .selection-menu .arrow, headerbar.selection-mode .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

.maximized .selection-mode headerbar, .maximized headerbar.selection-mode {
  background-color: mix(white,#5271ad,0.75);
}

.tiled headerbar, .tiled headerbar:backdrop, .maximized headerbar, .maximized headerbar:backdrop {
  border-radius: 0 0 0 0;
  box-shadow: none;
}

.maximized headerbar {
  background-color: rgba(10, 18, 45, 0.55);
  border-color: mix(black,#2e3440,0.25);
  box-shadow: none;
}

.maximized headerbar:backdrop {
  background-color: rgba(6, 12, 30, 0.34);
  border-color: alpha(mix(black,#2e3440,0.25),0.65);
}

.maximized headerbar.flat, .maximized headerbar.flat:backdrop {
  border: none;
  background: none;
}

headerbar windowcontrols {
  border-spacing: 6px;
  padding: 0 8px;
}

headerbar windowcontrols:not(.empty).start:dir(ltr), headerbar windowcontrols:not(.empty).end:dir(rtl) {
  margin-right: 8px;
}

headerbar windowcontrols:not(.empty).start:dir(rtl), headerbar windowcontrols:not(.empty).end:dir(ltr) {
  margin-left: 8px;
}

headerbar.titlebar headerbar windowcontrols {
  border-spacing: 6px;
}

headerbar windowcontrols button > image {
  padding: 0;
  margin: 0;
  background-color: transparent;
  background-image: none;
  color: transparent;
}

headerbar windowcontrols button.close, headerbar windowcontrols button.maximize, headerbar windowcontrols button.minimize {
  min-width: 16px;
  min-height: 16px;
  padding: 0;
  margin: 0 1px;
  background-position: center;
  background-repeat: no-repeat;
  background-size: 16px 16px;
}

headerbar windowcontrols button.close, headerbar windowcontrols button.close:hover, headerbar windowcontrols button.close:focus, headerbar windowcontrols button.close:active, headerbar windowcontrols button.close:backdrop, headerbar windowcontrols button.maximize, headerbar windowcontrols button.maximize:hover, headerbar windowcontrols button.maximize:focus, headerbar windowcontrols button.maximize:active, headerbar windowcontrols button.maximize:backdrop, headerbar windowcontrols button.minimize, headerbar windowcontrols button.minimize:hover, headerbar windowcontrols button.minimize:focus, headerbar windowcontrols button.minimize:active, headerbar windowcontrols button.minimize:backdrop {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  color: transparent;
}

headerbar windowcontrols button.close:backdrop, headerbar windowcontrols button.maximize:backdrop, headerbar windowcontrols button.minimize:backdrop {
  opacity: 1;
}

headerbar windowcontrols button.close {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-close-dark.png"), url("windows-assets/titlebutton-close-dark@2.png"));
}

headerbar windowcontrols button.close:backdrop {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-close-backdrop-dark.png"), url("windows-assets/titlebutton-close-backdrop-dark@2.png"));
}

headerbar windowcontrols button.close:backdrop:hover {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-close-backdrop-hover-dark.png"), url("windows-assets/titlebutton-close-backdrop-hover-dark@2.png"));
}

headerbar windowcontrols button.close:hover {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-close-hover-dark.png"), url("windows-assets/titlebutton-close-hover-dark@2.png"));
}

headerbar windowcontrols button.close:active {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-close-active-dark.png"), url("windows-assets/titlebutton-close-active-dark@2.png"));
}

headerbar windowcontrols button.maximize {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-maximize-dark.png"), url("windows-assets/titlebutton-maximize-dark@2.png"));
}

headerbar windowcontrols button.maximize:backdrop {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-maximize-backdrop-dark.png"), url("windows-assets/titlebutton-maximize-backdrop-dark@2.png"));
}

headerbar windowcontrols button.maximize:backdrop:hover {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-maximize-backdrop-hover-dark.png"), url("windows-assets/titlebutton-maximize-backdrop-hover-dark@2.png"));
}

headerbar windowcontrols button.maximize:hover {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-maximize-hover-dark.png"), url("windows-assets/titlebutton-maximize-hover-dark@2.png"));
}

headerbar windowcontrols button.maximize:active {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-maximize-active-dark.png"), url("windows-assets/titlebutton-maximize-active-dark@2.png"));
}

headerbar windowcontrols button.minimize {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-minimize-dark.png"), url("windows-assets/titlebutton-minimize-dark@2.png"));
}

headerbar windowcontrols button.minimize:backdrop {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-minimize-backdrop-dark.png"), url("windows-assets/titlebutton-minimize-backdrop-dark@2.png"));
}

headerbar windowcontrols button.minimize:backdrop:hover {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-minimize-backdrop-hover-dark.png"), url("windows-assets/titlebutton-minimize-backdrop-hover-dark@2.png"));
}

headerbar windowcontrols button.minimize:hover {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-minimize-hover-dark.png"), url("windows-assets/titlebutton-minimize-hover-dark@2.png"));
}

headerbar windowcontrols button.minimize:active {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-minimize-active-dark.png"), url("windows-assets/titlebutton-minimize-active-dark@2.png"));
}

.fullscreen headerbar windowcontrols button.maximize, .maximized headerbar windowcontrols button.maximize {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-restore-dark.png"), url("windows-assets/titlebutton-restore-dark@2.png"));
}

.fullscreen headerbar windowcontrols button.maximize:backdrop, .maximized headerbar windowcontrols button.maximize:backdrop {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-restore-backdrop-dark.png"), url("windows-assets/titlebutton-restore-backdrop-dark@2.png"));
}

.fullscreen headerbar windowcontrols button.maximize:backdrop:hover, .maximized headerbar windowcontrols button.maximize:backdrop:hover {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-restore-backdrop-hover-dark.png"), url("windows-assets/titlebutton-restore-backdrop-hover-dark@2.png"));
}

.fullscreen headerbar windowcontrols button.maximize:hover, .maximized headerbar windowcontrols button.maximize:hover {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-restore-hover-dark.png"), url("windows-assets/titlebutton-restore-hover-dark@2.png"));
}

.fullscreen headerbar windowcontrols button.maximize:active, .maximized headerbar windowcontrols button.maximize:active {
  background-image: -gtk-scaled(url("windows-assets/titlebutton-restore-active-dark.png"), url("windows-assets/titlebutton-restore-active-dark@2.png"));
}

headerbar.default-decoration {
  min-height: 32px;
  padding: 0;
  background-color: rgba(10, 18, 45, 0.55);
  border: none;
  box-shadow: none;
}

headerbar.default-decoration > windowhandle > box {
  padding: 0 3px;
  margin-top: 0;
  margin-bottom: 0;
}

.tiled headerbar.default-decoration, .maximized headerbar.default-decoration, .fullscreen headerbar.default-decoration {
  box-shadow: none;
}

headerbar.default-decoration windowcontrols button,
headerbar.default-decoration windowcontrols menubutton {
  border: none;
  min-width: 16px;
  min-height: 16px;
  margin: 0;
  padding: 0;
}

headerbar.default-decoration windowcontrols menubutton button {
  min-height: 20px;
  min-width: 20px;
  margin: 0;
  padding: 4px;
}

headerbar.default-decoration windowcontrols button.close, headerbar.default-decoration windowcontrols button.maximize, headerbar.default-decoration windowcontrols button.minimize {
  min-width: 16px;
  min-height: 16px;
  margin: 0 1px;
  padding: 0;
}

.titlebar > box.left.horizontal,
.titlebar > box.right.horizontal {
  padding: 0 6px;
}

window > .titlebar:not(headerbar), window > .titlebar:not(headerbar):backdrop, window.csd > .titlebar:not(headerbar), window.csd > .titlebar:not(headerbar):backdrop {
  padding: 0;
  background: none;
  border: none;
  box-shadow: none;
}

.titlebar:not(headerbar) > separator {
  min-width: 1px;
}

pathbar > button {
  min-width: 12px;
  min-height: 26px;
}

pathbar > button.text-button, pathbar > button.image-button, pathbar > button {
  padding-left: 6px;
  padding-right: 6px;
}

pathbar > button:hover {
  box-shadow: none;
}

pathbar > button:active, pathbar > button:checked {
  background-color: #b8b8b8;
  color: rgba(0, 0, 0, 0.75);
  border-color: rgba(0, 0, 0, 0.15);
}

pathbar > button:disabled {
  border-color: rgba(0, 0, 0, 0.15);
}

pathbar > button.text-button.image-button label {
  padding-left: 0;
  padding-right: 0;
}

pathbar > button.text-button.image-button label:last-child, pathbar > button label:last-child {
  padding-right: 10px;
}

pathbar > button.text-button.image-button label:first-child, pathbar > button label:first-child {
  padding-left: 10px;
}

pathbar > button.slider-button, pathbar > button:not(.image-button):not(.text-button) {
  padding-left: 1px;
  padding-right: 1px;
}

pathbar > button image {
  padding-left: 6px;
  padding-right: 6px;
}

columnview.view,
treeview.view {
  border-left-color: rgba(255, 255, 255, 0.1);
  border-top-color: rgba(255, 255, 255, 0.1);
}

columnview.view acceleditor > label,
treeview.view acceleditor > label {
  background-color: #5271ad;
}

columnview.view:disabled,
treeview.view:disabled {
  color: rgba(160, 180, 220, 0.4);
}

columnview.view:disabled:selected,
treeview.view:disabled:selected {
  color: alpha(#ffffff,0.45);
}

columnview.view.separator,
treeview.view.separator {
  min-height: 2px;
  color: rgba(255, 255, 255, 0.13);
}

columnview.view > dndtarget:drop(active),
treeview.view > dndtarget:drop(active) {
  border-style: solid none;
  border-width: 1px;
  border-color: #d0846c;
}

columnview.view > dndtarget:drop(active).after,
treeview.view > dndtarget:drop(active).after {
  border-top-style: none;
}

columnview.view > dndtarget:drop(active).before,
treeview.view > dndtarget:drop(active).before {
  border-bottom-style: none;
}

columnview.view.expander,
treeview.view.expander {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  color: rgba(200, 215, 240, 0.85);
}

columnview.view.expander:dir(rtl),
treeview.view.expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

columnview.view.expander:hover,
treeview.view.expander:hover {
  color: #e8edf8;
}

columnview.view.expander:checked,
treeview.view.expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

columnview.view.expander:disabled,
treeview.view.expander:disabled {
  color: rgba(162, 171, 188, 0.35);
}

columnview.view.progressbar,
treeview.view.progressbar {
  color: #ffffff;
  border-radius: 6px;
  background-color: #5271ad;
}

columnview.view.progressbar:selected,
treeview.view.progressbar:selected {
  color: #5271ad;
  box-shadow: none;
  background-color: #ffffff;
}

columnview.view.trough,
treeview.view.trough {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.12);
  border-radius: 6px;
  border-width: 0;
}

columnview.view.trough:selected,
treeview.view.trough:selected {
  color: #ffffff;
  background-color: rgba(0, 0, 0, 0.2);
  border-radius: 6px;
  border-width: 0;
}

columnview.view > header > button,
treeview.view > header > button {
  min-height: 26px;
  min-width: 38px;
  padding: 0 6px;
  font-weight: bold;
  color: rgba(200, 215, 240, 0.85);
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  border-style: none solid none none;
  border-radius: 0;
  border-image: linear-gradient(to bottom, transparent 20%, rgba(255, 255, 255, 0.13) 20%, rgba(255, 255, 255, 0.13) 80%, transparent 80%) 0 1 0 0/0 1px 0 0 stretch;
}

columnview.view > header > button:hover,
treeview.view > header > button:hover {
  color: #5271ad;
}

columnview.view > header > button:active,
treeview.view > header > button:active {
  color: #e8edf8;
}

columnview.view > header > button:active, columnview.view > header > button:hover,
treeview.view > header > button:active,
treeview.view > header > button:hover {
  background-color: rgba(8, 14, 36, 0.42);
}

columnview.view > header > button:disabled,
treeview.view > header > button:disabled {
  border-color: rgba(12, 20, 48, 0.52);
  background-image: none;
}

columnview.view > header > button:last-child,
treeview.view > header > button:last-child {
  border-right-style: none;
  border-image: none;
}

columnview.view button.dnd, columnview.view button.dnd:selected, columnview.view button.dnd:hover, columnview.view button.dnd:active,
columnview.view header.button.dnd,
columnview.view header.button.dnd:selected,
columnview.view header.button.dnd:hover,
columnview.view header.button.dnd:active,
treeview.view button.dnd,
treeview.view button.dnd:selected,
treeview.view button.dnd:hover,
treeview.view button.dnd:active,
treeview.view header.button.dnd,
treeview.view header.button.dnd:selected,
treeview.view header.button.dnd:hover,
treeview.view header.button.dnd:active {
  padding: 0 6px;
  transition: none;
  color: #ffffff;
  background-color: #5271ad;
  border-radius: 0;
  border-style: none;
}

treeview.navigation-sidebar {
  padding: 0;
}

menubar {
  padding: 0;
  background-color: rgba(10, 18, 45, 0.55);
  color: rgba(230, 238, 255, 0.95);
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.13);
}

menubar:backdrop {
  color: mix(rgba(230, 238, 255, 0.95),rgba(6, 12, 30, 0.34),0.3);
}

menubar > item {
  transition: all 0.2s cubic-bezier(0, 0, 0.2, 1);
  padding: 4px 6px;
  border: none;
  border-radius: 3px;
}

menubar > item:hover {
  transition: none;
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.12);
}

menubar > item:disabled {
  color: mix(rgba(230, 238, 255, 0.95),rgba(10, 18, 45, 0.55),0.5);
}

menubar > item popover.menu.background > contents {
  padding: 6px;
  border-radius: 12px;
}

menubar > item popover.menu popover.menu {
  padding: 0 0 6px 0;
}

menubar > item popover.menu.background popover.menu.background > contents {
  margin: 0;
  border-radius: 12px;
}

popover.background {
  background-color: transparent;
  font: initial;
}

popover.background:backdrop {
  background-color: transparent;
}

popover > arrow,
popover > contents {
  color: #e8edf8;
  background-clip: padding-box;
  background-color: rgba(10, 18, 46, 0.6);
  box-shadow: 0 3px 6px 0 rgba(0, 0, 0, 0.15), 0 0 0 1px rgba(0, 0, 0, 0.75);
  border: 1px solid mix(white,rgba(10, 18, 46, 0.6),0.92);
}

popover, popover:backdrop {
  background-color: transparent;
}

popover > contents {
  padding: 6px;
  border-radius: 12px;
}

popover > contents list,
popover > contents .view,
popover > contents > toolbar {
  border: none;
  background-color: transparent;
}

popover > contents separator {
  background-color: rgba(255, 255, 255, 0.05);
  margin: 3px;
}

popover > contents > scrolledwindow > viewport > stack > box {
  padding: 0;
}

popover > contents stack scrolledwindow:not(.view) > viewport {
  border: 1px solid rgba(255, 255, 255, 0.13);
  border-radius: 6px;
  background-color: rgba(8, 14, 36, 0.42);
}

popover > contents listview, popover > contents list {
  padding: 0;
  margin: 0;
}

popover > contents listview > row, popover > contents list > row {
  padding: 3px 9px;
  margin: 0;
  border-radius: 6px;
}

popover > contents listview > row:selected, popover > contents list > row:selected {
  color: #ffffff;
  background-color: #5271ad;
}

.osd popover, popover.touch-selection, popover.magnifier {
  background-color: transparent;
}

.osd popover > arrow,
.osd popover > contents, popover.touch-selection > arrow,
popover.touch-selection > contents, popover.magnifier > arrow,
popover.magnifier > contents {
  box-shadow: 0 3px 6px 0 rgba(0, 0, 0, 0.15), 0 0 0 1px rgba(0, 0, 0, 0.75);
  border: 1px solid mix(white,rgba(5, 10, 30, 0.72),0.92);
}

cursor-handle {
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  border-style: none;
}

cursor-handle.top {
  -gtk-icon-source: -gtk-icontheme("selection-start-symbolic");
}

cursor-handle.bottom {
  -gtk-icon-source: -gtk-icontheme("selection-end-symbolic");
}

popover.menu.background, popover.menu.background:backdrop {
  background-color: transparent;
}

popover.menu.suggestions > contents {
  padding: 0;
}

popover.menu box.inline-buttons {
  padding: 0 6px;
}

popover.menu box.inline-buttons button.image-button.model {
  min-height: 28px;
  min-width: 28px;
  padding: 0;
  border: none;
  outline: none;
  transition: none;
}

popover.menu box.inline-buttons button.image-button.model:selected {
  color: #ffffff;
  background-image: image(#5271ad);
}

popover.menu box.circular-buttons {
  padding: 6px;
}

popover.menu box.circular-buttons button.circular.image-button.model {
  padding: 0;
  border: none;
}

popover.menu box.circular-buttons button.circular.image-button.model:focus {
  background-color: rgba(255, 255, 255, 0.1);
}

popover.menu box.circular-buttons button.circular.image-button.model:active:focus {
  color: #ffffff;
  background-color: #5271ad;
}

popover.menu > arrow, popover.menu.background > contents {
  background-color: rgba(10, 18, 46, 0.6);
  color: #e8edf8;
}

popover.menu.background separator {
  margin: 6px 0;
}

popover.menu accelerator {
  color: alpha(currentColor,0.55);
}

popover.menu accelerator:dir(ltr) {
  margin-left: 6px;
}

popover.menu accelerator:dir(rtl) {
  margin-right: 6px;
}

popover.menu arrow.left,
popover.menu radio.left,
popover.menu check.left {
  margin-left: -2px;
  margin-right: 6px;
}

popover.menu arrow.right,
popover.menu radio.right,
popover.menu check.right {
  margin-left: 6px;
  margin-right: -2px;
}

popover.menu modelbutton {
  min-height: 22px;
  min-width: 88px;
  padding: 2px 6px;
  border-radius: 6px;
  transition: none;
  color: #dce4f5;
}

popover.menu modelbutton:focus {
  background-color: transparent;
  color: #e8edf8;
  box-shadow: inset 0 0 0 2px alpha(#e8edf8,0.06);
  transition: none;
}

popover.menu modelbutton:hover {
  color: #ffffff;
  background-color: #5271ad;
  transition: background-color 50ms cubic-bezier(0, 0, 0.2, 1);
}

popover.menu modelbutton:hover arrow {
  color: #ffffff;
}

popover.menu modelbutton:hover:focus {
  color: #ffffff;
  background-color: #5271ad;
  box-shadow: none;
}

popover.menu modelbutton:selected:active {
  color: #ffffff;
  transition: background-color 100ms cubic-bezier(0, 0, 0.2, 1);
  background-color: #4a669c;
}

popover.menu label.title {
  font-weight: bold;
  padding: 3px 26px;
}

notebook > header > tabs > tab {
  color: rgba(160, 180, 220, 0.4);
  background-color: transparent;
  border: none;
  transition: all 150ms ease-out;
  border-radius: 14px;
  padding: 2px 10px;
  margin: 0;
  box-shadow: none;
}

notebook > header > tabs > tab:hover {
  color: rgba(180, 198, 228, 0.6);
  background-color: alpha(currentColor,0.1);
}

notebook > header > tabs > tab:active {
  color: #e8edf8;
  background-color: alpha(currentColor,0.2);
}

notebook > header > tabs > tab:checked, notebook > header > tabs > tab:selected {
  color: #e8edf8;
  background-color: alpha(currentColor,0.12);
  box-shadow: 0 2px 3px rgba(0, 0, 0, 0.08), inset 1px 2px 1px -1px rgba(255, 255, 255, 0.08), inset -1px -1px 1px -1px rgba(255, 255, 255, 0.1);
}

notebook {
  padding: 0;
}

notebook.frame {
  border: 1px solid rgba(255, 255, 255, 0.1);
  border-radius: 19px;
}

notebook > stack:not(:only-child) {
  background-color: rgba(8, 14, 36, 0.42);
  border-radius: 19px;
}

notebook > header {
  border: none;
  color: #dce4f5;
  margin: 3px;
  padding: 2px;
  background-color: alpha(currentColor,0.05);
  border-radius: 16px;
}

notebook > header button.flat.toggle.popup {
  min-width: 32px;
  border: none;
  box-shadow: none;
  border-radius: 9999px;
  min-width: 24px;
  min-height: 24px;
  padding: 2px;
}

notebook > header button.flat.toggle.popup:active, notebook > header button.flat.toggle.popup:checked {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.15);
}

notebook > header.top > tabs {
  margin: 0;
  padding: 0;
}

notebook > header.top > tabs > tab {
  outline-offset: -4px;
  min-width: 24px;
  min-height: 24px;
}

notebook > header.top > tabs > tab + tab {
  margin-left: 3px;
}

notebook > header.bottom > tabs {
  margin: 0;
  padding: 0;
}

notebook > header.bottom > tabs > tab {
  outline-offset: -4px;
  min-width: 24px;
  min-height: 24px;
}

notebook > header.bottom > tabs > tab + tab {
  margin-left: 3px;
}

notebook > header.right > tabs {
  margin: 0;
  padding: 0;
}

notebook > header.right > tabs > tab {
  outline-offset: -4px;
  min-width: 24px;
  min-height: 24px;
}

notebook > header.right > tabs > tab + tab {
  margin-top: 3px;
}

notebook > header.left > tabs {
  margin: 0;
  padding: 0;
}

notebook > header.left > tabs > tab {
  outline-offset: -4px;
  min-width: 24px;
  min-height: 24px;
}

notebook > header.left > tabs > tab + tab {
  margin-top: 3px;
}

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

notebook > header.top > tabs > arrow.up:last-child, notebook > header.bottom > tabs > arrow.up:last-child {
  margin-left: 2px;
}

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

notebook > header.top > tabs > arrow.down:first-child, notebook > header.bottom > tabs > arrow.down:first-child {
  margin-right: 2px;
}

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

notebook > header.left > tabs > arrow.up:last-child, notebook > header.right > tabs > arrow.up:last-child {
  margin-top: 2px;
}

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

notebook > header.left > tabs > arrow.down:first-child, notebook > header.right > tabs > arrow.down:first-child {
  margin-bottom: 2px;
}

notebook > header > tabs > arrow {
  color: rgba(160, 180, 220, 0.4);
}

notebook > header > tabs > arrow:hover {
  color: rgba(180, 198, 228, 0.6);
}

notebook > header > tabs > arrow:active {
  color: #e8edf8;
}

notebook > header > tabs > arrow:disabled {
  color: rgba(162, 171, 188, 0.35);
}

notebook > header > tabs > tab button.flat,
notebook > header > tabs > tab button.close-button,
notebook > header > tabs > tab button.image-button.flat {
  border: none;
  box-shadow: none;
  border-radius: 9999px;
  padding: 0;
  color: rgba(200, 215, 240, 0.85);
  min-height: 16px;
  min-width: 16px;
  margin-top: 4px;
  margin-bottom: 4px;
  margin-left: 3px;
  margin-right: -3px;
}

notebook > header > tabs > tab button.flat:hover,
notebook > header > tabs > tab button.close-button:hover,
notebook > header > tabs > tab button.image-button.flat:hover {
  color: #e8edf8;
  background-color: alpha(#e8edf8,0.1);
}

notebook > header > tabs > tab button.flat:active,
notebook > header > tabs > tab button.close-button:active,
notebook > header > tabs > tab button.image-button.flat:active {
  color: #dce4f5;
  background-color: alpha(#e8edf8,0.2);
}

scrollbar {
  background-color: transparent;
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  outline: none;
}

scrollbar, scrollbar button {
  border: none;
}

scrollbar.vertical button.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

scrollbar.vertical button.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

scrollbar.horizontal button.down {
  -gtk-icon-source: -gtk-icontheme("pan-right-symbolic");
}

scrollbar.horizontal button.up {
  -gtk-icon-source: -gtk-icontheme("pan-left-symbolic");
}

scrollbar > range > trough {
  background: none;
  padding: 0;
  margin: 0;
  border: none;
  outline: none;
  transition: none;
}

scrollbar > range > trough > slider {
  min-width: 10px;
  min-height: 10px;
  margin: 0;
  border: none;
  border-radius: 12px;
  background-clip: padding-box;
  box-shadow: none;
  outline: none;
  transition: all 200ms linear;
  background-color: mix(#e8edf8,rgba(12, 20, 48, 0.52),0.6);
}

scrollbar > range > trough > slider:hover {
  background-color: mix(#e8edf8,rgba(12, 20, 48, 0.52),0.7);
}

scrollbar > range > trough > slider:hover:active {
  background-color: mix(#e8edf8,rgba(12, 20, 48, 0.52),0.5);
}

scrollbar > range > trough > slider:disabled {
  background-color: transparent;
}

scrollbar > range.fine-tune > trough > slider {
  min-width: 4px;
  min-height: 4px;
}

scrollbar.overlay-indicator {
  background: none;
  color: inherit;
  box-shadow: none;
  padding: 0;
}

scrollbar.overlay-indicator > range > trough {
  outline: none;
  background-color: alpha(currentColor,0.1);
  border-radius: 9999px;
  margin: 6px;
}

scrollbar.overlay-indicator > range > trough > slider {
  outline: none;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
  opacity: 0.5;
  border-color: transparent;
  background-color: transparent;
  box-shadow: none;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) > range > trough {
  background-color: transparent;
  border: none;
  margin: 6px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) > range > trough > slider {
  margin: 0;
  min-width: 4px;
  min-height: 4px;
  background-color: mix(#e8edf8,rgba(12, 20, 48, 0.52),0.3);
  border: none;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal > range > trough > slider {
  min-width: 40px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical > range > trough > slider {
  min-height: 40px;
}

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
  opacity: 1;
}

scrollbar.horizontal > range > trough > slider {
  min-width: 40px;
}

scrollbar.vertical > range > trough > slider {
  min-height: 40px;
}

switch {
  transition: all 150ms cubic-bezier(0, 0, 0.2, 1);
  border-radius: 9999px;
  background-color: alpha(#e8edf8,0.06);
  background-clip: padding-box;
  color: #e8edf8;
  min-width: 42px;
  min-height: 18px;
  font-size: 0;
  padding: 0;
  box-shadow: none;
  border: none;
  outline: none;
}

switch:disabled {
  filter: opacity(0.45);
  box-shadow: none;
}

switch:hover {
  background-color: alpha(#e8edf8,0.1);
}

switch:checked {
  background-color: #5271ad;
  box-shadow: none;
  transition: background-color 0.1s, box-shadow 0;
}

switch:checked:hover {
  background-color: mix(white,#5271ad,0.8);
}

switch:checked:active {
  background-color: mix(black,#5271ad,0.85);
}

switch:checked:backdrop {
  background-color: alpha(#e8edf8,0.2);
}

switch > slider {
  transition: all 150ms cubic-bezier(0, 0, 0.2, 1), margin 0;
  min-width: 20px;
  min-height: 14px;
  margin: 2px -6px 2px 2px;
  padding: 0;
  border-radius: 9999px;
  background-color: white;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.15);
  border: none;
}

switch:checked > slider {
  margin: 2px 2px 2px -6px;
  background-color: white;
}

switch:checked:disabled > slider {
  animation: none;
}

switch:active > slider {
  margin: 0 -4px 0 0;
  background-color: transparent;
  box-shadow: inset 1px 2px 1px -1px #5271ad, inset -1px -1px 1px -1px white;
}

switch:checked:active > slider {
  margin: 0 0 0 -4px;
  background-color: rgba(255, 255, 255, 0.25);
  box-shadow: inset 1px 1px 1px -1px white, inset -1px -1px 1px -1px white;
}

switch:disabled > slider {
  box-shadow: none;
}

.view.content-view.check:not(list),
.content-view .tile check:not(list) {
  min-height: 40px;
  min-width: 40px;
  margin: 0;
  padding: 0;
}

checkbutton, radiobutton {
  padding: 2px 0;
}

checkbutton.text-button, radiobutton.text-button {
  padding: 2px 0;
  outline-offset: 0;
}

checkbutton.text-button:hover, radiobutton.text-button:hover {
  color: #e8edf8;
}

checkbutton.text-button:disabled, radiobutton.text-button:disabled {
  color: rgba(160, 180, 220, 0.4);
}

checkbutton label:not(:only-child):first-child, radiobutton label:not(:only-child):first-child {
  margin-left: 4px;
}

checkbutton label:not(:only-child):last-child, radiobutton label:not(:only-child):last-child {
  margin-right: 4px;
}

check,
radio {
  min-width: 14px;
  min-height: 14px;
  margin: 3px;
  padding: 1px;
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.07);
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  background-clip: padding-box;
  border: none;
  box-shadow: none;
  -gtk-icon-size: 14px;
}

check:hover,
radio:hover {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.12);
}

check:active,
radio:active {
  color: #e8edf8;
  background-color: rgba(136, 170, 255, 0.22);
}

check:disabled,
radio:disabled {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.03);
}

check:checked, check:indeterminate,
radio:checked,
radio:indeterminate {
  color: #ffffff;
  background-color: #5271ad;
}

check:checked:hover, check:indeterminate:hover,
radio:checked:hover,
radio:indeterminate:hover {
  background-color: mix(#ffffff,#5271ad,0.75);
}

check:checked:active, check:indeterminate:active,
radio:checked:active,
radio:indeterminate:active {
  background-color: #5271ad;
}

check:checked:disabled, check:indeterminate:disabled,
radio:checked:disabled,
radio:indeterminate:disabled {
  color: rgba(162, 171, 188, 0.35);
  background-color: rgba(255, 255, 255, 0.03);
}


check {
  border-radius: 5px;
}


check:active,
check:checked {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/checkbox-checked-symbolic.svg")), -gtk-recolor(url("assets/scalable/checkbox-checked-symbolic@2.svg")));
}


check:indeterminate {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/checkbox-mixed-symbolic.svg")), -gtk-recolor(url("assets/scalable/checkbox-mixed-symbolic@2.svg")));
}


radio {
  border-radius: 9999px;
}


radio:active,
radio:checked {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/radio-checked-symbolic.svg")), -gtk-recolor(url("assets/scalable/radio-checked-symbolic@2.svg")));
}


radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(-gtk-recolor(url("assets/scalable/radio-mixed-symbolic.svg")), -gtk-recolor(url("assets/scalable/radio-mixed-symbolic@2.svg")));
}

scale {
  min-height: 15px;
  min-width: 15px;
  padding: 12px;
}

scale > trough > slider {
  background-color: #ffffff;
  border: 1px solid rgba(255, 255, 255, 0.12);
  border-radius: 9999px;
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05), 0 3px 8px 0 rgba(0, 0, 0, 0.03);
  background-clip: padding-box;
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-property: background, border;
  outline: none;
}

scale > trough > slider:hover {
  background-color: white;
  border-color: rgba(255, 255, 255, 0.12);
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05), 0 3px 12px 0 rgba(0, 0, 0, 0.1);
}

scale > trough > slider:active {
  background-color: transparent;
  border-color: rgba(255, 255, 255, 0.12);
  box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.03), 0 1px 2px 0 rgba(0, 0, 0, 0.01), inset 1px 2px 1px -1px #5271ad, inset -1px -1px 1px -1px white;
}

scale > trough > slider:disabled {
  background-color: mix(#ffffff,rgba(8, 14, 36, 0.42),0.5);
  border-color: alpha(rgba(255, 255, 255, 0.12),0.5);
  box-shadow: none;
}

scale.horizontal:not(.marks-before):not(.marks-after) > trough > slider {
  margin: -8px;
  min-width: 30px;
  min-height: 20px;
}

scale.horizontal:not(.marks-before):not(.marks-after) > trough > slider:active {
  margin: -11px;
  min-width: 40px;
  min-height: 26px;
  background-image: -gtk-recolor(url("assets/scalable/slider-glass.svg"));
  background-repeat: no-repeat;
  background-size: 40px 26px;
  color: #5271ad;
}

scale.vertical:not(.marks-before):not(.marks-after) > trough > slider {
  margin: -8px;
  min-width: 20px;
  min-height: 30px;
}

scale.vertical:not(.marks-before):not(.marks-after) > trough > slider:active {
  margin: -11px;
  min-width: 26px;
  min-height: 40px;
  background-image: -gtk-recolor(url("assets/scalable/slider-glass-vertical.svg"));
  background-repeat: no-repeat;
  background-size: 26px 40px;
  color: #5271ad;
}

scale > trough {
  outline-offset: 2px;
  border-radius: 9999px;
  background-color: rgba(0, 0, 0, 0.2);
}

scale > trough:disabled {
  background-color: alpha(rgba(0, 0, 0, 0.2),0.65);
}

.osd scale > trough {
  background-color: rgba(0, 0, 0, 0.2);
}

.osd scale > trough highlight {
  background-color: #5271ad;
}

modelbutton:hover scale > trough, row:selected scale > trough, infobar scale > trough {
  background-color: rgba(0, 0, 0, 0.2);
}

modelbutton:hover scale > trough > trough > highlight, row:selected scale > trough > trough > highlight, infobar scale > trough > trough > highlight {
  background-color: #ffffff;
}

modelbutton:hover scale > trough > trough > highlight:disabled, row:selected scale > trough > trough > highlight:disabled, infobar scale > trough > trough > highlight:disabled {
  background-color: alpha(#ffffff,0.5);
}

modelbutton:hover scale > trough:disabled, row:selected scale > trough:disabled, infobar scale > trough:disabled {
  background-color: rgba(0, 0, 0, 0.1);
}

scale > trough > highlight {
  border-radius: 9999px;
  background-color: #5271ad;
}

scale > trough > highlight:hover, scale > trough > highlight:active {
  background-color: #5271ad;
}

scale > trough > highlight:disabled {
  background-color: alpha(#5271ad,0.55);
}

scale > trough > fill {
  border-radius: 9999px;
  background-color: alpha(#5271ad,0.5);
}

scale > trough > fill:disabled {
  background-color: transparent;
}

scale:hover > trough > highlight, scale:active > trough > highlight {
  background-image: none;
}

scale > value {
  color: alpha(currentColor,0.4);
}

scale > marks {
  color: alpha(currentColor,0.4);
}

scale > marks.top {
  margin-bottom: 2px;
  margin-top: -8px;
}

scale > marks.bottom {
  margin-top: 2px;
  margin-bottom: -8px;
}

scale > marks.top {
  margin-right: 2px;
  margin-left: -8px;
}

scale > marks.bottom {
  margin-left: 2px;
  margin-right: -8px;
}

scale.fine-tune > marks.top {
  margin-bottom: 1px;
  margin-top: -6px;
}

scale.fine-tune > marks.bottom {
  margin-top: 1px;
  margin-bottom: -6px;
}

scale.fine-tune > marks.top {
  margin-right: 1px;
  margin-left: -6px;
}

scale.fine-tune > marks.bottom {
  margin-left: 1px;
  margin-right: -6px;
}

scale.horizontal indicator {
  min-height: 6px;
  min-width: 1px;
}

scale.horizontal.fine-tune indicator {
  min-height: 5px;
}

scale.vertical indicator {
  min-height: 1px;
  min-width: 6px;
}

scale.vertical.fine-tune indicator {
  min-width: 5px;
}

scale.horizontal.marks-before:not(.marks-after) slider {
  transform: none;
}

scale.horizontal.marks-before:not(.marks-after) slider {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above.png"), url("assets/slider-horz-scale-has-marks-above@2.png"));
  min-height: 26px;
  min-width: 24px;
  margin-top: -14px;
  background-position: top;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-top: -11px;
}

scale.horizontal.marks-before:not(.marks-after) slider {
  transform: none;
}

scale.horizontal.marks-before:not(.marks-after) slider:hover {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-hover.png"), url("assets/slider-horz-scale-has-marks-above-hover@2.png"));
  min-height: 26px;
  min-width: 24px;
  margin-top: -14px;
  background-position: top;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-top: -11px;
}

scale.horizontal.marks-before:not(.marks-after) slider {
  transform: none;
}

scale.horizontal.marks-before:not(.marks-after) slider:active {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-active.png"), url("assets/slider-horz-scale-has-marks-above-active@2.png"));
  min-height: 26px;
  min-width: 24px;
  margin-top: -14px;
  background-position: top;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-top: -11px;
}

scale.horizontal.marks-before:not(.marks-after) slider {
  transform: none;
}

scale.horizontal.marks-before:not(.marks-after) slider:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-insensitive.png"), url("assets/slider-horz-scale-has-marks-above-insensitive@2.png"));
  min-height: 26px;
  min-width: 24px;
  margin-top: -14px;
  background-position: top;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-top: -11px;
}

scale.horizontal.marks-after:not(.marks-before) slider {
  transform: none;
}

scale.horizontal.marks-after:not(.marks-before) slider {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below.png"), url("assets/slider-horz-scale-has-marks-below@2.png"));
  min-height: 26px;
  min-width: 24px;
  margin-bottom: -14px;
  background-position: bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-bottom: -11px;
}

scale.horizontal.marks-after:not(.marks-before) slider {
  transform: none;
}

scale.horizontal.marks-after:not(.marks-before) slider:hover {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-hover.png"), url("assets/slider-horz-scale-has-marks-below-hover@2.png"));
  min-height: 26px;
  min-width: 24px;
  margin-bottom: -14px;
  background-position: bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-bottom: -11px;
}

scale.horizontal.marks-after:not(.marks-before) slider {
  transform: none;
}

scale.horizontal.marks-after:not(.marks-before) slider:active {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-active.png"), url("assets/slider-horz-scale-has-marks-below-active@2.png"));
  min-height: 26px;
  min-width: 24px;
  margin-bottom: -14px;
  background-position: bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-bottom: -11px;
}

scale.horizontal.marks-after:not(.marks-before) slider {
  transform: none;
}

scale.horizontal.marks-after:not(.marks-before) slider:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-insensitive.png"), url("assets/slider-horz-scale-has-marks-below-insensitive@2.png"));
  min-height: 26px;
  min-width: 24px;
  margin-bottom: -14px;
  background-position: bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-bottom: -11px;
}

scale.vertical.marks-before:not(.marks-after) slider {
  transform: none;
}

scale.vertical.marks-before:not(.marks-after) slider {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above.png"), url("assets/slider-vert-scale-has-marks-above@2.png"));
  min-height: 24px;
  min-width: 26px;
  margin-left: -14px;
  background-position: left bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-left: -11px;
}

scale.vertical.marks-before:not(.marks-after) slider {
  transform: none;
}

scale.vertical.marks-before:not(.marks-after) slider:hover {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-hover.png"), url("assets/slider-vert-scale-has-marks-above-hover@2.png"));
  min-height: 24px;
  min-width: 26px;
  margin-left: -14px;
  background-position: left bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-left: -11px;
}

scale.vertical.marks-before:not(.marks-after) slider {
  transform: none;
}

scale.vertical.marks-before:not(.marks-after) slider:active {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-active.png"), url("assets/slider-vert-scale-has-marks-above-active@2.png"));
  min-height: 24px;
  min-width: 26px;
  margin-left: -14px;
  background-position: left bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-left: -11px;
}

scale.vertical.marks-before:not(.marks-after) slider {
  transform: none;
}

scale.vertical.marks-before:not(.marks-after) slider:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-insensitive.png"), url("assets/slider-vert-scale-has-marks-above-insensitive@2.png"));
  min-height: 24px;
  min-width: 26px;
  margin-left: -14px;
  background-position: left bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-before:not(.marks-after).fine-tune slider {
  margin: -7px;
  margin-left: -11px;
}

scale.vertical.marks-after:not(.marks-before) slider {
  transform: none;
}

scale.vertical.marks-after:not(.marks-before) slider {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below.png"), url("assets/slider-vert-scale-has-marks-below@2.png"));
  min-height: 24px;
  min-width: 26px;
  margin-right: -14px;
  background-position: right bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-right: -11px;
}

scale.vertical.marks-after:not(.marks-before) slider {
  transform: none;
}

scale.vertical.marks-after:not(.marks-before) slider:hover {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-hover.png"), url("assets/slider-vert-scale-has-marks-below-hover@2.png"));
  min-height: 24px;
  min-width: 26px;
  margin-right: -14px;
  background-position: right bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-right: -11px;
}

scale.vertical.marks-after:not(.marks-before) slider {
  transform: none;
}

scale.vertical.marks-after:not(.marks-before) slider:active {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-active.png"), url("assets/slider-vert-scale-has-marks-below-active@2.png"));
  min-height: 24px;
  min-width: 26px;
  margin-right: -14px;
  background-position: right bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-right: -11px;
}

scale.vertical.marks-after:not(.marks-before) slider {
  transform: none;
}

scale.vertical.marks-after:not(.marks-before) slider:disabled {
  margin: -10px;
  border-style: none;
  border-radius: 0;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-insensitive.png"), url("assets/slider-vert-scale-has-marks-below-insensitive@2.png"));
  min-height: 24px;
  min-width: 26px;
  margin-right: -14px;
  background-position: right bottom;
  background-repeat: no-repeat;
  box-shadow: none;
}

scale.vertical.marks-after:not(.marks-before).fine-tune slider {
  margin: -7px;
  margin-right: -11px;
}

progressbar {
  padding: 0;
  font-size: smaller;
  color: alpha(#e8edf8,0.7);
  font-feature-settings: "tnum";
}

progressbar.horizontal > trough {
  min-width: 150px;
}

progressbar.horizontal > trough, progressbar.horizontal > trough > progress {
  min-height: 4px;
  border-radius: 2px;
}

progressbar.vertical > trough {
  min-height: 80px;
}

progressbar.vertical > trough, progressbar.vertical > trough > progress {
  min-width: 4px;
  border-radius: 2px;
}

progressbar.osd {
  min-width: 3px;
  min-height: 3px;
  background-color: transparent;
  box-shadow: none;
  border: none;
  margin: 0;
  padding: 0;
}

progressbar.osd > trough {
  border-style: none;
  background-color: transparent;
  box-shadow: none;
}

progressbar.osd > progress {
  border-style: none;
  border-radius: 0;
}

progressbar > trough > progress {
  background-color: #5271ad;
  border: none;
  border-radius: 6px;
  box-shadow: none;
}

row:selected progressbar > trough > progress, infobar progressbar > trough > progress {
  background-color: #ffffff;
}

progressbar > trough {
  min-height: 4px;
  min-width: 4px;
  border: none;
  border-radius: 6px;
  background-color: rgba(0, 0, 0, 0.2);
}

row:selected progressbar > trough, infobar progressbar > trough {
  background-color: rgba(0, 0, 0, 0.2);
}

levelbar block {
  min-width: 32px;
  min-height: 1px;
}

levelbar.vertical block {
  min-width: 1px;
  min-height: 32px;
}

levelbar trough {
  border: none;
  padding: 3px;
  border-radius: 6px;
  background-color: rgba(0, 0, 0, 0.2);
}

levelbar.horizontal.discrete block {
  margin: 0 1px;
}

levelbar.vertical.discrete block {
  margin: 1px 0;
}

levelbar block:not(.empty) {
  border: 1px solid #5271ad;
  background-color: #5271ad;
  border-radius: 6px;
}

levelbar block.low {
  border-color: #d0846c;
  background-color: #d0846c;
}

levelbar block.high {
  border-color: #5271ad;
  background-color: #5271ad;
}

levelbar block.full {
  border-color: #82ac5d;
  background-color: #82ac5d;
}

levelbar block.empty {
  background-color: rgba(8, 14, 36, 0.42);
  border-color: rgba(8, 14, 36, 0.42);
}

window.dialog.print drawing {
  color: #e8edf8;
  background: none;
  border: none;
  padding: 0;
}

window.dialog.print drawing paper {
  border: 1px solid rgba(255, 255, 255, 0.13);
  background: rgba(8, 14, 36, 0.42);
  padding: 0;
}

window.dialog.print .dialog-action-box {
  margin: 12px;
}

frame,
.frame {
  border: 1px solid rgba(255, 255, 255, 0.13);
}

frame > list,
.frame > list {
  border: none;
}

frame {
  border-radius: 12px;
}

frame > label {
  margin: 4px;
}

frame > list {
  border-radius: 10px;
  box-shadow: none;
}

scrolledwindow viewport.frame {
  border: none;
}

scrolledwindow viewport.frame .frame {
  border: none;
}

scrolledwindow viewport.frame .frame > textview {
  border-radius: 6px;
  background: none;
}

scrolledwindow viewport.frame .frame > textview > text {
  border-radius: 6px;
  border: 1px solid rgba(255, 255, 255, 0.13);
}

scrolledwindow > overshoot.top {
  background-image: radial-gradient(farthest-side at top, alpha(currentColor,0.12) 85%, alpha(currentColor,0)), radial-gradient(farthest-side at top, alpha(currentColor,0.05), alpha(currentColor,0));
  background-size: 100% 3%, 100% 50%;
  background-repeat: no-repeat;
  background-position: top;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > overshoot.bottom {
  background-image: radial-gradient(farthest-side at bottom, alpha(currentColor,0.12) 85%, alpha(currentColor,0)), radial-gradient(farthest-side at bottom, alpha(currentColor,0.05), alpha(currentColor,0));
  background-size: 100% 3%, 100% 50%;
  background-repeat: no-repeat;
  background-position: bottom;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > overshoot.left {
  background-image: radial-gradient(farthest-side at left, alpha(currentColor,0.12) 85%, alpha(currentColor,0)), radial-gradient(farthest-side at left, alpha(currentColor,0.05), alpha(currentColor,0));
  background-size: 3% 100%, 50% 100%;
  background-repeat: no-repeat;
  background-position: left;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > overshoot.right {
  background-image: radial-gradient(farthest-side at right, alpha(currentColor,0.12) 85%, alpha(currentColor,0)), radial-gradient(farthest-side at right, alpha(currentColor,0.05), alpha(currentColor,0));
  background-size: 3% 100%, 50% 100%;
  background-repeat: no-repeat;
  background-position: right;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow > undershoot {
  background: none;
  border: none;
  padding: 0;
}

scrolledwindow.undershoot-top > undershoot.top {
  box-shadow: none;
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

scrolledwindow.undershoot-bottom > undershoot.bottom {
  box-shadow: none;
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

scrolledwindow.undershoot-start:dir(ltr) > undershoot.left {
  box-shadow: none;
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

scrolledwindow.undershoot-start:dir(rtl) > undershoot.right {
  box-shadow: none;
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

scrolledwindow.undershoot-end:dir(ltr) > undershoot.right {
  box-shadow: none;
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

scrolledwindow.undershoot-end:dir(rtl) > undershoot.left {
  box-shadow: none;
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

scrolledwindow > junction {
  border: none;
  background-color: alpha(currentColor,0.05);
}

separator {
  background-color: rgba(255, 255, 255, 0.13);
  min-width: 1px;
  min-height: 1px;
}

separator.spacer {
  background: none;
}

separator.spacer.horizontal {
  min-width: 12px;
}

separator.spacer.vertical {
  min-height: 12px;
}

.card, list.boxed-list-separate, list.boxed-list, listview.content:not(.conversation-listbox),
list.content:not(.conversation-listbox) {
  border-radius: 12px;
  box-shadow: inset 0 0 8px rgba(0, 0, 0, 0.03);
  background-color: rgba(0, 0, 0, 0.12);
  border: 1px solid rgba(0, 0, 0, 0.15);
  color: #dce4f5;
  background-clip: border-box;
}

.card > separator, list.boxed-list-separate > separator, list.boxed-list > separator, listview.content:not(.conversation-listbox) > separator,
list.content:not(.conversation-listbox) > separator {
  min-height: 0;
  background-color: transparent;
}

list.boxed-list-separate > row, listview.content:not(.conversation-listbox) > row,
list.content:not(.conversation-listbox) > row {
  border: none;
}

list.boxed-list-separate > row:first-child, listview.content:not(.conversation-listbox) > row:first-child,
list.content:not(.conversation-listbox) > row:first-child {
  border-top-left-radius: 13px;
  border-top-right-radius: 13px;
}

list.boxed-list-separate > row:last-child, listview.content:not(.conversation-listbox) > row:last-child,
list.content:not(.conversation-listbox) > row:last-child {
  border-bottom-left-radius: 13px;
  border-bottom-right-radius: 13px;
}

list.boxed-list-separate > row:only-child, listview.content:not(.conversation-listbox) > row:only-child,
list.content:not(.conversation-listbox) > row:only-child {
  border-radius: 13px;
}

list.boxed-list-separate > row + row, listview.content:not(.conversation-listbox) > row + row,
list.content:not(.conversation-listbox) > row + row {
  border-top: 1px solid transparent;
  border-image: linear-gradient(to right, transparent 0%, transparent 2%, rgba(255, 255, 255, 0.05) 2%, rgba(255, 255, 255, 0.05) 98%, transparent 98%, transparent 100%) 1 0 0 0/1px 0 0 0 stretch;
}

list.boxed-list-separate > row:hover, listview.content:not(.conversation-listbox) > row:hover,
list.content:not(.conversation-listbox) > row:hover, list.boxed-list-separate > row:hover + row, listview.content:not(.conversation-listbox) > row:hover + row,
list.content:not(.conversation-listbox) > row:hover + row, list.boxed-list-separate > row:active, listview.content:not(.conversation-listbox) > row:active,
list.content:not(.conversation-listbox) > row:active, list.boxed-list-separate > row:active + row, listview.content:not(.conversation-listbox) > row:active + row,
list.content:not(.conversation-listbox) > row:active + row, list.boxed-list-separate > row:selected, listview.content:not(.conversation-listbox) > row:selected,
list.content:not(.conversation-listbox) > row:selected, list.boxed-list-separate > row:selected + row, listview.content:not(.conversation-listbox) > row:selected + row,
list.content:not(.conversation-listbox) > row:selected + row {
  border-image: none;
}

listview,
list {
  background-color: rgba(8, 14, 36, 0.42);
  border-color: rgba(255, 255, 255, 0.13);
  background-clip: padding-box;
  color: #e8edf8;
}

listview > row,
list > row {
  background-clip: padding-box;
}

listview > row.expander,
list > row.expander {
  padding: 0;
}

listview > row.expander .row-header,
list > row.expander .row-header {
  padding: 3px;
}

listview.horizontal row.separator, listview.separators.horizontal > row:not(.separator),
list.horizontal row.separator,
list.separators.horizontal > row:not(.separator) {
  border-left: 1px solid rgba(255, 255, 255, 0.13);
}

listview:not(.horizontal) row.separator, listview.separators:not(.horizontal) > row:not(.separator),
list:not(.horizontal) row.separator,
list.separators:not(.horizontal) > row:not(.separator) {
  border-bottom: 1px solid rgba(255, 255, 255, 0.13);
}

listview.view {
  color: #e8edf8;
  background-color: transparent;
}

row.has-open-popup.activatable, row.activatable:hover {
  background-color: alpha(currentColor,0.05);
}

row.activatable:active {
  color: #e8edf8;
  background-color: alpha(currentColor,0.16);
  transition-duration: 200ms;
}

row.activatable:disabled {
  color: rgba(160, 180, 220, 0.4);
}

row.activatable:disabled image {
  color: inherit;
}

row.activatable:selected {
  color: #e8edf8;
  background-color: alpha(currentColor,0.12);
}

row.activatable:selected.has-open-popup, row.activatable:selected:hover {
  background-color: alpha(currentColor,0.16);
}

row {
  background-clip: padding-box;
}

row label.subtitle {
  font-size: smaller;
}

row > box.header {
  margin-left: 12px;
  margin-right: 12px;
  min-height: 44px;
}

row > box.header > .icon:disabled {
  filter: opacity(0.45);
}

row > box.header > box.title {
  margin-top: 6px;
  margin-bottom: 6px;
  border-spacing: 3px;
}

row:not(:hover) {
  transition: all 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

button row.activatable:focus, button row.activatable:hover, button row.activatable:active {
  background: none;
}

row:selected {
  color: #e8edf8;
  background-color: alpha(currentColor,0.12);
}

row.combo image.dropdown-arrow:disabled {
  filter: opacity(0.45);
}

row.combo listview.inline {
  background: none;
  border: none;
  box-shadow: none;
  color: inherit;
}

row.combo listview.inline, row.combo listview.inline:disabled {
  background: none;
  color: inherit;
}

row.combo popover > contents {
  min-width: 120px;
}

columnview > listview > row {
  padding: 0;
}

columnview > listview > row > cell {
  padding: 8px 6px;
}

columnview > listview > row > cell:not(:first-child) {
  border-left: 1px solid transparent;
}

columnview.column-separators > listview > row > cell {
  border-left-color: rgba(255, 255, 255, 0.13);
}

columnview.data-table > listview > row > cell {
  padding-top: 2px;
  padding-bottom: 2px;
}

treeexpander {
  border-spacing: 6px;
}

columnview row:not(:selected) cell editablelabel:not(.editing):focus-within {
  outline: 2px solid rgba(255, 255, 255, 0.13);
}

columnview row:not(:selected) cell editablelabel.editing:focus-within {
  outline: 2px solid #5271ad;
}

columnview row:not(:selected) cell editablelabel.editing text selection {
  color: #ffffff;
  background-color: #5271ad;
}

.rich-list {
  /* rich lists usually containing other widgets than just labels/text */
}

.rich-list > row {
  padding: 8px 12px;
  min-height: 32px;
  /* should be tall even when only containing a label */
}

.rich-list > row > box {
  border-spacing: 12px;
}

.rich-list > header {
  padding-left: 12px;
  padding-right: 12px;
}

/****************
 * AdwActionRow *
 ****************/
row label.subtitle {
  font-size: smaller;
}

row > box.header {
  margin-left: 12px;
  margin-right: 12px;
  border-spacing: 6px;
  min-height: 50px;
}

row > box.header > .icon:disabled {
  filter: opacity(0.45);
}

row > box.header > box.title {
  margin-top: 6px;
  margin-bottom: 6px;
  border-spacing: 3px;
  padding: 0;
}

row > box.header > box.title,
row > box.header > box.title > .title,
row > box.header > box.title > .subtitle {
  padding: 0;
  font-weight: inherit;
}

row > box.header > .prefixes,
row > box.header > .suffixes {
  border-spacing: 6px;
}

row > box.header > .icon:dir(ltr),
row > box.header > .prefixes:dir(ltr) {
  margin-right: 6px;
}

row > box.header > .icon:dir(rtl),
row > box.header > .prefixes:dir(rtl) {
  margin-left: 6px;
}

row.property > box.header > box.title > .title, row.expander.property box > list > row > box.header > box.title > .title {
  font-size: smaller;
}

row.property > box.header > box.title > .subtitle, row.expander.property box > list > row > box.header > box.title > .subtitle {
  font-size: inherit;
  opacity: 1;
}

row.property.monospace, row.expander.property box > list > row.monospace {
  font-family: inherit;
}

row.property.monospace > box.header > box.title > .subtitle, row.expander.property box > list > row.monospace > box.header > box.title > .subtitle {
  font-family: monospace;
}

/******************************
 * AdwEntryRow and AdwSpinRow *
 ******************************/
row.entry:disabled text {
  opacity: 0.45;
}

row.entry:disabled .dim-label, row.entry:disabled row.expander image.expander-row-arrow, row.expander row.entry:disabled image.expander-row-arrow, row.entry:disabled entry > text:disabled,
row.entry:disabled entry > text > placeholder, row.entry:disabled row.property > box.header > box.title > .title, row.entry:disabled row.expander.property box > list > row > box.header > box.title > .title, row.expander.property row.entry:disabled box > list > row > box.header > box.title > .title, row.entry:disabled .subtitle {
  opacity: 1;
}

row.entry .edit-icon, row.entry .indicator {
  min-width: 24px;
  min-height: 24px;
  padding: 5px;
}

row.entry .edit-icon:disabled {
  opacity: 0.45;
}

row.entry .indicator {
  opacity: 0.6;
}

row.entry.monospace {
  font-family: inherit;
}

row.entry.monospace text {
  font-family: monospace;
}

row.spin spinbutton {
  border-spacing: 6px;
}

row.spin spinbutton, row.spin spinbutton:focus, row.spin spinbutton:focus-within, row.spin spinbutton:hover, row.spin spinbutton:active {
  outline: none;
  box-shadow: none;
  background: none;
}

row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque),
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child,
row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child {
  min-width: 30px;
  min-height: 30px;
  margin: 10px 2px;
  border: none;
}

row.spin:disabled spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:disabled, row.spin:disabled spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child:disabled, row.spin:disabled spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child:disabled,
row.spin:disabled spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled,
row.spin:disabled spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child:disabled,
row.spin:disabled spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child:disabled {
  filter: none;
}

row.entry,
row.spin {
  outline: none;
}

row.entry:not(:selected).activatable.focused:hover, row.entry:not(:selected).activatable.focused:active,
row.spin:not(:selected).activatable.focused:hover,
row.spin:not(:selected).activatable.focused:active {
  background-color: transparent;
}

row.entry.error,
row.spin.error {
  color: #5271ad;
}

row.entry.error .dim-label, row.entry.error row.expander image.expander-row-arrow, row.expander row.entry.error image.expander-row-arrow, row.entry.error entry > text:disabled,
row.entry.error entry > text > placeholder, row.entry.error row.property > box.header > box.title > .title, row.entry.error row.expander.property box > list > row > box.header > box.title > .title, row.expander.property row.entry.error box > list > row > box.header > box.title > .title, row.entry.error .subtitle,
row.spin.error .dim-label,
row.spin.error row.expander image.expander-row-arrow,
row.expander row.spin.error image.expander-row-arrow,
row.spin.error entry > text:disabled,
row.spin.error entry > text > placeholder,
row.spin.error row.property > box.header > box.title > .title,
row.spin.error row.expander.property box > list > row > box.header > box.title > .title,
row.expander.property row.spin.error box > list > row > box.header > box.title > .title,
row.spin.error .subtitle {
  opacity: 1;
}

row.entry.warning,
row.spin.warning {
  color: #5271ad;
}

row.entry.warning .dim-label, row.entry.warning row.expander image.expander-row-arrow, row.expander row.entry.warning image.expander-row-arrow, row.entry.warning entry > text:disabled,
row.entry.warning entry > text > placeholder, row.entry.warning row.property > box.header > box.title > .title, row.entry.warning row.expander.property box > list > row > box.header > box.title > .title, row.expander.property row.entry.warning box > list > row > box.header > box.title > .title, row.entry.warning .subtitle,
row.spin.warning .dim-label,
row.spin.warning row.expander image.expander-row-arrow,
row.expander row.spin.warning image.expander-row-arrow,
row.spin.warning entry > text:disabled,
row.spin.warning entry > text > placeholder,
row.spin.warning row.property > box.header > box.title > .title,
row.spin.warning row.expander.property box > list > row > box.header > box.title > .title,
row.expander.property row.spin.warning box > list > row > box.header > box.title > .title,
row.spin.warning .subtitle {
  opacity: 1;
}

row.entry.success,
row.spin.success {
  color: #5271ad;
}

row.entry.success .dim-label, row.entry.success row.expander image.expander-row-arrow, row.expander row.entry.success image.expander-row-arrow, row.entry.success entry > text:disabled,
row.entry.success entry > text > placeholder, row.entry.success row.property > box.header > box.title > .title, row.entry.success row.expander.property box > list > row > box.header > box.title > .title, row.expander.property row.entry.success box > list > row > box.header > box.title > .title, row.entry.success .subtitle,
row.spin.success .dim-label,
row.spin.success row.expander image.expander-row-arrow,
row.expander row.spin.success image.expander-row-arrow,
row.spin.success entry > text:disabled,
row.spin.success entry > text > placeholder,
row.spin.success row.property > box.header > box.title > .title,
row.spin.success row.expander.property box > list > row > box.header > box.title > .title,
row.expander.property row.spin.success box > list > row > box.header > box.title > .title,
row.spin.success .subtitle {
  opacity: 1;
}

/***************
 * AdwComboRow *
 ***************/
row.combo image.dropdown-arrow:disabled {
  filter: opacity(0.45);
}

row.combo listview.inline {
  background: none;
  border: none;
  box-shadow: none;
  color: inherit;
}

row.combo listview.inline, row.combo listview.inline:disabled {
  background: none;
  color: inherit;
}

row.combo popover > contents {
  min-width: 120px;
}

row.combo popover > contents .combo-searchbar {
  margin: 6px;
}

row.combo popover > contents .combo-searchbar + scrolledwindow > undershoot.top {
  box-shadow: none;
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

/******************
 * AdwExpanderRow *
 ******************/
row.expander {
  background: none;
  padding: 0px;
}

row.expander > box > list {
  background: none;
  color: inherit;
}

row.expander list.nested {
  background-color: alpha(rgba(8, 14, 36, 0.42),0.5);
  color: inherit;
}

row.expander image.expander-row-arrow {
  transition: -gtk-icon-transform 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

row.expander image.expander-row-arrow:dir(ltr) {
  margin-left: 3px;
}

row.expander image.expander-row-arrow:dir(rtl) {
  margin-right: 3px;
}

row.expander image.expander-row-arrow:dir(ltr) {
  -gtk-icon-transform: rotate(0.5turn);
}

row.expander image.expander-row-arrow:dir(rtl) {
  -gtk-icon-transform: rotate(-0.5turn);
}

row.expander image.expander-row-arrow:disabled {
  filter: opacity(0.45);
}

row.expander:checked image.expander-row-arrow {
  -gtk-icon-transform: rotate(0turn);
  opacity: 1;
}

row.expander:checked image.expander-row-arrow:not(:disabled) {
  color: #5271ad;
}

.osd row.expander:checked image.expander-row-arrow:not(:disabled) {
  color: inherit;
}

/***************
 * AdwButtonRow *
 ***************/
row.button > box {
  margin-left: 12px;
  margin-right: 12px;
  border-spacing: 6px;
  min-height: 42px;
}

row.button > box > .icon:disabled {
  filter: opacity(0.45);
}

/*****************
 * Boxed Lists *
 *****************/
list.boxed-list-separate > row.expander row.header, list.boxed-list-separate > row, list.boxed-list > row, list.boxed-list > row.expander row.header, row.expander list.nested > row {
  outline: none;
  border: none;
}

list.boxed-list-separate > row.expander row.has-open-popup.header, list.boxed-list-separate > row.has-open-popup, list.boxed-list > row.has-open-popup, list.boxed-list > row.expander row.has-open-popup.header, row.expander list.nested > row.has-open-popup, list.boxed-list-separate > row.expander row.header:hover, list.boxed-list-separate > row:hover, list.boxed-list > row:hover, list.boxed-list > row.expander row.header:hover, row.expander list.nested > row:hover {
  background-color: alpha(currentColor,0.05);
}

list.boxed-list-separate > row.expander row.header:active, list.boxed-list-separate > row:active, list.boxed-list > row:active, list.boxed-list > row.expander row.header:active, row.expander list.nested > row:active {
  color: #e8edf8;
  background-color: alpha(currentColor,0.16);
  transition-duration: 200ms;
}

list.boxed-list-separate > row.expander row.header:disabled, list.boxed-list-separate > row:disabled, list.boxed-list > row:disabled, list.boxed-list > row.expander row.header:disabled, row.expander list.nested > row:disabled {
  color: rgba(160, 180, 220, 0.4);
}

list.boxed-list-separate > row.expander row.header:disabled image, list.boxed-list-separate > row:disabled image, list.boxed-list > row:disabled image, list.boxed-list > row.expander row.header:disabled image, row.expander list.nested > row:disabled image {
  color: inherit;
}

list.boxed-list-separate > row.expander row.header:selected, list.boxed-list-separate > row:selected, list.boxed-list > row:selected, list.boxed-list > row.expander row.header:selected, row.expander list.nested > row:selected {
  color: #e8edf8;
  background-color: alpha(currentColor,0.12);
}

list.boxed-list-separate > row.expander row.header:selected.has-open-popup, list.boxed-list-separate > row:selected.has-open-popup, list.boxed-list > row:selected.has-open-popup, list.boxed-list > row.expander row.header:selected.has-open-popup, row.expander list.nested > row:selected.has-open-popup, list.boxed-list-separate > row.expander row.header:selected:hover, list.boxed-list-separate > row:selected:hover, list.boxed-list > row:selected:hover, list.boxed-list > row.expander row.header:selected:hover, row.expander list.nested > row:selected:hover {
  background-color: alpha(currentColor,0.16);
}

list.boxed-list-separate > row.expander row.header + row, list.boxed-list-separate > row + row, list.boxed-list > row + row, list.boxed-list > row.expander row.header + row, row.expander list.nested > row + row {
  border-top: 1px solid transparent;
  border-image: linear-gradient(to right, transparent 0%, transparent 2%, rgba(255, 255, 255, 0.05) 2%, rgba(255, 255, 255, 0.05) 98%, transparent 98%, transparent 100%) 1 0 0 0/1px 0 0 0 stretch;
}

list.boxed-list-separate > row.expander row.header:hover, list.boxed-list-separate > row:hover, list.boxed-list > row:hover, list.boxed-list > row.expander row.header:hover, row.expander list.nested > row:hover, list.boxed-list-separate > row.expander row.header:hover + row, list.boxed-list-separate > row:hover + row, list.boxed-list > row:hover + row, list.boxed-list > row.expander row.header:hover + row, row.expander list.nested > row:hover + row, list.boxed-list-separate > row.expander row.header:active, list.boxed-list-separate > row:active, list.boxed-list > row:active, list.boxed-list > row.expander row.header:active, row.expander list.nested > row:active, list.boxed-list-separate > row.expander row.header:active + row, list.boxed-list-separate > row:active + row, list.boxed-list > row:active + row, list.boxed-list > row.expander row.header:active + row, row.expander list.nested > row:active + row, list.boxed-list-separate > row.expander row.header:selected, list.boxed-list-separate > row:selected, list.boxed-list > row:selected, list.boxed-list > row.expander row.header:selected, row.expander list.nested > row:selected, list.boxed-list-separate > row.expander row.header:selected + row, list.boxed-list-separate > row:selected + row, list.boxed-list > row:selected + row, list.boxed-list > row.expander row.header:selected + row, row.expander list.nested > row:selected + row {
  border-image: none;
}

list.boxed-list > row.expander {
  border: none;
}

list.boxed-list > row:first-child, list.boxed-list > row:first-child.expander row.header {
  border-top-left-radius: 12px;
  border-top-right-radius: 12px;
}

list.boxed-list > row:last-child, list.boxed-list > row:last-child.expander:not(:checked), list.boxed-list > row:last-child.expander:not(:checked) row.header, list.boxed-list > row:last-child.expander:checked list.nested, list.boxed-list > row:last-child.expander:checked list.nested > row:last-child {
  border-bottom-left-radius: 12px;
  border-bottom-right-radius: 12px;
  border-bottom-width: 0;
}

list.boxed-list-separate {
  color: #e8edf8;
}

list.boxed-list-separate > row {
  border: none;
  margin-bottom: 12px;
  outline: none;
  box-shadow: none;
  background-color: transparent;
}

list.boxed-list-separate > row:selected {
  background-color: alpha(currentColor,0.12);
}

list.boxed-list-separate > row:last-child {
  margin-bottom: 0;
}

list.boxed-list-separate > row:not(.expander):not(:selected).activatable:hover {
  background-color: rgba(8, 14, 36, 0.42);
  background-image: image(alpha(currentColor,0.03));
}

list.boxed-list-separate > row:not(.expander):not(:selected).activatable:active {
  background-color: rgba(8, 14, 36, 0.42);
  background-image: image(alpha(currentColor,0.08));
}

list.boxed-list-separate > row:not(.expander):not(:selected).activatable.has-open-popup {
  background-color: rgba(8, 14, 36, 0.42);
  background-image: image(alpha(currentColor,0.03));
}

list.boxed-list-separate > row.entry:not(:selected).activatable.focused:hover, list.boxed-list-separate > row.entry:not(:selected).activatable.focused:active, list.boxed-list-separate > row.spin:not(:selected).activatable.focused:hover, list.boxed-list-separate > row.spin:not(:selected).activatable.focused:active {
  background-color: rgba(8, 14, 36, 0.42);
  background-image: none;
}

list.boxed-list-separate > row.expander row.header {
  border-top-left-radius: 12px;
  border-top-right-radius: 12px;
}

list.boxed-list-separate > row.expander:not(:checked) row.header, list.boxed-list-separate > row.expander.expander:checked list.nested, list.boxed-list-separate > row.expander.expander:checked list.nested > row:last-child {
  border-bottom-left-radius: 12px;
  border-bottom-right-radius: 12px;
  border-bottom: none;
}

.app-notification {
  padding: 6px;
  margin: 6px 16px 16px 16px;
  color: #e8edf8;
  background-color: rgba(10, 18, 46, 0.6);
  border-radius: 12px;
  border: none;
  box-shadow: 0 5px 15px 0 rgba(0, 0, 0, 0.25), inset 0 0 0 1px rgba(255, 255, 255, 0.06), 0 0 0 1px rgba(0, 0, 0, 0.75);
}

.app-notification border {
  border: none;
}

.app-notification button {
  min-height: 22px;
  padding: 2px 8px;
}

.app-notification button:hover {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.12);
}

.app-notification button:active, .app-notification button:checked {
  color: #e8edf8;
  background-color: rgba(136, 170, 255, 0.22);
}

.app-notification button:disabled {
  color: rgba(160, 180, 220, 0.4);
  background-color: transparent;
}

expander {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

expander:hover {
  color: rgba(200, 215, 240, 0.85);
}

expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

expander:disabled {
  filter: opacity(0.45);
}

expander-widget > box > title {
  border-radius: 6px;
}

expander-widget > box > title > expander {
  opacity: .7;
}

expander-widget > box > title:hover > expander {
  opacity: 1;
}

.navigation-sidebar:not(decoration):not(window):drop(active):focus, .navigation-sidebar:not(decoration):not(window):drop(active),
placessidebar:not(decoration):not(window):drop(active):focus,
placessidebar:not(decoration):not(window):drop(active),
stackswitcher:not(decoration):not(window):drop(active):focus,
stackswitcher:not(decoration):not(window):drop(active),
expander-widget:not(decoration):not(window):drop(active):focus,
expander-widget:not(decoration):not(window):drop(active) {
  box-shadow: none;
}


calendar {
  color: #e8edf8;
  border: 1px solid rgba(255, 255, 255, 0.13);
  border-radius: 6px;
  padding: 2px 6px;
  margin: 0;
}


calendar > header {
  color: #e8edf8;
  border-bottom: 1px solid rgba(255, 255, 255, 0.13);
}


calendar > header > button {
  border: none;
  box-shadow: none;
  background: none;
  border-radius: 0;
}


calendar > header > button:hover {
  background-color: alpha(#e8edf8,0.1);
}


calendar > header > button:active {
  background-color: #5271ad;
}


calendar > header > button:backdrop {
  background: none;
}


calendar > grid > label.today {
  background-color: alpha(#e8edf8,0.15);
  border-radius: 3px;
}


calendar > grid > label.today:selected {
  box-shadow: none;
}


calendar > grid > label:focus {
  outline-style: none;
}


calendar > grid > label.day-number {
  padding: 4px;
}


calendar > grid > label.day-number:selected {
  border-radius: 6px;
}


calendar > grid > label.day-number.other-month {
  color: alpha(currentColor,0.3);
}

window.dialog.message.background {
  background-color: rgba(10, 16, 42, 0.65);
}

window.dialog.message .titlebar {
  min-height: 28px;
  background-color: transparent;
  border: none;
}

window.dialog.message box.dialog-vbox.vertical {
  border-spacing: 10px;
}

window.dialog.message label.title {
  font-weight: 800;
  font-size: 15pt;
}

window.dialog.message .dialog-action-area {
  padding: 18px;
}

window.dialog.message .dialog-action-area > button {
  min-height: 20px;
  padding: 4px 8px;
  box-shadow: none;
  border-radius: 6px;
  margin: 3px;
  border: none;
}

window.dialog.message .dialog-action-area > button:not(.suggested-action):not(.destructive-action) {
  border-radius: 6px;
  background-color: transparent;
}

window.dialog.message .dialog-action-area > button:not(.suggested-action):not(.destructive-action):hover {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.12);
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

window.dialog.message .dialog-action-area > button:not(.suggested-action):not(.destructive-action):active {
  color: #e8edf8;
  background-color: rgba(136, 170, 255, 0.22);
}

window.dialog.message .dialog-action-area > button.suggested-action, window.dialog.message .dialog-action-area > button.destructive-action {
  border-radius: 6px;
}

window.background.messagedialog .response-area {
  padding: 9px;
}

window.background.messagedialog .response-area button {
  min-height: 20px;
  padding: 4px 8px;
  box-shadow: none;
  border-radius: 6px;
  margin: 3px;
  border: none;
}

window.background.messagedialog .response-area button:not(.suggested-action):not(.destructive-action) {
  border-radius: 6px;
  background-color: transparent;
}

window.background.messagedialog .response-area button:not(.suggested-action):not(.destructive-action):hover {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.12);
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

window.background.messagedialog .response-area button:not(.suggested-action):not(.destructive-action):active {
  color: #e8edf8;
  background-color: rgba(136, 170, 255, 0.22);
}

window.background.messagedialog .response-area button.suggested-action, window.background.messagedialog .response-area button.destructive-action {
  border-radius: 6px;
}

window.background.messagedialog .response-area separator {
  background-color: transparent;
}

window.aboutdialog image.large-icons {
  -gtk-icon-size: 128px;
}

filechooser paned.horizontal > separator {
  background-image: image(mix(black,#2e3440,0.25));
}

filechooser #pathbarbox {
  border-bottom: 1px solid rgba(255, 255, 255, 0.13);
}

filechooserbutton > button > box {
  border-spacing: 6px;
}

filechooserbutton:drop(active) {
  box-shadow: none;
  border-color: transparent;
}

.sidebar {
  border: none;
  background-color: rgba(12, 20, 48, 0.52);
  color: #e8edf8;
}

.sidebar list {
  background-color: transparent;
}

.sidebar list > separator {
  min-height: 0;
  background: none;
  border: none;
}

separator.sidebar {
  background-color: mix(black,#2e3440,0.25);
  min-height: 1px;
  min-width: 1px;
  border: none;
}

stacksidebar list.separators:not(.horizontal) > row:not(.separator) {
  border-bottom: none;
}

stacksidebar row {
  padding: 4px;
}

stacksidebar row > label {
  padding-left: 6px;
  padding-right: 6px;
}

stacksidebar row.needs-attention > label {
  background-size: 6px 6px, 0 0;
}

.navigation-sidebar {
  background-color: transparent;
  padding: 8px;
}

.navigation-sidebar > separator {
  margin: 6px 0;
  background: none;
}

.navigation-sidebar > row {
  min-height: 32px;
  padding: 0 8px;
  border-radius: 8px;
  margin: 0;
  outline: none;
}

.navigation-sidebar > row + row {
  margin-top: 3px;
}

.navigation-sidebar > row:hover, .navigation-sidebar > row:focus-visible:focus-within {
  background-color: alpha(#e8edf8,0.1);
}

.navigation-sidebar > row:active {
  color: #e8edf8;
  background-color: alpha(#e8edf8,0.2);
}

.navigation-sidebar > row:selected {
  color: #e8edf8;
  background-color: alpha(#e8edf8,0.15);
}

.navigation-sidebar > row:selected:hover {
  background-color: alpha(#e8edf8,0.2);
}

.navigation-sidebar > row:selected:focus-visible:focus-within {
  outline: none;
  color: #e8edf8;
  background-color: alpha(#e8edf8,0.15);
}

.navigation-sidebar > row:selected:focus-visible:focus-within:hover {
  background-color: alpha(#e8edf8,0.2);
}

.navigation-sidebar > row:disabled {
  color: rgba(160, 180, 220, 0.4);
}

placessidebar > viewport.frame {
  border-style: none;
}

placessidebar .navigation-sidebar > row {
  min-height: 32px;
  padding: 0 8px;
}

placessidebar .navigation-sidebar > row > revealer {
  padding: 0;
}

placessidebar .navigation-sidebar > row image.sidebar-icon:dir(ltr) {
  padding-right: 8px;
}

placessidebar .navigation-sidebar > row image.sidebar-icon:dir(rtl) {
  padding-left: 8px;
}

placessidebar .navigation-sidebar > row label.sidebar-label:dir(ltr) {
  padding-right: 8px;
}

placessidebar .navigation-sidebar > row label.sidebar-label:dir(rtl) {
  padding-left: 8px;
}

placessidebar .navigation-sidebar > row button.sidebar-button {
  min-width: 22px;
  min-height: 22px;
  margin-top: 2px;
  margin-bottom: 2px;
  padding: 0;
  border-radius: 9999px;
  border: none;
}

placessidebar .navigation-sidebar > row button.sidebar-button > image {
  opacity: 0.85;
}

placessidebar .navigation-sidebar > row button.sidebar-button:not(:hover):not(:active) > image {
  opacity: 0.65;
}

placessidebar .navigation-sidebar > row.sidebar-placeholder-row {
  padding: 0 8px;
  min-height: 2px;
  background-image: linear-gradient(to bottom, #d0846c, #d0846c);
  background-clip: content-box;
}

placessidebar .navigation-sidebar > row.sidebar-new-bookmark-row {
  color: #5271ad;
}

placessidebar .navigation-sidebar > row:drop(active):not(:disabled) {
  color: #d0846c;
  box-shadow: inset 0 1px #d0846c, inset 0 -1px #d0846c;
}

placessidebar .navigation-sidebar > row:drop(active):not(:disabled):selected {
  color: rgba(210, 222, 248, 0.9);
  background-color: #d0846c;
}

placesview .server-list-button > image {
  -gtk-icon-transform: rotate(0turn);
}

placesview .server-list-button:checked > image {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  -gtk-icon-transform: rotate(-0.5turn);
}

placesview > actionbar > revealer > box > label {
  padding-left: 8px;
  padding-right: 8px;
}

paned > separator {
  min-width: 1px;
  min-height: 1px;
  background: none;
  background-size: 1px 1px;
}

paned > separator.wide {
  min-width: 5px;
  min-height: 5px;
}

paned.horizontal > separator:dir(ltr) {
  margin: 0 -8px 0 0;
  padding: 0 8px 0 0;
  box-shadow: inset 1px 0 rgba(255, 255, 255, 0.13);
}

paned.horizontal > separator:dir(rtl) {
  margin: 0 0 0 -8px;
  padding: 0 0 0 8px;
  box-shadow: inset -1px 0 rgba(255, 255, 255, 0.13);
}

paned.horizontal > separator.wide {
  margin: 0;
  padding: 0;
  box-shadow: inset 1px 0 rgba(255, 255, 255, 0.13), inset -1px 0 rgba(255, 255, 255, 0.13);
}

paned.vertical > separator {
  margin: 0 0 -8px 0;
  padding: 0 0 8px 0;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
}

paned.vertical > separator.wide {
  margin: 0;
  padding: 0;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13), inset 0 -1px rgba(255, 255, 255, 0.13);
}

infobar {
  border-style: none;
}

infobar.info > revealer > box, infobar.info:backdrop > revealer > box {
  background-color: #5271ad;
}

infobar.info > revealer > box selection, infobar.info:backdrop > revealer > box selection {
  color: #5271ad;
}

infobar.question > revealer > box, infobar.question:backdrop > revealer > box {
  background-color: #4c7bd9;
}

infobar.question > revealer > box selection, infobar.question:backdrop > revealer > box selection {
  color: #4c7bd9;
}

infobar.warning > revealer > box, infobar.warning:backdrop > revealer > box {
  background-color: #d0846c;
}

infobar.warning > revealer > box selection, infobar.warning:backdrop > revealer > box selection {
  color: #d0846c;
}

infobar.error > revealer > box, infobar.error:backdrop > revealer > box {
  background-color: #c35b65;
}

infobar.error > revealer > box selection, infobar.error:backdrop > revealer > box selection {
  color: #c35b65;
}

infobar.info > revealer > box, infobar.info:hover > revealer > box, infobar.info:backdrop > revealer > box, infobar.question > revealer > box, infobar.question:hover > revealer > box, infobar.question:backdrop > revealer > box, infobar.warning > revealer > box, infobar.warning:hover > revealer > box, infobar.warning:backdrop > revealer > box, infobar.error > revealer > box, infobar.error:hover > revealer > box, infobar.error:backdrop > revealer > box {
  color: #ffffff;
  caret-color: currentColor;
}

infobar.info > revealer > box button, infobar.info:hover > revealer > box button, infobar.info:backdrop > revealer > box button, infobar.question > revealer > box button, infobar.question:hover > revealer > box button, infobar.question:backdrop > revealer > box button, infobar.warning > revealer > box button, infobar.warning:hover > revealer > box button, infobar.warning:backdrop > revealer > box button, infobar.error > revealer > box button, infobar.error:hover > revealer > box button, infobar.error:backdrop > revealer > box button {
  min-height: 28px;
}

infobar.info > revealer > box selection, infobar.info:hover > revealer > box selection, infobar.info:backdrop > revealer > box selection, infobar.question > revealer > box selection, infobar.question:hover > revealer > box selection, infobar.question:backdrop > revealer > box selection, infobar.warning > revealer > box selection, infobar.warning:hover > revealer > box selection, infobar.warning:backdrop > revealer > box selection, infobar.error > revealer > box selection, infobar.error:hover > revealer > box selection, infobar.error:backdrop > revealer > box selection {
  background-color: #ffffff;
}

infobar .close,
searchbar .close {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  min-width: 16px;
  min-height: 16px;
  padding: 4px;
  border-radius: 1000px;
}

infobar .close:hover,
searchbar .close:hover {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.12);
}

tooltip {
  border-radius: 12px;
  box-shadow: none;
}

tooltip.background {
  background-color: rgba(5, 10, 30, 0.72);
  background-clip: padding-box;
  border-radius: 12px;
  color: rgba(225, 232, 252, 0.95);
  border: 1px solid rgba(0, 0, 0, 0.2);
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.1);
}

tooltip.background:backdrop {
  background-color: rgba(5, 10, 30, 0.72);
}

tooltip.background label {
  padding: 6px;
}

tooltip > box {
  border-spacing: 6px;
}

colorswatch, colorswatch:drop(active) {
  border-style: none;
}

colorswatch.top {
  border-top-left-radius: 2.5px;
  border-top-right-radius: 2.5px;
}

colorswatch.top overlay {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

colorswatch.bottom {
  border-bottom-left-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
}

colorswatch.bottom overlay {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
}

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 2.5px;
  border-bottom-left-radius: 2.5px;
}

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
}

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

colorswatch.dark overlay {
  color: rgba(255, 255, 255, 0.7);
}

colorswatch.dark overlay:hover {
  border-color: rgba(255, 255, 255, 0.13);
}

colorswatch.light overlay {
  color: rgba(0, 0, 0, 0.7);
}

colorswatch.light overlay:hover {
  border-color: rgba(255, 255, 255, 0.13);
}

colorswatch overlay {
  border: 1px solid rgba(255, 255, 255, 0.13);
}

colorswatch overlay:hover {
  background-color: rgba(255, 255, 255, 0.2);
}

colorswatch:disabled {
  opacity: 0.5;
}

colorswatch:disabled overlay {
  border-color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
}

colorswatch#add-color-button {
  border-style: solid;
  border-width: 1px;
  color: rgba(200, 215, 240, 0.85);
  background-color: rgba(255, 255, 255, 0.07);
  box-shadow: none;
  border: none;
}

colorswatch#add-color-button:hover {
  color: #e8edf8;
  background-color: rgba(255, 255, 255, 0.12);
}

colorswatch#add-color-button overlay {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}

button.color {
  padding: 0;
}

button.color > colorswatch:only-child {
  border-radius: 3px;
}

button.color > colorswatch:only-child > overlay {
  border-radius: 2px;
}

button.color > colorswatch:only-child:disabled {
  filter: none;
}

button.color > colorswatch:only-child.light > overlay {
  border-color: rgba(255, 255, 255, 0.13);
}

button.color colorswatch:first-child:last-child {
  margin: 3px;
}

button.color colorswatch:first-child:last-child, button.color colorswatch:first-child:last-child > overlay {
  border-radius: 3px;
}

colorchooser .popover.osd {
  border-radius: 6px;
}

.content-view {
  background-color: rgba(8, 14, 36, 0.42);
}

.content-view:hover {
  -gtk-icon-filter: brightness(1.2);
}

.content-view .tile {
  margin: 2px;
  background-color: black;
  border-radius: 0;
  padding: 0;
}

.content-view .tile:active, .content-view .tile:selected {
  background-color: #5271ad;
}

.content-view .tile:disabled {
  color: mix(rgba(12, 20, 48, 0.52),rgba(8, 14, 36, 0.42),0.4);
}

.osd .scale-popup button.flat {
  border-style: none;
  border-radius: 6px;
}

.scale-popup button {
  border: none;
}

.context-menu {
  font: initial;
}

.keycap {
  min-width: 16px;
  min-height: 20px;
  padding: 3px 6px;
  color: #e8edf8;
  background-color: rgba(8, 14, 36, 0.42);
  border: 1px solid rgba(255, 255, 255, 0.13);
  border-radius: 6px;
  box-shadow: inset 0px -2px 0px rgba(0, 0, 0, 0.15);
}

stackswitcher button.text-button {
  min-width: 80px;
}

shortcuts-section {
  margin: 20px;
}

*:drop(active):focus,
*:drop(active) {
  box-shadow: inset 0 0 0 1px #d0846c;
}

window {
  border: none;
}

window.csd {
  transition: none;
  border-radius: 24px;
  outline: 1px solid rgba(255, 255, 255, 0.1);
  outline-offset: -1px;
  box-shadow: 0 3px 6px RGB(0 0 0/15%), 0 7px 24px RGB(0 0 0/12%), 0 12px 32px RGB(0 0 0/8%), 0 0 0 2px rgba(0, 0, 0, 0.1), 0 0 0 1px rgba(0, 0, 0, 0.75);
  margin: 0;
}

window.csd:backdrop {
  transition: box-shadow 150ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: 0 3px 6px RGB(0 0 0/10%), 0 7px 24px RGB(0 0 0/6%), 0 12px 32px transparent, 0 0 0 2px rgba(0, 0, 0, 0.1), 0 0 0 1px rgba(0, 0, 0, 0.75);
}

window.csd.tiled, window.csd.tiled-top, window.csd.tiled-left, window.csd.tiled-right, window.csd.tiled-bottom {
  border-radius: 0;
  outline: none;
}

window.csd.maximized, window.csd.fullscreen {
  border-radius: 0;
  outline: none;
  box-shadow: none;
  transition: none;
}

window.csd.ssd-frame {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  outline: none;
}

window.csd.ssd-frame headerbar {
  border-top-left-radius: 24px;
  border-top-right-radius: 24px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

window.csd.ssd-frame.maximized headerbar, window.csd.ssd-frame.fullscreen headerbar {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  box-shadow: none;
}

window.solid-csd {
  border: 1px solid mix(black,#2e3440,0.25);
  border-radius: 0;
  margin: 0;
  background-color: rgba(10, 18, 45, 0.55);
  box-shadow: none;
}

window.ssd {
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.75);
}

popover.emoji-picker {
  padding: 0;
  border-radius: 12px;
}

popover.emoji-picker > contents {
  padding: 0;
}

.emoji-searchbar {
  padding: 6px;
  border-spacing: 6px;
}

.emoji-searchbar entry {
  margin: 0;
}

.emoji-toolbar {
  padding: 3px;
  border-spacing: 0;
  border-top: 1px solid rgba(255, 255, 255, 0.13);
}

.emoji-toolbar button.image-button {
  border-radius: 6px;
}

button.emoji-section {
  margin: 0;
  padding: 1px 12px;
  border-radius: 6px;
  border: none;
  outline-offset: -2px;
  box-shadow: none;
}

popover.emoji-picker emoji {
  font-size: x-large;
  padding: 6px;
  border-radius: 6px;
}

emoji-completion-row > box {
  border-spacing: 6px;
  padding: 3px 10px;
}

emoji-completion-row:focus,
emoji-completion-row:hover {
  background-color: #5271ad;
  color: #ffffff;
}

emoji-completion-row emoji:focus,
emoji-completion-row emoji:hover {
  background-color: rgba(255, 255, 255, 0.13);
}

popover.entry-completion > contents {
  padding: 0;
}

statusbar {
  padding: 6px 12px;
}

.nautilus-window .nautilus-list-view listview.view > row.activatable,
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable, .nautilus-window .nautilus-grid-view child.activatable,
#NautilusFileChooser .nautilus-grid-view child.activatable {
  border-radius: 8px;
  transition: background-color 150ms cubic-bezier(0, 0, 0.2, 1);
}

.nautilus-window .nautilus-list-view listview.view > row.activatable:hover,
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable:hover, .nautilus-window .nautilus-grid-view child.activatable:hover,
#NautilusFileChooser .nautilus-grid-view child.activatable:hover {
  background-color: alpha(currentColor,0.05);
  transition-duration: 100ms;
}

.nautilus-window .nautilus-list-view listview.view > row.activatable:active,
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable:active, .nautilus-window .nautilus-grid-view child.activatable:active,
#NautilusFileChooser .nautilus-grid-view child.activatable:active {
  color: #e8edf8;
  background-color: alpha(currentColor,0.1);
}

.nautilus-window .nautilus-list-view listview.view > row.activatable:disabled,
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable:disabled, .nautilus-window .nautilus-grid-view child.activatable:disabled,
#NautilusFileChooser .nautilus-grid-view child.activatable:disabled {
  color: rgba(160, 180, 220, 0.4);
}

.nautilus-window .nautilus-list-view listview.view > row.activatable:selected,
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable:selected, .nautilus-window .nautilus-grid-view child.activatable:selected,
#NautilusFileChooser .nautilus-grid-view child.activatable:selected {
  color: #e8edf8;
  background-color: alpha(currentColor,0.12);
}

.nautilus-window .nautilus-list-view listview.view > row.activatable:selected:hover,
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable:selected:hover, .nautilus-window .nautilus-grid-view child.activatable:selected:hover,
#NautilusFileChooser .nautilus-grid-view child.activatable:selected:hover {
  background-color: alpha(currentColor,0.16);
}

.nautilus-window .nautilus-list-view listview.view > row.activatable:selected:active,
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable:selected:active, .nautilus-window .nautilus-grid-view child.activatable:selected:active,
#NautilusFileChooser .nautilus-grid-view child.activatable:selected:active {
  background-color: alpha(currentColor,0.2);
}

.nautilus-window headerbar > windowhandle > box > widget > box.start > stack > widget > box,
.nautilus-window headerbar > windowhandle > box > widget > box.start > box > stack > widget > box,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > stack > widget > box,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > box > stack > widget > box {
  margin-left: 12px;
  padding: 3px;
  border-radius: 9999px;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.03), rgba(255, 255, 255, 0.02));
  box-shadow: 0 6px 20px rgba(0, 0, 0, 0.15), inset 1px 2px 1px -1px rgba(255, 255, 255, 0.08), inset -1px -1px 1px 0 rgba(255, 255, 255, 0.08);
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.03), rgba(255, 255, 255, 0.02)), image(rgba(255, 255, 255, 0.13));
  background-size: auto, 1px 18px;
  background-position: center center;
  background-repeat: no-repeat;
  border-spacing: 4px;
}

.nautilus-window headerbar > windowhandle > box > widget > box.start > stack > widget > box:backdrop,
.nautilus-window headerbar > windowhandle > box > widget > box.start > box > stack > widget > box:backdrop,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > stack > widget > box:backdrop,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > box > stack > widget > box:backdrop {
  background-color: alpha(rgba(230, 238, 255, 0.95),0.05);
  background-image: none;
  border: none;
  box-shadow: none;
  background-image: image(rgba(255, 255, 255, 0.13));
  background-size: 1px 18px;
}

.nautilus-window headerbar > windowhandle > box > widget > box.start > stack > widget > box > button,
.nautilus-window headerbar > windowhandle > box > widget > box.start > box > stack > widget > box > button,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > stack > widget > box > button,
#NautilusFileChooser headerbar > windowhandle > box > widget > box.start > box > stack > widget > box > button {
  min-height: 24px;
  min-width: 24px;
  padding: 3px;
}

.nautilus-window .view,
#NautilusFileChooser .view {
  background-color: transparent;
}

.nautilus-window .nautilus-grid-view,
#NautilusFileChooser .nautilus-grid-view {
  background-color: transparent;
}

.nautilus-window .nautilus-grid-view child.activatable,
#NautilusFileChooser .nautilus-grid-view child.activatable {
  padding: 0;
}

.nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell,
#NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell {
  padding: 4px;
}

.nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell clamp box,
#NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell clamp box {
  margin: 0;
  border-spacing: 0;
}

.nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell .icon-ui-labels-box,
#NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell .icon-ui-labels-box {
  margin: 0 0 8px;
  border-spacing: 0;
}

.nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell .dim-label, .nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell entry > text:disabled,
.nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell entry > text > placeholder, .nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell row label.subtitle, row .nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell label.subtitle, .nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell row.property > box.header > box.title > .title, .nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell row.expander image.expander-row-arrow, row.expander .nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell image.expander-row-arrow, .nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell row.expander.property box > list > row > box.header > box.title > .title, row.expander.property .nautilus-window .nautilus-grid-view child.activatable #NautilusViewCell box > list > row > box.header > box.title > .title,
#NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell .dim-label,
#NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell entry > text:disabled,
#NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell entry > text > placeholder,
#NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell row label.subtitle,
row #NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell label.subtitle,
#NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell row.property > box.header > box.title > .title,
#NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell row.expander image.expander-row-arrow,
row.expander #NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell image.expander-row-arrow,
#NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell row.expander.property box > list > row > box.header > box.title > .title,
row.expander.property #NautilusFileChooser .nautilus-grid-view child.activatable #NautilusViewCell box > list > row > box.header > box.title > .title {
  border-spacing: 0;
}

.nautilus-window .nautilus-list-view,
#NautilusFileChooser .nautilus-list-view {
  padding: 0;
  margin: 0;
  border-spacing: 0;
  background-color: transparent;
}

.nautilus-window .nautilus-list-view listview.view,
#NautilusFileChooser .nautilus-list-view listview.view {
  padding: 0;
  margin: 0;
  border-spacing: 3px;
}

.nautilus-window .nautilus-list-view listview.view > row.activatable,
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable {
  padding: 0;
  margin: 0;
}

.nautilus-window .nautilus-list-view listview.view > row.activatable > cell,
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable > cell {
  padding: 0;
}

.nautilus-window .nautilus-list-view listview.view > row.activatable > cell > widget#NautilusViewCell,
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable > cell > widget#NautilusViewCell {
  padding: 3px 9px;
}

.nautilus-window .nautilus-list-view listview.view > row.activatable:nth-child(odd):not(:disabled),
#NautilusFileChooser .nautilus-list-view listview.view > row.activatable:nth-child(odd):not(:disabled) {
  background-image: image(alpha(currentColor,0.03));
}

.nautilus-window .sidebar-pane:dir(ltr), .nautilus-window .sidebar-pane:dir(ltr) banner > revealer > widget, .nautilus-window .sidebar-pane.end:dir(rtl), .nautilus-window .sidebar-pane.end:dir(rtl) banner > revealer > widget,
#NautilusFileChooser .sidebar-pane:dir(ltr),
#NautilusFileChooser .sidebar-pane:dir(ltr) banner > revealer > widget,
#NautilusFileChooser .sidebar-pane.end:dir(rtl),
#NautilusFileChooser .sidebar-pane.end:dir(rtl) banner > revealer > widget {
  box-shadow: 0 0 0 6px rgba(8, 14, 36, 0.42), 0 32px 0 6px rgba(8, 14, 36, 0.42), 0 -32px 0 6px rgba(8, 14, 36, 0.42), 2px 3px 12px rgba(0, 0, 0, 0.1), inset 0 0 0 1px rgba(255, 255, 255, 0.06);
}

.nautilus-window .sidebar-pane:dir(rtl), .nautilus-window .sidebar-pane:dir(rtl) banner > revealer > widget, .nautilus-window .sidebar-pane.end:dir(ltr), .nautilus-window .sidebar-pane.end:dir(ltr) banner > revealer > widget,
#NautilusFileChooser .sidebar-pane:dir(rtl),
#NautilusFileChooser .sidebar-pane:dir(rtl) banner > revealer > widget,
#NautilusFileChooser .sidebar-pane.end:dir(ltr),
#NautilusFileChooser .sidebar-pane.end:dir(ltr) banner > revealer > widget {
  box-shadow: 0 0 0 6px rgba(8, 14, 36, 0.42), 0 32px 0 6px rgba(8, 14, 36, 0.42), 0 -32px 0 6px rgba(8, 14, 36, 0.42), -2px 3px 12px rgba(0, 0, 0, 0.1), inset 0 0 0 1px rgba(255, 255, 255, 0.06);
}

.nautilus-window .sidebar-pane:backdrop:dir(ltr), .nautilus-window .sidebar-pane:backdrop:dir(ltr) banner > revealer > widget, .nautilus-window .sidebar-pane:backdrop.end:dir(rtl), .nautilus-window .sidebar-pane:backdrop.end:dir(rtl) banner > revealer > widget,
#NautilusFileChooser .sidebar-pane:backdrop:dir(ltr),
#NautilusFileChooser .sidebar-pane:backdrop:dir(ltr) banner > revealer > widget,
#NautilusFileChooser .sidebar-pane:backdrop.end:dir(rtl),
#NautilusFileChooser .sidebar-pane:backdrop.end:dir(rtl) banner > revealer > widget {
  box-shadow: none;
}

.nautilus-window .sidebar-pane:backdrop:dir(rtl), .nautilus-window .sidebar-pane:backdrop:dir(rtl) banner > revealer > widget, .nautilus-window .sidebar-pane:backdrop.end:dir(ltr), .nautilus-window .sidebar-pane:backdrop.end:dir(ltr) banner > revealer > widget,
#NautilusFileChooser .sidebar-pane:backdrop:dir(rtl),
#NautilusFileChooser .sidebar-pane:backdrop:dir(rtl) banner > revealer > widget,
#NautilusFileChooser .sidebar-pane:backdrop.end:dir(ltr),
#NautilusFileChooser .sidebar-pane:backdrop.end:dir(ltr) banner > revealer > widget {
  box-shadow: none;
}

.nautilus-window .sidebar-pane placessidebar,
#NautilusFileChooser .sidebar-pane placessidebar {
  background: none;
}

.nautilus-window .sidebar-pane placessidebar .navigation-sidebar:not(.view) > row:selected,
#NautilusFileChooser .sidebar-pane placessidebar .navigation-sidebar:not(.view) > row:selected {
  background-color: rgba(255, 255, 255, 0.06);
  color: #5271ad;
}

.nautilus-window .sidebar-pane > separator.horizontal,
#NautilusFileChooser .sidebar-pane > separator.horizontal {
  background-color: mix(black,#2e3440,0.25);
}

.nautilus-window .content-pane,
#NautilusFileChooser .content-pane {
  background-color: rgba(8, 14, 36, 0.42);
}

.nautilus-window .content-pane:backdrop,
#NautilusFileChooser .content-pane:backdrop {
  background-color: rgba(6, 10, 28, 0.36);
}

.nautilus-window .content-pane headerbar .linked > entry:first-child,
#NautilusFileChooser .content-pane headerbar .linked > entry:first-child {
  border-top-left-radius: 9999px;
  border-bottom-left-radius: 9999px;
}

.nautilus-window .content-pane headerbar .linked > button:last-child,
#NautilusFileChooser .content-pane headerbar .linked > button:last-child {
  border-top-right-radius: 9999px;
  border-bottom-right-radius: 9999px;
}

.floating-bar {
  padding: 3px;
  min-height: 24px;
  background-color: #5271ad;
  color: #ffffff;
  border-radius: 9999px;
  margin: 6px;
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.15), 0 2px 3px 0 rgba(0, 0, 0, 0.1), inset 0 0 0 1px rgba(255, 255, 255, 0.1);
}

.floating-bar > button.circular.flat {
  border-radius: 9999px;
  min-height: 24px;
  min-width: 24px;
  padding: 0;
}

#NautilusQueryEditor, .nautilus-query-editor {
  padding-right: 3px;
}

#NautilusQueryEditor > image,
#NautilusQueryEditor > box,
#NautilusQueryEditor > text, .nautilus-query-editor > image,
.nautilus-query-editor > box,
.nautilus-query-editor > text {
  margin: 0;
}

#NautilusQueryEditor #NautilusQueryEditorTag > button, #NautilusQueryEditor .nautilus-query-editor-tag > button, .nautilus-query-editor #NautilusQueryEditorTag > button, .nautilus-query-editor .nautilus-query-editor-tag > button {
  margin: 0;
}

#NautilusQueryEditor > menubutton > button, .nautilus-query-editor > menubutton > button {
  min-width: 24px;
  min-height: 24px;
  margin: 0;
  padding: 3px;
  border-radius: 9999px;
}

#NautilusPathBar, .nautilus-pathbar {
  border-radius: 9999px;
  margin: 0;
  padding: 3px;
  color: rgba(230, 238, 255, 0.95);
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.03), rgba(255, 255, 255, 0.02));
  box-shadow: 0 6px 20px rgba(0, 0, 0, 0.15), inset 1px 2px 1px -1px rgba(255, 255, 255, 0.08), inset -1px -1px 1px 0 rgba(255, 255, 255, 0.08);
  border: none;
}

#NautilusPathBar:backdrop, .nautilus-pathbar:backdrop {
  background-color: alpha(rgba(230, 238, 255, 0.95),0.05);
  background-image: none;
  border: none;
  box-shadow: none;
}

#NautilusPathBar #NautilusPathButton, #NautilusPathBar .nautilus-path-button, .nautilus-pathbar #NautilusPathButton, .nautilus-pathbar .nautilus-path-button {
  margin: 0;
  border-radius: 9999px;
  min-height: 24px;
  padding: 3px 6px;
}

#NautilusPathBar #NautilusPathButton.current-dir, #NautilusPathBar .nautilus-path-button.current-dir, .nautilus-pathbar #NautilusPathButton.current-dir, .nautilus-pathbar .nautilus-path-button.current-dir {
  color: rgba(230, 238, 255, 0.95);
}

#NautilusPathBar #NautilusPathButton.current-dir:hover, #NautilusPathBar #NautilusPathButton.current-dir:active, #NautilusPathBar .nautilus-path-button.current-dir:hover, #NautilusPathBar .nautilus-path-button.current-dir:active, .nautilus-pathbar #NautilusPathButton.current-dir:hover, .nautilus-pathbar #NautilusPathButton.current-dir:active, .nautilus-pathbar .nautilus-path-button.current-dir:hover, .nautilus-pathbar .nautilus-path-button.current-dir:active {
  background: none;
  box-shadow: none;
}

#NautilusPathBar > menubutton, #NautilusPathBar > menubutton.flat.popup, .nautilus-pathbar > menubutton, .nautilus-pathbar > menubutton.flat.popup {
  margin: 0;
}

#NautilusPathBar > menubutton > button, #NautilusPathBar > menubutton.flat.popup > button, .nautilus-pathbar > menubutton > button, .nautilus-pathbar > menubutton.flat.popup > button {
  min-height: 24px;
  min-width: 24px;
  padding: 3px;
  border-radius: 9999px;
}

#NautilusFileChooser multi-layout-view > box {
  padding-left: 12px;
}

navigation-view-page > toolbarview > scrolledwindow > viewport > clamp > box > box > stack > button {
  margin-top: 12px;
}

popover.background.entry-completion {
  margin: 6px;
}

popover.background.entry-completion treeview.view:selected {
  background-image: image(#5271ad);
}

window.background.csd > contents > leaflet.unfolded > box > scrolledwindow > viewport > widget > stack > list.navigation-sidebar,
window.background.csd > widget > leaflet.unfolded > box > scrolledwindow > viewport > widget > stack > list.navigation-sidebar {
  background-color: rgba(8, 13, 38, 0.48);
}

window.background.csd > contents > leaflet.unfolded > box > scrolledwindow > viewport > widget > stack > list.navigation-sidebar > separator,
window.background.csd > widget > leaflet.unfolded > box > scrolledwindow > viewport > widget > stack > list.navigation-sidebar > separator {
  background-color: transparent;
  margin: 0;
  min-height: 0;
}

window.background.csd > contents > leaflet.unfolded > box > scrolledwindow > viewport > widget > stack > box > list.navigation-sidebar,
window.background.csd > widget > leaflet.unfolded > box > scrolledwindow > viewport > widget > stack > box > list.navigation-sidebar {
  background-color: rgba(8, 13, 38, 0.48);
}

window.background.csd > contents > leaflet.unfolded > box > stack.background,
window.background.csd > widget > leaflet.unfolded > box > stack.background {
  background-color: rgba(8, 14, 36, 0.42);
}

preferencesgroup > box button.background-preview-button {
  padding: 3px;
  outline: 2px solid transparent;
  outline-offset: 0;
  border-radius: 9px;
}

preferencesgroup > box button.background-preview-button, preferencesgroup > box button.background-preview-button:hover, preferencesgroup > box button.background-preview-button:active, preferencesgroup > box button.background-preview-button:checked {
  background: none;
  border: none;
  box-shadow: none;
}

preferencesgroup > box button.background-preview-button:hover {
  outline-color: rgba(162, 171, 188, 0.35);
}

preferencesgroup > box button.background-preview-button:active {
  outline-color: rgba(200, 215, 240, 0.85);
}

preferencesgroup > box button.background-preview-button:checked {
  outline-color: #5271ad;
}

preferencesgroup > box flowbox.background-flowbox > flowboxchild {
  outline: 2px solid transparent;
  outline-offset: 0;
  border-radius: 9px;
  padding: 3px;
}

preferencesgroup > box flowbox.background-flowbox > flowboxchild:hover {
  outline-color: rgba(162, 171, 188, 0.35);
}

preferencesgroup > box flowbox.background-flowbox > flowboxchild:active {
  outline-color: rgba(200, 215, 240, 0.85);
}

preferencesgroup > box flowbox.background-flowbox > flowboxchild:selected {
  outline-color: #5271ad;
  background-color: transparent;
}

preferencesgroup > box .cutout-button {
  background-color: rgba(10, 16, 42, 0.65);
}

window.background > contents > toastoverlay > leaflet > box,
window.background > widget > toastoverlay > leaflet > box {
  background-color: rgba(8, 14, 36, 0.42);
}

window.background > contents > toastoverlay > leaflet > box > headerbar, window.background > contents > toastoverlay > leaflet > box > headerbar:backdrop,
window.background > widget > toastoverlay > leaflet > box > headerbar,
window.background > widget > toastoverlay > leaflet > box > headerbar:backdrop {
  background: none;
  border: none;
}

window.background > contents > toastoverlay > leaflet > box + separator + box,
window.background > widget > toastoverlay > leaflet > box + separator + box {
  background-color: rgba(8, 13, 38, 0.48);
}

window.background > contents > toastoverlay > leaflet > box > .view,
window.background > contents > toastoverlay > leaflet > box list:not(.boxed-list),
window.background > widget > toastoverlay > leaflet > box > .view,
window.background > widget > toastoverlay > leaflet > box list:not(.boxed-list) {
  background-color: transparent;
}

window.background > contents > toastoverlay > leaflet > box list > row textview,
window.background > widget > toastoverlay > leaflet > box list > row textview {
  padding: 6px;
  border-left: 1px solid rgba(255, 255, 255, 0.13);
}

window.background > contents > toastoverlay > leaflet > box list > row textview, window.background > contents > toastoverlay > leaflet > box list > row textview > text,
window.background > widget > toastoverlay > leaflet > box list > row textview,
window.background > widget > toastoverlay > leaflet > box list > row textview > text {
  background: none;
}

window.background.maximized > contents > toastoverlay > leaflet > box > headerbar, window.background.maximized > contents > toastoverlay > leaflet > box > headerbar:backdrop,
window.background.maximized > widget > toastoverlay > leaflet > box > headerbar,
window.background.maximized > widget > toastoverlay > leaflet > box > headerbar:backdrop, window.background.tiled > contents > toastoverlay > leaflet > box > headerbar, window.background.tiled > contents > toastoverlay > leaflet > box > headerbar:backdrop,
window.background.tiled > widget > toastoverlay > leaflet > box > headerbar,
window.background.tiled > widget > toastoverlay > leaflet > box > headerbar:backdrop {
  background: none;
  border: none;
}

datechooser .current-week {
  background-color: alpha(currentColor,0.05);
}

datechooser button.circular.day {
  border: none;
  box-shadow: none;
}

datechooser button.circular.day:selected {
  background-color: #5271ad;
  color: #ffffff;
}

datechooser navigator > button.flat {
  padding: 0;
  min-height: 28px;
  min-width: 28px;
}

agenda-view list.background {
  background-color: transparent;
}

menubutton.flat.popup.sources-button {
  margin: 0;
}

menubutton.flat.popup.sources-button > button {
  margin: 0;
  border-radius: 0;
  padding: 0 12px;
}

menubutton.flat.popup.sources-button > button .title {
  font-size: small;
  font-weight: normal;
}

menubutton.flat.popup.sources-button > button .title,
menubutton.flat.popup.sources-button > button .subtitle {
  padding: 2px 0 2px 6px;
}

menubutton.flat.popup.sources-button > button image.calendar-color-image {
  -gtk-icon-size: 8px;
}

#gnome-system-monitor scrolledwindow.default {
  border-radius: 6px;
}

#gnome-system-monitor scrolledwindow.default > treeview.view {
  border-radius: 12px;
  border: 1px solid rgba(255, 255, 255, 0.13);
}

#gnome-system-monitor scrolledwindow > columnview.view {
  border-radius: 12px;
  border: 1px solid rgba(255, 255, 255, 0.13);
}

.contacts-editor-address > entry.flat:not(:last-child) {
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.13);
}

.contacts-editor-address > entry.flat:first-child {
  border-radius: 6px 6px 0 0;
}

.contacts-editor-address > entry.flat:last-child {
  border-radius: 0 0 6px 6px;
}

.history-view {
  background-color: rgba(8, 14, 36, 0.42);
}

.card.display-container, .card.bit-panel {
  border: 1px solid rgba(255, 255, 255, 0.13);
}

.card mathdisplay > box {
  border-top: 1px solid rgba(255, 255, 255, 0.13);
}

.card.bit-panel {
  padding: 6px 0;
}

.card.bit-panel button, .card.bit-panel button.flat,
.card.bit-panel button.text-button {
  min-width: 14px;
  min-height: 12px;
  padding: 0;
}

.small .card {
  border-radius: 0;
}

.small .card.display-container {
  border-width: 0;
}

.small .card.bit-panel {
  border-width: 1px 0;
}

.small .card + widget > stack {
  border-top: 1px solid rgba(255, 255, 255, 0.13);
}

.math-buttons .buttons {
  min-width: 0;
  min-height: 0;
}

.math-buttons button,
.math-buttons button.text-button,
.math-buttons menubutton > button,
.math-buttons menubutton > button.text-button {
  min-width: 16px;
  padding: 2px 4px;
}

.math-buttons button.number-button {
  background-image: image(rgba(255, 255, 255, 0.07));
}

@define-color weather_temp_chart_fill_color rgba(208, 132, 108, 0.5);
@define-color weather_temp_chart_stroke_color #c46445;
@define-color weather_thermometer_warm_color #FFD97A;
@define-color weather_thermometer_cold_color #5E8FFF;
#places-label {
  font-weight: bold;
}

#temperature-label {
  font-size: 32pt;
  font-weight: 900;
  margin-left: 9px;
}

#conditions-grid *:backdrop {
  color: rgba(200, 215, 240, 0.85);
}

.content-view.cell {
  font-weight: bold;
}

#locationEntry {
  margin: 6px;
}

.weather-popover {
  margin-top: 6px;
}

.forecast-card {
  transition: border-radius 100ms ease-out;
  border-radius: 6px;
}

.forecast-card separator {
  background-color: rgba(255, 255, 255, 0.13);
}

#daily-forecast-box > separator:last-child {
  background-color: transparent;
  min-width: 0;
}

#conditions-grid,
#attributionGrid {
  margin-left: 18px;
  margin-right: 18px;
}

#weather-page .small .forecast-card {
  margin-left: 0;
  margin-right: 0;
  border-radius: 0;
  border-width: 1px 0;
}

.forecast-temperature-label {
  font-weight: bold;
  color: #ae7b03;
}

WeatherThermometer {
  margin-bottom: 12px;
}

WeatherThermometer > label.high {
  font-weight: bold;
  color: #FFD97A;
}

WeatherThermometer > label.low {
  font-weight: bold;
  color: #5E8FFF;
}

.forecast-button {
  margin: 0 12px;
}

.forecast-button > button.image-button {
  min-height: 28px;
  min-width: 28px;
  padding: 0;
  border-radius: 9999px;
}

.forecast-graphic {
  margin: 18px;
}

button.osd.circular > image {
  padding: 0;
}

scrolledwindow.inline list,
scrolledwindow.inline listview {
  background: none;
  color: inherit;
}

scrolledwindow.inline undershoot.top {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
}

.search-view {
  background-color: #5271ad;
  color: #ffffff;
}

.search-view menubutton button:focus:focus-visible {
  outline-color: rgba(255, 255, 255, 0.3);
}

image.circular {
  min-width: 32px;
  min-height: 32px;
  padding: 0;
  border-radius: 9999px;
}

.details-page {
  margin: 24px 0px;
}

.installed-overlay-box {
  font-size: smaller;
  background-color: #5271ad;
  border-radius: 0;
  color: #ffffff;
  text-shadow: 0 1px 0 rgba(0, 0, 0, 0.2);
}

screenshot-carousel box.frame {
  border-width: 1px 0;
  border-radius: 0;
}

screenshot-carousel button,
.featured-carousel button {
  margin: 12px;
}

.screenshot-image-main .image1,
.screenshot-image-main .image2 {
  margin-top: 6px;
  margin-bottom: 12px;
  margin-left: 6px;
  margin-right: 6px;
}

.app-tile-label {
  font-size: 105%;
}

.review-textbox {
  padding: 6px;
}

.origin-rounded-box {
  background-color: alpha(currentColor,0.1);
  border-radius: 9999px;
  padding: 4px;
}

.origin-beta {
  color: #d0846c;
}

.origin-button > button {
  padding: 3px 9px;
}

flowboxchild.card:not(.category-tile) {
  padding: 0;
  border: none;
  box-shadow: none;
  background: none;
}

.category-tile.card {
  padding: 21px;
  border: none;
  border-radius: 6px;
  min-width: 140px;
  font-weight: 900;
  font-size: larger;
}

.category-tile.card.category-tile-iconless {
  padding: 9px 15px;
  min-width: 130px;
  font-size: 105%;
  font-weight: normal;
  box-shadow: none;
}

.category-tile.card.category-create {
  background: linear-gradient(180deg, #ce8cd7 0%, #2861c6 100%);
  color: white;
}

.category-tile.card.category-create:hover {
  background: linear-gradient(180deg, shade(#ce8cd7, 1.07) 0%, shade(#2861c6, 1.1) 100%);
  color: white;
}

.category-tile.card.category-create:active {
  background: linear-gradient(180deg, shade(#ce8cd7, 0.95) 0%, shade(#2861c6, 0.95) 100%);
  color: white;
}

.category-tile.card.category-develop {
  background: #5e5c64;
  color: white;
}

.category-tile.card.category-develop:hover {
  background: shade(#5e5c64, 1.2);
  color: white;
}

.category-tile.card.category-develop:active {
  background-color: shade(#5e5c64, 0.95);
  color: white;
}

.category-tile.card.category-learn {
  background: linear-gradient(180deg, #2ec27e 30%, #27a66c 100%);
  color: white;
}

.category-tile.card.category-learn:hover {
  background: linear-gradient(180deg, shade(#2ec27e, 1.06) 30%, shade(#27a66c, 1.06) 100%);
  color: white;
}

.category-tile.card.category-learn:active {
  background: linear-gradient(180deg, shade(#2ec27e, 0.95) 30%, shade(#27a66c, 0.95) 100%);
  color: white;
}

.category-tile.card.category-play {
  background: linear-gradient(75deg, #f9e2a7 0%, #eb5ec3 50%, #6d53e0 100%);
  color: #393484;
}

.category-tile.card.category-play:hover {
  background: linear-gradient(75deg, shade(#f9e2a7, 1.07) 0%, shade(#eb5ec3, 1.07) 50%, shade(#6d53e0, 1.07) 100%);
  color: #393484;
}

.category-tile.card.category-play:active {
  background: linear-gradient(75deg, shade(#f9e2a7, 0.97) 0%, shade(#eb5ec3, 0.95) 50%, shade(#6d53e0, 1.07) 100%);
  color: #393484;
}

.category-tile.card.category-socialize {
  background: linear-gradient(90deg, #ef4e9b 0%, #f77466 100%);
  color: #fac7d1;
}

.category-tile.card.category-socialize:hover {
  background: linear-gradient(90deg, shade(#ef4e9b, 1.08) 0%, shade(#f77466, 1.08) 100%);
  color: #fac7d1;
}

.category-tile.card.category-socialize:active {
  background: linear-gradient(90deg, shade(#ef4e9b, 0.95) 0%, shade(#f77466, 0.95) 100%);
  color: #fac7d1;
}

.category-tile.card.category-work {
  padding: 1px;
  /* FIXME: work around https://gitlab.gnome.org/GNOME/gtk/-/issues/4324 */
  color: #1c71d8;
  background-color: #fdf8d7;
  background-image: linear-gradient(rgba(255, 255, 255, 0.13) 1px, transparent 1px), linear-gradient(90deg, rgba(255, 255, 255, 0.13) 1px, transparent 1px);
  background-size: 10px 10px, 10px 10px;
  background-position: -1px -4px, center -1px;
}

.category-tile.card.category-work:hover {
  color: #1c71d8;
  background-color: #fefcef;
  background-image: linear-gradient(rgba(255, 255, 255, 0.13) 1px, transparent 1px), linear-gradient(90deg, rgba(255, 255, 255, 0.13) 1px, transparent 1px);
}

.category-tile.card.category-work:active {
  color: #1c71d8;
  background-color: #fcf4bf;
  background-image: linear-gradient(rgba(255, 255, 255, 0.13) 1px, transparent 1px), linear-gradient(90deg, rgba(255, 255, 255, 0.13) 1px, transparent 1px);
}

clamp.medium .category-tile:not(.category-tile-iconless),
clamp.large .category-tile:not(.category-tile-iconless) {
  font-size: larger;
}

.featured-tile {
  padding: 0;
  box-shadow: none;
}

.featured-tile label.title-1 {
  margin-top: 6px;
  margin-bottom: 6px;
}

.featured-tile.narrow label.title-1 {
  font-size: 16pt;
}

.application-details-infobar, .application-details-infobar.info {
  background-color: alpha(currentColor,0.05);
  color: #e8edf8;
  border: 1px solid rgba(255, 255, 255, 0.13);
}

.application-details-infobar.warning {
  background-color: #d0846c;
  color: #ffffff;
  border: 1px solid alpha(currentColor,0.1);
}

@keyframes install-progress-unknown-move {
  0% {
    background-position: 0%;
  }
  50% {
    background-position: 100%;
  }
  100% {
    background-position: 0%;
  }
}

.application-details-description .button {
  padding-left: 24px;
  padding-right: 24px;
}

.install-progress {
  background-image: linear-gradient(to top, #5271ad 2px, alpha(#5271ad,0) 2px);
  background-repeat: no-repeat;
  background-position: 0 bottom;
  background-size: 0;
  transition: none;
}

.install-progress:dir(rtl) {
  background-position: 100% bottom;
}

.review-row > * {
  margin: 12px;
}

.review-row button {
  font-size: smaller;
}

.review-row .vote-buttons button {
  margin-right: -1px;
}

.review-row .vote-buttons button:not(:first-child) {
  border-image: linear-gradient(to top, rgba(255, 255, 255, 0.13), rgba(255, 255, 255, 0.13)) 0 0 0 1/5px 0 5px 1px;
}

.review-row .vote-buttons button:hover,
.review-row .vote-buttons button:active,
.review-row .vote-buttons button:hover + button,
.review-row .vote-buttons button:active + button {
  border-image: none;
}

review-bar {
  color: rgba(160, 180, 220, 0.4);
  background-image: none;
  background-color: alpha(currentColor,0.16);
}

.review-histogram star-image {
  color: rgba(160, 180, 220, 0.4);
}

.version-arrow-label {
  font-size: x-small;
}

.overview-more-button {
  font-size: smaller;
  padding: 0 16px;
}

.app-row-origin-text {
  font-size: smaller;
}

.app-listbox-header {
  padding: 6px;
  border-bottom: 1px solid rgba(255, 255, 255, 0.13);
}

.image-list {
  background-color: transparent;
}

box.star {
  background-color: transparent;
  background-image: none;
}

button.star {
  outline-offset: 0;
  background-color: transparent;
  background-image: none;
  border-image: none;
  border-radius: 0;
  border-width: 0;
  padding: 0;
  box-shadow: none;
  outline-offset: -1px;
}

star-image {
  color: #FFD97A;
}

.dimmer-label {
  opacity: 0.25;
}

.update-failed-details {
  font-family: Monospace;
  font-size: smaller;
  padding: 16px;
}

.upgrade-banner {
  padding: 0px;
  border-radius: 6px;
  border: none;
}

.upgrade-banner-background {
  background: linear-gradient(to bottom, #82ac5d, #4c7bd9);
  color: white;
}

.upgrade-buttons #button_upgrades_install {
  padding-left: 16px;
  padding-right: 16px;
}

scrolledwindow.list-page > viewport > clamp > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

.update-preferences preferencesgroup > box > box {
  margin-top: 18px;
}

.section > label:not(:first-child) {
  margin-top: 6px;
}

.section > box:not(:first-child) {
  margin-top: 12px;
}

clamp.status-page {
  margin: 36px 12px;
}

clamp.status-page .iconbox {
  min-height: 128px;
  min-width: 128px;
}

clamp.status-page .icon {
  color: rgba(160, 180, 220, 0.4);
  min-height: 32px;
  min-width: 32px;
}

clamp.status-page .icon:not(:last-child) {
  margin-bottom: 36px;
}

clamp.status-page .title:not(:last-child) {
  margin-bottom: 12px;
}

app-context-bar .context-tile {
  border: 1px solid rgba(255, 255, 255, 0.13);
  background-color: transparent;
  border-radius: 0;
  padding: 24px 12px 21px 12px;
  outline-offset: 5px;
  transition-property: outline, outline-offset, background-image;
  border-bottom: none;
  border-right: none;
}

app-context-bar .context-tile:hover {
  background-image: none;
  background-color: alpha(currentColor,0.1);
}

app-context-bar .context-tile.keyboard-activating, app-context-bar .context-tile:active {
  background-color: alpha(currentColor,0.16);
}

app-context-bar .context-tile:focus:focus-visible {
  outline-offset: -1px;
}

app-context-bar.horizontal box:first-child .context-tile:first-child, app-context-bar.vertical .context-tile:first-child {
  border-left: none;
}

app-context-bar.horizontal .context-tile, app-context-bar.vertical box:first-child .context-tile {
  border-top: none;
}

app-context-bar > box:not(:first-child) > button.flat {
  border-radius: 0;
}

app-context-bar > box:not(:first-child) > button.flat:last-child {
  border-radius: 0 6px 6px 0;
}

app-context-bar > box:first-child > button.flat {
  border-radius: 0;
}

app-context-bar > box:first-child > button.flat:first-child {
  border-radius: 6px 0 0 6px;
}

app-context-bar > box > button.flat {
  border-left-color: rgba(255, 255, 255, 0.13);
}

carousel.card {
  border: none;
  background-color: alpha(currentColor,0.05);
}

.context-tile-lozenge {
  min-height: 28px;
  min-width: 28px;
  padding: 6px;
  font-size: 18px;
  font-weight: bold;
  border-radius: 9999px;
}

.context-tile-lozenge.large {
  font-size: 24px;
  padding: 16px;
  min-width: 24px;
  /* 60px minus the left and right padding */
  min-height: 24px;
  /* 60px minus the top and bottom padding */
}

.context-tile-lozenge.wide-image image {
  margin-top: -28px;
  margin-bottom: -28px;
}

.context-tile-lozenge image {
  -gtk-icon-style: symbolic;
}

.context-tile-lozenge.grey {
  color: #e8edf8;
  background-color: alpha(currentColor,0.1);
}

.context-tile-lozenge.green, .context-tile-lozenge.details-rating-0 {
  color: #46c16d;
  background-color: alpha(#7FD49A,0.15);
}

.context-tile-lozenge.blue, .context-tile-lozenge.details-rating-5 {
  color: #5E8FFF;
  background-color: alpha(#5E8FFF,0.15);
}

.context-tile-lozenge.yellow, .context-tile-lozenge.details-rating-12 {
  color: #ffc32e;
  background-color: alpha(#FFD97A,0.15);
}

.context-tile-lozenge.details-rating-15 {
  color: #FFB070;
  background-color: alpha(#FFB070,0.15);
}

.context-tile-lozenge.red, .context-tile-lozenge.details-rating-18 {
  color: #ff2e2e;
  background-color: alpha(#FF7A7A,0.15);
}

.eol-red {
  font-weight: bold;
  color: #c35b65;
}

window.narrow .app-title {
  font-size: 16pt;
}

window.narrow .app-developer {
  font-size: small;
}

.install-progress-label {
  font-size: smaller;
  font-feature-settings: "tnum";
}

scrolledwindow.fake-adw-status-page > viewport > box {
  margin: 36px 12px;
}

scrolledwindow.fake-adw-status-page > viewport > box > clamp:not(:last-child) > box {
  margin-bottom: 36px;
}

scrolledwindow.fake-adw-status-page > viewport > box > clamp > box > .icon:not(:last-child) {
  margin-bottom: 36px;
}

scrolledwindow.fake-adw-status-page > viewport > box > clamp > box > .title:not(:last-child) {
  margin-bottom: 12px;
}

window.info scrollbar.vertical {
  margin-top: 48px;
  background: none;
  box-shadow: none;
}

window.info scrollbar.vertical trough {
  margin-top: 0;
}

row.app > box.header {
  margin-left: 12px;
  margin-right: 12px;
}

row.app > box.header {
  border-spacing: 12px;
}

row.app > box.header > image {
  margin-top: 12px;
  margin-bottom: 12px;
}

row.app label.warning {
  color: #d0846c;
}

@keyframes pre-delay {
  from {
    opacity: 0;
  }
  to {
    opacity: 0;
  }
}

@keyframes fade-in {
  from {
    filter: opacity(0%);
  }
}

/* Give a fade-in animation to spinners. */
spinner.fade-in:checked {
  animation: pre-delay 0.5s linear 1, fade-in 1s linear 1, spin 1s linear infinite;
  animation-delay: 0s, 0.5s, 0.5s;
}

window.background.csd > dialog-host > widget > widget > box > leaflet stack.background {
  background-color: rgba(8, 14, 36, 0.42);
}

popover.background.global-search > arrow,
popover.background.global-search > contents {
  padding: 0;
}

popover.background.pages-popover listview > row {
  padding: 4px;
}

popover.background.pages-popover listview > row button {
  margin: 0;
}

popover.background.pages-popover listview > row check {
  margin: 4px 2px;
  -gtk-icon-size: 12px;
}

panelresizer .top-bar {
  border-bottom: 1px solid mix(black,#2e3440,0.25);
}

panelframetabbar.frameheader.header {
  min-height: 28px;
  padding: 0;
  border: none;
  border-bottom: 1px solid rgba(255, 255, 255, 0.13);
}

panelframetabbar.frameheader.header tabbar.inline .start-action {
  padding: 0 3px;
}

panelframetabbar.frameheader.header tabbar.inline .end-action {
  padding: 0 3px;
}

panelframeswitcher:not(.vertical).frameheader.header {
  min-height: 28px;
  padding: 5px 6px;
  border: none;
}

panelframeswitcher:not(.vertical) > button.toggle.image-button {
  border: none;
  min-height: 22px;
  padding: 2px 6px;
}

panelframeswitcher.frameheader.header.vertical > button.toggle.image-button {
  min-height: 24px;
  min-width: 24px;
  padding: 4px;
}

panelstatusbar {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
}

panelstatusbar > menubutton > button,
panelstatusbar > paneltogglebutton button {
  border-radius: 0;
}

panelwidget entry.statusbar {
  background-color: rgba(12, 20, 48, 0.52);
  border-radius: 0;
  outline: none;
  box-shadow: none;
  border-top: 1px solid rgba(255, 255, 255, 0.13);
}

panelwidget entry.statusbar:focus-within {
  outline: none;
}

.style-variant {
  padding: 0 8px;
}

.style-variant button.toggle {
  padding: 0;
}

.style-variant button.toggle, .style-variant button.toggle:hover, .style-variant button.toggle:focus, .style-variant button.toggle:active, .style-variant button.toggle:checked {
  background: none;
  outline: none;
  border: none;
  box-shadow: none;
}

.style-variant button.toggle > stylevariantpreview > .wallpaper {
  border-radius: 6px;
  outline-color: transparent;
  outline-width: 3px;
  outline-offset: 2px;
  outline-style: solid;
  box-shadow: none;
}

.style-variant button.toggle:hover > stylevariantpreview > .wallpaper {
  outline-color: alpha(currentColor,0.05);
}

.style-variant button.toggle:active > stylevariantpreview > .wallpaper {
  outline-color: alpha(currentColor,0.15);
}

.style-variant button.toggle:checked > stylevariantpreview > .wallpaper {
  outline-color: #5271ad;
}

popover.details-popover .actions {
  border-spacing: 6px;
}

popover.details-popover .actions > button {
  padding: 8px;
}

window.shortcuts headerbar > windowhandle {
  padding: 0;
}

.ptyxis-window vte-terminal {
  background: none;
}

.ptyxis-window .thumbnail button.tab-close-button {
  padding: 0;
}

.ptyxis-window .thumbnail button.tab-close-button, .ptyxis-window .thumbnail button.tab-close-button:hover, .ptyxis-window .thumbnail button.tab-close-button:active {
  background: none;
  border: none;
}

preferencesgroup flowbox > flowboxchild {
  padding: 0;
  border: none;
  border-radius: 11px;
}

preferencesgroup flowbox > flowboxchild > button.palette {
  margin: 3px;
  padding: 0;
  border-radius: 8px;
  border: 1px solid rgba(255, 255, 255, 0.13);
}

preferencesgroup flowbox > flowboxchild > button.palette.selected {
  border-color: #5271ad;
  box-shadow: 0 0 0 2px #5271ad;
}

preferencesgroup flowbox > flowboxchild > button.palette > palettepreview {
  border-radius: 8px;
  margin: 0;
}

preferencesgroup flowbox > flowboxchild > button.palette > palettepreview palettepreviewcolor {
  border-radius: 3px;
}

#desktopwindow.background {
  background-color: transparent;
  background-image: none;
}

window.nightthemeswitcher headerbar {
  background: rgba(10, 18, 45, 0.55);
  color: rgba(230, 238, 255, 0.95);
}

dialog-host > widget > widget > toolbarview > box > entry.search {
  margin: 8px 0;
}

dialog-host > widget > widget > toolbarview > box > entry.search + toastoverlay > stack {
  border-top: 1px solid mix(black,#2e3440,0.25);
}

window.background.chromium headerbar.header-bar.titlebar button.titlebutton {
  min-width: 16px;
  min-height: 16px;
  margin: 0 3px;
  padding: 0;
  border-radius: 9999px;
  background-image: none;
  border: none;
}

window.background.chromium headerbar.header-bar.titlebar button.close.titlebutton {
  background-color: #e9524a;
  color: #e9524a;
}

window.background.chromium headerbar.header-bar.titlebar button.close.titlebutton:hover {
  background-color: #e9524a;
  color: mix(black,#e9524a,0.5);
}

window.background.chromium headerbar.header-bar.titlebar button.close.titlebutton:active {
  background-color: #ba423b;
  color: mix(black,#ba423b,0.5);
}

window.background.chromium headerbar.header-bar.titlebar button.minimize.titlebutton {
  background-color: #f1ae1b;
  color: #f1ae1b;
}

window.background.chromium headerbar.header-bar.titlebar button.minimize.titlebutton:hover {
  background-color: #f1ae1b;
  color: mix(black,#f1ae1b,0.5);
}

window.background.chromium headerbar.header-bar.titlebar button.minimize.titlebutton:active {
  background-color: #c18b16;
  color: mix(black,#c18b16,0.5);
}

window.background.chromium headerbar.header-bar.titlebar button.maximize.titlebutton {
  background-color: #59c837;
  color: #59c837;
}

window.background.chromium headerbar.header-bar.titlebar button.maximize.titlebutton:hover {
  background-color: #59c837;
  color: mix(black,#59c837,0.5);
}

window.background.chromium headerbar.header-bar.titlebar button.maximize.titlebutton:active {
  background-color: #47a02c;
  color: mix(black,#47a02c,0.5);
}

window.background.chromium {
  box-shadow: 0 12px 20px rgba(0, 0, 0, 0.35), 0 0 0 1px rgba(0, 0, 0, 0.75);
}

window.background.chromium:backdrop {
  transition: box-shadow 150ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: 0 7px 12px rgba(0, 0, 0, 0.15), 0 0 0 1px rgba(0, 0, 0, 0.65);
}

window.background.chromium headerbar.header-bar.titlebar {
  padding: 0 12px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  border-radius: 24px 24px 0 0;
}

.colorpad {
  background-color: @colorpad_color;
  color: @colorpad_fg_color;
}

.colorsetter, .colorsetter:hover, .colorsetter:focus, .colorsetter:active {
  background-color: @colorsetter_color;
  color: @colorsetter_fg_color;
}

.colorsetter:checked {
  background-color: @colorsetter_color;
  color: @colorsetter_fg_color;
  box-shadow: inset 0 -3px @colorsetter_fg_color;
}

avatar {
  border-radius: 9999px;
  font-weight: bold;
}

avatar.color1 {
  background-image: linear-gradient(#83b6ec, #337fdc);
  color: #cfe1f5;
}

avatar.color2 {
  background-image: linear-gradient(#7ad9f1, #0f9ac8);
  color: #caeaf2;
}

avatar.color3 {
  background-image: linear-gradient(#8de6b1, #29ae74);
  color: #cef8d8;
}

avatar.color4 {
  background-image: linear-gradient(#b5e98a, #6ab85b);
  color: #e6f9d7;
}

avatar.color5 {
  background-image: linear-gradient(#f8e359, #d29d09);
  color: #f9f4e1;
}

avatar.color6 {
  background-image: linear-gradient(#ffcb62, #d68400);
  color: #ffead1;
}

avatar.color7 {
  background-image: linear-gradient(#ffa95a, #ed5b00);
  color: #ffe5c5;
}

avatar.color8 {
  background-image: linear-gradient(#f78773, #e62d42);
  color: #f8d2ce;
}

avatar.color9 {
  background-image: linear-gradient(#e973ab, #e33b6a);
  color: #fac7de;
}

avatar.color10 {
  background-image: linear-gradient(#cb78d4, #9945b5);
  color: #e7c2e8;
}

avatar.color11 {
  background-image: linear-gradient(#9e91e8, #7a59ca);
  color: #d5d2f5;
}

avatar.color12 {
  background-image: linear-gradient(#e3cf9c, #b08952);
  color: #f2eade;
}

avatar.color13 {
  background-image: linear-gradient(#be916d, #785336);
  color: #e5d6ca;
}

avatar.color14 {
  background-image: linear-gradient(#c0bfbc, #6e6d71);
  color: #d8d7d3;
}

avatar.contrasted {
  color: white;
}

avatar.image {
  background: none;
}

video {
  background: black;
}

video image.osd {
  min-width: 64px;
  min-height: 64px;
  border-radius: 32px;
}

window.about .main-page > viewport > clamp > box,
dialog.about .main-page > viewport > clamp > box {
  margin: 12px;
  border-spacing: 6px;
}

window.about .main-page > viewport > clamp > box > box,
dialog.about .main-page > viewport > clamp > box > box {
  margin-top: 18px;
  border-spacing: 18px;
  margin-bottom: 6px;
}

window.about .main-page .app-version,
dialog.about .main-page .app-version {
  padding: 3px 18px;
  color: #5271ad;
  border-radius: 999px;
  margin-top: 3px;
}

window.about .subpage > viewport > clamp > box,
dialog.about .subpage > viewport > clamp > box {
  margin: 18px 12px;
  border-spacing: 18px;
}

window.about .subpage > clamp > textview,
dialog.about .subpage > clamp > textview {
  background: none;
  color: inherit;
}

preferencespage > scrolledwindow > viewport > clamp > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

preferencesgroup > box, preferencesgroup > box .labels {
  border-spacing: 6px;
}

preferencesgroup > box > box.header:not(.single-line) {
  margin-bottom: 6px;
}

preferencesgroup > box > box.single-line {
  min-height: 34px;
}

preferencesgroup > box grid > box > switch {
  margin: 14px 0;
}

statuspage > scrolledwindow > viewport > box {
  margin: 36px 12px;
  border-spacing: 36px;
}

statuspage > scrolledwindow > viewport > box > clamp > box {
  border-spacing: 12px;
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon {
  -gtk-icon-size: 128px;
  color: alpha(currentColor,0.55);
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:disabled {
  opacity: 0.45;
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) {
  margin-bottom: 24px;
}

statuspage.compact > scrolledwindow > viewport > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon {
  -gtk-icon-size: 96px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) {
  margin-bottom: 12px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .title {
  font-size: 18pt;
}

.osd .card, .card.osd {
  background-color: alpha(currentColor,0.1);
  color: inherit;
  box-shadow: none;
}

.osd .card:focus:focus-visible, .card.osd:focus:focus-visible {
  outline-color: alpha(currentColor,0.05);
}

.card.activatable {
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.card.activatable:hover {
  background-image: image(alpha(currentColor,0.03));
}

.card.activatable:active {
  background-image: image(alpha(currentColor,0.08));
}

toast {
  margin: 12px;
  margin-bottom: 18px;
  border-radius: 9999px;
  border-spacing: 6px;
  padding: 6px;
  box-shadow: 0 3px 8px rgba(0, 0, 0, 0.35), 0 0 0 2px rgba(0, 0, 0, 0.1), 0 0 0 1px rgba(0, 0, 0, 0.75);
  outline: 1px solid rgba(255, 255, 255, 0.1);
  outline-offset: -1px;
}

toast:dir(ltr) {
  padding-left: 12px;
}

toast:dir(rtl) {
  padding-right: 12px;
}

toast > widget {
  margin: 0 6px;
}

viewswitcher {
  margin: 0;
  min-height: 28px;
  border-spacing: 3px;
}

viewswitcher.narrow {
  margin-top: 0;
  margin-bottom: 0;
  min-height: 6px;
}

viewswitcher.narrow > button.toggle image {
  -gtk-icon-size: 12px;
}

viewswitcher.narrow > button.toggle label {
  margin-top: 3px;
  margin-bottom: -2px;
}

viewswitcher button.toggle {
  font-weight: normal;
  padding: 0;
}

viewswitcher button.toggle > stack > box.narrow {
  font-size: 0.75rem;
  padding-top: 8px;
}

viewswitcher button.toggle > stack > box.narrow > label {
  min-height: 18px;
  padding-left: 3px;
  padding-right: 3px;
  padding-bottom: 0;
}

viewswitcher button.toggle > stack > box.wide {
  padding: 0 12px;
  border-spacing: 6px;
}

viewswitcherbar actionbar > revealer > box {
  padding-left: 6px;
  padding-right: 6px;
  padding-top: 6px;
}

viewswitcherbar actionbar > revealer > box viewswitcher.narrow > button.toggle {
  padding: 6px 12px;
  border-radius: 8px;
}

viewswitcherbar actionbar > revealer > box viewswitcher.narrow > button.toggle image {
  -gtk-icon-size: 16px;
}

viewswitcherbar actionbar > revealer > box viewswitcher.narrow > button.toggle label {
  margin-top: 6px;
}

viewswitchertitle {
  margin-top: 0;
  margin-bottom: 0;
}

viewswitchertitle viewswitcher {
  margin-left: 12px;
  margin-right: 12px;
}

viewswitchertitle viewswitcher.wide {
  margin-top: 0;
  margin-bottom: 0;
}

viewswitchertitle windowtitle {
  margin-top: 0;
  margin-bottom: 0;
}

indicatorbin > indicator, indicatorbin > mask {
  min-width: 12px;
  min-height: 12px;
  border-radius: 9999px;
}

indicatorbin > indicator {
  margin: 1px;
  background: alpha(currentColor,0.4);
}

indicatorbin > indicator > label {
  font-size: 0.6rem;
  font-weight: normal;
  padding: 1px 4px;
  color: white;
}

indicatorbin > mask {
  padding: 0;
  background: black;
}

indicatorbin > image {
  -gtk-icon-size: 16px;
  margin-top: -4px;
  margin-bottom: -4px;
}

indicatorbin.needs-attention > indicator {
  background: #5271ad;
}

indicatorbin.needs-attention > indicator > label {
  color: #ffffff;
}

indicatorbin.badge > indicator,
indicatorbin.badge > mask {
  min-height: 13px;
}

indicatorbin.badge > indicator > label {
  font-size: 0.6rem;
  font-weight: bold;
  padding-left: 4px;
  padding-right: 4px;
  color: white;
}

indicatorbin.badge.needs-attention > indicator {
  background: #5271ad;
}

indicatorbin.badge.needs-attention > indicator > label {
  color: #ffffff;
}

headerbar > windowhandle > box viewswitcher {
  min-height: 0;
  border-spacing: 0;
  border-radius: 9999px;
  padding: 3px;
  color: rgba(230, 238, 255, 0.95);
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.03), rgba(255, 255, 255, 0.02));
  box-shadow: 0 6px 20px rgba(0, 0, 0, 0.15), inset 1px 2px 1px -1px rgba(255, 255, 255, 0.08), inset -1px -1px 1px 0 rgba(255, 255, 255, 0.08);
  border: none;
}

headerbar > windowhandle > box viewswitcher:backdrop {
  background-color: alpha(rgba(230, 238, 255, 0.95),0.05);
  background-image: none;
  border: none;
  box-shadow: none;
}

headerbar > windowhandle > box viewswitcher.narrow {
  margin: 0;
  padding: 0;
}

headerbar > windowhandle > box viewswitcher > button.toggle {
  margin: 0;
  min-height: 0;
  font-weight: 500;
  border-radius: 9999px;
}

headerbar > windowhandle > box viewswitcher > button.toggle:not(:first-child) {
  border-width: 0 0 0 1px;
  border-style: none solid none none;
  border-image: linear-gradient(to bottom, transparent 16%, rgba(255, 255, 255, 0.1) 16%, rgba(255, 255, 255, 0.1) 84%, transparent 84%) 0 0 0 1/0 0 0 1px stretch;
}

headerbar > windowhandle > box viewswitcher > button.toggle:hover, headerbar > windowhandle > box viewswitcher > button.toggle:active, headerbar > windowhandle > box viewswitcher > button.toggle:checked {
  border-image: none;
}

headerbar > windowhandle > box viewswitcher > button.toggle:hover + button, headerbar > windowhandle > box viewswitcher > button.toggle:active + button, headerbar > windowhandle > box viewswitcher > button.toggle:checked + button {
  border-image: none;
}

tabbar tabbox > tab,
tabbar tabbox > tabboxchild > tab {
  color: rgba(160, 180, 220, 0.4);
  background-color: transparent;
  border: none;
  transition: all 150ms ease-out;
  border-radius: 9999px;
  padding: 2px 5px;
  margin: 0;
}

tabbar tabbox > tab:hover,
tabbar tabbox > tabboxchild > tab:hover {
  color: rgba(180, 198, 228, 0.6);
  background-color: alpha(currentColor,0.1);
}

tabbar tabbox > tab:active,
tabbar tabbox > tabboxchild > tab:active {
  color: #e8edf8;
  background-color: alpha(currentColor,0.2);
}

tabbar tabbox > tab:checked,
tabbar tabbox > tabboxchild > tab:checked, tabbar tabbox > tab:selected,
tabbar tabbox > tabboxchild > tab:selected {
  color: #e8edf8;
  background-color: alpha(currentColor,0.12);
  box-shadow: 0 2px 3px rgba(0, 0, 0, 0.08), inset 1px 2px 1px -1px rgba(255, 255, 255, 0.08), inset -1px -1px 1px -1px rgba(255, 255, 255, 0.1);
}

tabbar .start-action,
tabbar .end-action {
  padding: 6px;
}

tabbar .start-action button,
tabbar .end-action button {
  min-height: 28px;
  min-width: 28px;
  padding: 2px;
  border-radius: 9999px;
}

tabbar .start-action:dir(ltr),
tabbar .end-action:dir(rtl) {
  padding-right: 0;
}

tabbar .start-action:dir(rtl),
tabbar .end-action:dir(ltr) {
  padding-left: 0;
}

tabbar .box {
  min-height: 28px;
  color: #dce4f5;
  margin: 2px 6px;
  box-shadow: none;
  border: none;
  padding: 2px 0;
  background-color: alpha(currentColor,0.05);
  border-radius: 9999px;
}

tabbar:backdrop .box > scrolledwindow,
tabbar:backdrop .box > .start-action,
tabbar:backdrop .box > .end-action {
  filter: opacity(0.5);
}

tabbar.inline .box {
  min-height: 28px;
  margin: 0;
  padding: 3px;
  background-color: transparent;
  border-radius: 0;
}

tabbar tabbox {
  border: none;
  padding: 0;
  box-shadow: none;
  background-color: transparent;
  min-height: 28px;
  margin: 0 -3px;
}

tabbar tabbox > separator {
  margin: 6px 0;
  background-color: rgba(255, 255, 255, 0.13);
}

tabbar tabbox > separator.hidden {
  opacity: 0;
}

tabbar tabbox > revealer > indicator {
  min-width: 2px;
  border-radius: 2px;
  background: alpha(#5271ad,0.5);
  margin: 3px 6px;
}

tabbar tabbox > tabboxchild {
  margin: 0;
}

tabbar tabbox > tab button.tab-close-button,
tabbar tabbox > tabboxchild > tab button.tab-close-button {
  border-radius: 9999px;
  border: none;
  padding: 3px;
  min-height: 16px;
  min-width: 16px;
}

tabbar tabbox > tab button.tab-close-button:hover,
tabbar tabbox > tabboxchild > tab button.tab-close-button:hover {
  color: #e8edf8;
  background-color: alpha(currentColor,0.1);
}

tabbar tabbox > tab button.tab-close-button:active, tabbar tabbox > tab button.tab-close-button:active:hover,
tabbar tabbox > tabboxchild > tab button.tab-close-button:active,
tabbar tabbox > tabboxchild > tab button.tab-close-button:active:hover {
  color: #dce4f5;
  background-color: alpha(currentColor,0.2);
}

dnd tab {
  margin: 0;
}

dnd tab button.tab-close-button {
  border-radius: 3px;
  min-height: 20px;
  min-width: 20px;
  padding: 0;
}

dnd tab indicator {
  min-height: 2px;
  border-radius: 2px;
  background: alpha(#5271ad,0.5);
}

tabview:drop(active),
tabbox:drop(active) {
  box-shadow: none;
}

flap > dimming,
leaflet > dimming,
navigation-view > dimming,
overlay-split-view > dimming {
  background: none;
}

flap > border,
leaflet > border,
navigation-view > border,
overlay-split-view > border {
  background: none;
}

flap > shadow,
leaflet > shadow,
navigation-view > shadow,
overlay-split-view > shadow {
  min-width: 56px;
  min-height: 56px;
}

flap > shadow.left,
leaflet > shadow.left,
navigation-view > shadow.left,
overlay-split-view > shadow.left {
  background-image: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.22),0.7), alpha(rgba(0, 0, 0, 0.22),0.14) 40px, alpha(rgba(0, 0, 0, 0.22),0) 56px), linear-gradient(to right, alpha(rgba(0, 0, 0, 0.22),0.4), alpha(rgba(0, 0, 0, 0.22),0.14) 7px, alpha(rgba(0, 0, 0, 0.22),0) 24px);
}

flap > shadow.right,
leaflet > shadow.right,
navigation-view > shadow.right,
overlay-split-view > shadow.right {
  background-image: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.22),0.7), alpha(rgba(0, 0, 0, 0.22),0.14) 40px, alpha(rgba(0, 0, 0, 0.22),0) 56px), linear-gradient(to left, alpha(rgba(0, 0, 0, 0.22),0.4), alpha(rgba(0, 0, 0, 0.22),0.14) 7px, alpha(rgba(0, 0, 0, 0.22),0) 24px);
}

flap > shadow.up,
leaflet > shadow.up,
navigation-view > shadow.up,
overlay-split-view > shadow.up {
  background-image: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.22),0.7), alpha(rgba(0, 0, 0, 0.22),0.14) 40px, alpha(rgba(0, 0, 0, 0.22),0) 56px), linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.22),0.4), alpha(rgba(0, 0, 0, 0.22),0.14) 7px, alpha(rgba(0, 0, 0, 0.22),0) 24px);
}

flap > shadow.down,
leaflet > shadow.down,
navigation-view > shadow.down,
overlay-split-view > shadow.down {
  background-image: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.22),0.7), alpha(rgba(0, 0, 0, 0.22),0.14) 40px, alpha(rgba(0, 0, 0, 0.22),0) 56px), linear-gradient(to top, alpha(rgba(0, 0, 0, 0.22),0.4), alpha(rgba(0, 0, 0, 0.22),0.14) 7px, alpha(rgba(0, 0, 0, 0.22),0) 24px);
}

toolbarview.undershoot-top scrolledwindow > undershoot.top {
  box-shadow: none;
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom {
  box-shadow: none;
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

.unfolded stacksidebar.sidebar {
  border: none;
}

.sidebar-pane .sidebar-pane {
  background-color: transparent;
  background-image: none;
  color: inherit;
}

.sidebar-pane list:not(.boxed-list),
.sidebar-pane .frame,
.sidebar-pane .sidebar,
.sidebar-pane .toolbar,
.sidebar-pane headerbar,
.sidebar-pane .navigation-sidebar,
.sidebar-pane searchbar > revealer > box {
  background-color: transparent;
  box-shadow: none;
  border: none;
}

.sidebar-pane entry.search {
  min-height: 26px;
  padding: 3px 8px;
}

.sidebar-pane .toolbar {
  padding: 6px 12px;
}

.sidebar-pane .navigation-sidebar:not(.view) {
  padding: 10px;
}

.sidebar-pane .navigation-sidebar:not(.view) > row:selected {
  background-color: #5271ad;
  color: #ffffff;
}

.sidebar-pane,
.content-pane .sidebar-pane,
.sidebar-pane .content-pane {
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.03), transparent 80%, rgba(255, 255, 255, 0.03));
  color: rgba(210, 222, 248, 0.9);
  border-radius: 18px;
  background-color: alpha(#e8edf8,0.015);
}

.sidebar-pane flap > dimming,
.sidebar-pane leaflet > dimming,
.sidebar-pane navigation-view > dimming,
.sidebar-pane overlay-split-view > dimming,
.content-pane .sidebar-pane flap > dimming,
.content-pane .sidebar-pane leaflet > dimming,
.content-pane .sidebar-pane navigation-view > dimming,
.content-pane .sidebar-pane overlay-split-view > dimming,
.sidebar-pane .content-pane flap > dimming,
.sidebar-pane .content-pane leaflet > dimming,
.sidebar-pane .content-pane navigation-view > dimming,
.sidebar-pane .content-pane overlay-split-view > dimming {
  background: none;
}

.sidebar-pane flap > border,
.sidebar-pane leaflet > border,
.sidebar-pane navigation-view > border,
.sidebar-pane overlay-split-view > border,
.content-pane .sidebar-pane flap > border,
.content-pane .sidebar-pane leaflet > border,
.content-pane .sidebar-pane navigation-view > border,
.content-pane .sidebar-pane overlay-split-view > border,
.sidebar-pane .content-pane flap > border,
.sidebar-pane .content-pane leaflet > border,
.sidebar-pane .content-pane navigation-view > border,
.sidebar-pane .content-pane overlay-split-view > border {
  background: none;
}

.sidebar-pane flap > shadow,
.sidebar-pane leaflet > shadow,
.sidebar-pane navigation-view > shadow,
.sidebar-pane overlay-split-view > shadow,
.content-pane .sidebar-pane flap > shadow,
.content-pane .sidebar-pane leaflet > shadow,
.content-pane .sidebar-pane navigation-view > shadow,
.content-pane .sidebar-pane overlay-split-view > shadow,
.sidebar-pane .content-pane flap > shadow,
.sidebar-pane .content-pane leaflet > shadow,
.sidebar-pane .content-pane navigation-view > shadow,
.sidebar-pane .content-pane overlay-split-view > shadow {
  min-width: 56px;
  min-height: 56px;
}

.sidebar-pane flap > shadow.left,
.sidebar-pane leaflet > shadow.left,
.sidebar-pane navigation-view > shadow.left,
.sidebar-pane overlay-split-view > shadow.left,
.content-pane .sidebar-pane flap > shadow.left,
.content-pane .sidebar-pane leaflet > shadow.left,
.content-pane .sidebar-pane navigation-view > shadow.left,
.content-pane .sidebar-pane overlay-split-view > shadow.left,
.sidebar-pane .content-pane flap > shadow.left,
.sidebar-pane .content-pane leaflet > shadow.left,
.sidebar-pane .content-pane navigation-view > shadow.left,
.sidebar-pane .content-pane overlay-split-view > shadow.left {
  background-image: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.22),0.7), alpha(rgba(0, 0, 0, 0.22),0.14) 40px, alpha(rgba(0, 0, 0, 0.22),0) 56px), linear-gradient(to right, alpha(rgba(0, 0, 0, 0.22),0.4), alpha(rgba(0, 0, 0, 0.22),0.14) 7px, alpha(rgba(0, 0, 0, 0.22),0) 24px);
}

.sidebar-pane flap > shadow.right,
.sidebar-pane leaflet > shadow.right,
.sidebar-pane navigation-view > shadow.right,
.sidebar-pane overlay-split-view > shadow.right,
.content-pane .sidebar-pane flap > shadow.right,
.content-pane .sidebar-pane leaflet > shadow.right,
.content-pane .sidebar-pane navigation-view > shadow.right,
.content-pane .sidebar-pane overlay-split-view > shadow.right,
.sidebar-pane .content-pane flap > shadow.right,
.sidebar-pane .content-pane leaflet > shadow.right,
.sidebar-pane .content-pane navigation-view > shadow.right,
.sidebar-pane .content-pane overlay-split-view > shadow.right {
  background-image: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.22),0.7), alpha(rgba(0, 0, 0, 0.22),0.14) 40px, alpha(rgba(0, 0, 0, 0.22),0) 56px), linear-gradient(to left, alpha(rgba(0, 0, 0, 0.22),0.4), alpha(rgba(0, 0, 0, 0.22),0.14) 7px, alpha(rgba(0, 0, 0, 0.22),0) 24px);
}

.sidebar-pane flap > shadow.up,
.sidebar-pane leaflet > shadow.up,
.sidebar-pane navigation-view > shadow.up,
.sidebar-pane overlay-split-view > shadow.up,
.content-pane .sidebar-pane flap > shadow.up,
.content-pane .sidebar-pane leaflet > shadow.up,
.content-pane .sidebar-pane navigation-view > shadow.up,
.content-pane .sidebar-pane overlay-split-view > shadow.up,
.sidebar-pane .content-pane flap > shadow.up,
.sidebar-pane .content-pane leaflet > shadow.up,
.sidebar-pane .content-pane navigation-view > shadow.up,
.sidebar-pane .content-pane overlay-split-view > shadow.up {
  background-image: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.22),0.7), alpha(rgba(0, 0, 0, 0.22),0.14) 40px, alpha(rgba(0, 0, 0, 0.22),0) 56px), linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.22),0.4), alpha(rgba(0, 0, 0, 0.22),0.14) 7px, alpha(rgba(0, 0, 0, 0.22),0) 24px);
}

.sidebar-pane flap > shadow.down,
.sidebar-pane leaflet > shadow.down,
.sidebar-pane navigation-view > shadow.down,
.sidebar-pane overlay-split-view > shadow.down,
.content-pane .sidebar-pane flap > shadow.down,
.content-pane .sidebar-pane leaflet > shadow.down,
.content-pane .sidebar-pane navigation-view > shadow.down,
.content-pane .sidebar-pane overlay-split-view > shadow.down,
.sidebar-pane .content-pane flap > shadow.down,
.sidebar-pane .content-pane leaflet > shadow.down,
.sidebar-pane .content-pane navigation-view > shadow.down,
.sidebar-pane .content-pane overlay-split-view > shadow.down {
  background-image: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.22),0.7), alpha(rgba(0, 0, 0, 0.22),0.14) 40px, alpha(rgba(0, 0, 0, 0.22),0) 56px), linear-gradient(to top, alpha(rgba(0, 0, 0, 0.22),0.4), alpha(rgba(0, 0, 0, 0.22),0.14) 7px, alpha(rgba(0, 0, 0, 0.22),0) 24px);
}

.sidebar-pane banner > revealer > widget,
.content-pane .sidebar-pane banner > revealer > widget,
.sidebar-pane .content-pane banner > revealer > widget {
  background-color: mix(#5271ad,rgba(8, 14, 36, 0.42),0.7);
  color: #dce4f5;
}

.sidebar-pane banner > revealer > widget:backdrop,
.content-pane .sidebar-pane banner > revealer > widget:backdrop,
.sidebar-pane .content-pane banner > revealer > widget:backdrop {
  background-color: mix(#5271ad,rgba(8, 14, 36, 0.42),0.7);
}

.sidebar-pane:dir(ltr),
.content-pane .sidebar-pane:dir(ltr),
.sidebar-pane .content-pane:dir(ltr) {
  margin: 6px 0 6px 6px;
}

.sidebar-pane:dir(rtl),
.content-pane .sidebar-pane:dir(rtl),
.sidebar-pane .content-pane:dir(rtl) {
  margin: 6px 6px 6px 0;
}

.sidebar-pane:dir(ltr), .sidebar-pane:dir(ltr) banner > revealer > widget,
.content-pane .sidebar-pane:dir(ltr),
.content-pane .sidebar-pane:dir(ltr) banner > revealer > widget,
.sidebar-pane .content-pane:dir(ltr),
.sidebar-pane .content-pane:dir(ltr) banner > revealer > widget {
  box-shadow: 2px 3px 12px rgba(0, 0, 0, 0.1), inset 0 0 0 1px rgba(255, 255, 255, 0.06);
  border-right: none;
}

.sidebar-pane:dir(rtl), .sidebar-pane:dir(rtl) banner > revealer > widget,
.content-pane .sidebar-pane:dir(rtl),
.content-pane .sidebar-pane:dir(rtl) banner > revealer > widget,
.sidebar-pane .content-pane:dir(rtl),
.sidebar-pane .content-pane:dir(rtl) banner > revealer > widget {
  box-shadow: -2px 3px 12px rgba(0, 0, 0, 0.1), inset 0 0 0 1px rgba(255, 255, 255, 0.06);
  border-left: none;
}

.sidebar-pane.end:dir(rtl), .sidebar-pane.end:dir(ltr),
.content-pane .sidebar-pane.end:dir(rtl),
.content-pane .sidebar-pane.end:dir(ltr),
.sidebar-pane .content-pane.end:dir(rtl),
.sidebar-pane .content-pane.end:dir(ltr) {
  margin: 0;
  border-radius: 0;
}

.sidebar-pane.end:dir(rtl), .sidebar-pane.end:dir(rtl) banner > revealer > widget,
.content-pane .sidebar-pane.end:dir(rtl),
.content-pane .sidebar-pane.end:dir(rtl) banner > revealer > widget,
.sidebar-pane .content-pane.end:dir(rtl),
.sidebar-pane .content-pane.end:dir(rtl) banner > revealer > widget {
  box-shadow: none;
  border-right: 1px solid mix(black,#2e3440,0.25);
}

.sidebar-pane.end:dir(ltr), .sidebar-pane.end:dir(ltr) banner > revealer > widget,
.content-pane .sidebar-pane.end:dir(ltr),
.content-pane .sidebar-pane.end:dir(ltr) banner > revealer > widget,
.sidebar-pane .content-pane.end:dir(ltr),
.sidebar-pane .content-pane.end:dir(ltr) banner > revealer > widget {
  box-shadow: none;
  border-left: 1px solid mix(black,#2e3440,0.25);
}

.sidebar-pane:backdrop,
.content-pane .sidebar-pane:backdrop,
.sidebar-pane .content-pane:backdrop {
  transition: background-color 150ms cubic-bezier(0, 0, 0.2, 1);
  background-color: alpha(rgba(230, 238, 255, 0.95),0.05);
  background-image: none;
  border: none;
  box-shadow: none;
}

.sidebar-pane:backdrop:dir(ltr), .sidebar-pane:backdrop:dir(ltr) banner > revealer > widget, .sidebar-pane:backdrop.end:dir(rtl), .sidebar-pane:backdrop.end:dir(rtl) banner > revealer > widget,
.content-pane .sidebar-pane:backdrop:dir(ltr),
.content-pane .sidebar-pane:backdrop:dir(ltr) banner > revealer > widget,
.content-pane .sidebar-pane:backdrop.end:dir(rtl),
.content-pane .sidebar-pane:backdrop.end:dir(rtl) banner > revealer > widget,
.sidebar-pane .content-pane:backdrop:dir(ltr),
.sidebar-pane .content-pane:backdrop:dir(ltr) banner > revealer > widget,
.sidebar-pane .content-pane:backdrop.end:dir(rtl),
.sidebar-pane .content-pane:backdrop.end:dir(rtl) banner > revealer > widget {
  box-shadow: none;
  border-right: none;
}

.sidebar-pane:backdrop:dir(rtl), .sidebar-pane:backdrop:dir(rtl) banner > revealer > widget, .sidebar-pane:backdrop.end:dir(ltr), .sidebar-pane:backdrop.end:dir(ltr) banner > revealer > widget,
.content-pane .sidebar-pane:backdrop:dir(rtl),
.content-pane .sidebar-pane:backdrop:dir(rtl) banner > revealer > widget,
.content-pane .sidebar-pane:backdrop.end:dir(ltr),
.content-pane .sidebar-pane:backdrop.end:dir(ltr) banner > revealer > widget,
.sidebar-pane .content-pane:backdrop:dir(rtl),
.sidebar-pane .content-pane:backdrop:dir(rtl) banner > revealer > widget,
.sidebar-pane .content-pane:backdrop.end:dir(ltr),
.sidebar-pane .content-pane:backdrop.end:dir(ltr) banner > revealer > widget {
  box-shadow: none;
  border-left: none;
}

.content-pane, .content-pane:backdrop {
  background-color: transparent;
}

.content-pane toolbarview, .content-pane toolbarview.view {
  background-color: transparent;
}

.content-pane toolbarview > stack, .content-pane toolbarview > box > stack.view {
  background-color: transparent;
}

.content-pane notebook > stack box > switch {
  margin: 14px 0;
}

.content-pane list.background {
  background-color: transparent;
}

.sidebar-pane headerbar, .sidebar-pane headerbar:backdrop,
.content-pane headerbar,
.content-pane headerbar:backdrop {
  background-color: transparent;
  border: none;
  box-shadow: none;
}

dialog-host toolbarview.undershoot-top scrolledwindow > undershoot.top,
navigation-view-page toolbarview.undershoot-top scrolledwindow > undershoot.top,
.sidebar-pane toolbarview.undershoot-top scrolledwindow > undershoot.top, .content-pane toolbarview.undershoot-top scrolledwindow > undershoot.top,
.content-pane .sidebar-pane toolbarview.undershoot-top scrolledwindow > undershoot.top,
.sidebar-pane .content-pane toolbarview.undershoot-top scrolledwindow > undershoot.top {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

dialog-host toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom,
navigation-view-page toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom,
.sidebar-pane toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom, .content-pane toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom,
.content-pane .sidebar-pane toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom,
.sidebar-pane .content-pane toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom {
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.13);
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

dialog-host scrolledwindow.undershoot-top > undershoot.top,
navigation-view-page scrolledwindow.undershoot-top > undershoot.top,
.sidebar-pane scrolledwindow.undershoot-top > undershoot.top, .content-pane scrolledwindow.undershoot-top > undershoot.top,
.content-pane .sidebar-pane scrolledwindow.undershoot-top > undershoot.top,
.sidebar-pane .content-pane scrolledwindow.undershoot-top > undershoot.top {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
  background: linear-gradient(to bottom, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

dialog-host scrolledwindow.undershoot-bottom > undershoot.bottom,
navigation-view-page scrolledwindow.undershoot-bottom > undershoot.bottom,
.sidebar-pane scrolledwindow.undershoot-bottom > undershoot.bottom, .content-pane scrolledwindow.undershoot-bottom > undershoot.bottom,
.content-pane .sidebar-pane scrolledwindow.undershoot-bottom > undershoot.bottom,
.sidebar-pane .content-pane scrolledwindow.undershoot-bottom > undershoot.bottom {
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.13);
  background: linear-gradient(to top, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

dialog-host scrolledwindow.undershoot-start:dir(ltr) > undershoot.left,
navigation-view-page scrolledwindow.undershoot-start:dir(ltr) > undershoot.left,
.sidebar-pane scrolledwindow.undershoot-start:dir(ltr) > undershoot.left, .content-pane scrolledwindow.undershoot-start:dir(ltr) > undershoot.left,
.content-pane .sidebar-pane scrolledwindow.undershoot-start:dir(ltr) > undershoot.left,
.sidebar-pane .content-pane scrolledwindow.undershoot-start:dir(ltr) > undershoot.left {
  box-shadow: inset 1px 0 rgba(255, 255, 255, 0.13);
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

dialog-host scrolledwindow.undershoot-start:dir(rtl) > undershoot.right,
navigation-view-page scrolledwindow.undershoot-start:dir(rtl) > undershoot.right,
.sidebar-pane scrolledwindow.undershoot-start:dir(rtl) > undershoot.right, .content-pane scrolledwindow.undershoot-start:dir(rtl) > undershoot.right,
.content-pane .sidebar-pane scrolledwindow.undershoot-start:dir(rtl) > undershoot.right,
.sidebar-pane .content-pane scrolledwindow.undershoot-start:dir(rtl) > undershoot.right {
  box-shadow: inset -1px 0 rgba(255, 255, 255, 0.13);
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

dialog-host scrolledwindow.undershoot-end:dir(ltr) > undershoot.right,
navigation-view-page scrolledwindow.undershoot-end:dir(ltr) > undershoot.right,
.sidebar-pane scrolledwindow.undershoot-end:dir(ltr) > undershoot.right, .content-pane scrolledwindow.undershoot-end:dir(ltr) > undershoot.right,
.content-pane .sidebar-pane scrolledwindow.undershoot-end:dir(ltr) > undershoot.right,
.sidebar-pane .content-pane scrolledwindow.undershoot-end:dir(ltr) > undershoot.right {
  box-shadow: inset -1px 0 rgba(255, 255, 255, 0.13);
  background: linear-gradient(to left, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

dialog-host scrolledwindow.undershoot-end:dir(rtl) > undershoot.left,
navigation-view-page scrolledwindow.undershoot-end:dir(rtl) > undershoot.left,
.sidebar-pane scrolledwindow.undershoot-end:dir(rtl) > undershoot.left, .content-pane scrolledwindow.undershoot-end:dir(rtl) > undershoot.left,
.content-pane .sidebar-pane scrolledwindow.undershoot-end:dir(rtl) > undershoot.left,
.sidebar-pane .content-pane scrolledwindow.undershoot-end:dir(rtl) > undershoot.left {
  box-shadow: inset 1px 0 rgba(255, 255, 255, 0.13);
  background: linear-gradient(to right, alpha(rgba(0, 0, 0, 0.2),0.25), transparent 6px);
}

toolbarview > .top-bar headerbar, toolbarview > .top-bar headerbar:backdrop,
toolbarview > .bottom-bar headerbar,
toolbarview > .bottom-bar headerbar:backdrop {
  background-color: transparent;
  border: none;
  box-shadow: none;
}

toolbarview > .top-bar searchbar > revealer > box,
toolbarview > .top-bar actionbar > revealer > box,
toolbarview > .bottom-bar searchbar > revealer > box,
toolbarview > .bottom-bar actionbar > revealer > box {
  background-color: transparent;
  border: none;
  box-shadow: none;
}

toolbarview > .top-bar .toolbar,
toolbarview > .bottom-bar .toolbar {
  background-color: transparent;
}

toolbarview > .top-bar .collapse-spacing,
toolbarview > .bottom-bar .collapse-spacing {
  padding-top: 0;
  padding-bottom: 0;
}

toolbarview > .top-bar .collapse-spacing headerbar,
toolbarview > .bottom-bar .collapse-spacing headerbar {
  min-height: 48px;
}

toolbarview > .top-bar .collapse-spacing headerbar > windowhandle > box,
toolbarview > .bottom-bar .collapse-spacing headerbar > windowhandle > box {
  padding-top: 6px;
  padding-bottom: 6px;
}

toolbarview > .top-bar .collapse-spacing headerbar > windowhandle > box > widget > box.vertical,
toolbarview > .bottom-bar .collapse-spacing headerbar > windowhandle > box > widget > box.vertical {
  margin-top: -6px;
  margin-bottom: -6px;
}

toolbarview > .top-bar .collapse-spacing headerbar.default-decoration,
toolbarview > .bottom-bar .collapse-spacing headerbar.default-decoration {
  min-height: 32px;
}

toolbarview > .top-bar .collapse-spacing headerbar.default-decoration > windowhandle > box,
toolbarview > .bottom-bar .collapse-spacing headerbar.default-decoration > windowhandle > box {
  padding-top: 0;
  padding-bottom: 0;
}

toolbarview > .top-bar .collapse-spacing searchbar > revealer > box,
toolbarview > .top-bar .collapse-spacing actionbar > revealer > box,
toolbarview > .bottom-bar .collapse-spacing searchbar > revealer > box,
toolbarview > .bottom-bar .collapse-spacing actionbar > revealer > box {
  padding-top: 6px;
  padding-bottom: 6px;
}

toolbarview > .top-bar .collapse-spacing .toolbar,
toolbarview > .bottom-bar .collapse-spacing .toolbar {
  padding-top: 6px;
  padding-bottom: 6px;
}

toolbarview > .top-bar .collapse-spacing tabbar,
toolbarview > .bottom-bar .collapse-spacing tabbar {
  padding-top: 0;
  padding-bottom: 0;
}

toolbarview > .top-bar .collapse-spacing tabbar .box,
toolbarview > .bottom-bar .collapse-spacing tabbar .box {
  margin-bottom: 6px;
}

toolbarview > .top-bar.raised,
toolbarview > .bottom-bar.raised {
  background-color: transparent;
  color: rgba(230, 238, 255, 0.95);
}

toolbarview > .top-bar.raised:backdrop,
toolbarview > .bottom-bar.raised:backdrop {
  background-color: transparent;
}

toolbarview > .top-bar:backdrop > windowhandle,
toolbarview > .bottom-bar:backdrop > windowhandle {
  filter: none;
}

toolbarview > .bottom-bar {
  padding: 0;
  border-spacing: 0;
  box-shadow: none;
  background-color: transparent;
  color: #dce4f5;
}

toolbarview > .bottom-bar:backdrop {
  background-color: transparent;
  color: rgba(160, 180, 220, 0.4);
}

toolbarview > .top-bar.raised {
  box-shadow: 0 1px mix(black,#2e3440,0.25), 0 2px 4px alpha(mix(black,#2e3440,0.25),0.35);
}

toolbarview > .top-bar.raised.border {
  box-shadow: 0 1px mix(black,#2e3440,0.25);
}

toolbarview > .bottom-bar.raised {
  box-shadow: 0 -1px mix(black,#2e3440,0.25), 0 -2px 4px alpha(mix(black,#2e3440,0.25),0.35);
}

toolbarview > .bottom-bar.raised.border {
  box-shadow: 0 -1px mix(black,#2e3440,0.25);
}

fullscreenbox toolbarview > .top-bar, fullscreenbox toolbarview > .top-bar.raised, fullscreenbox toolbarview > .bottom-bar, fullscreenbox toolbarview > .bottom-bar.raised {
  background-color: alpha(rgba(8, 14, 36, 0.42),0.9);
}

.sidebar-pane headerbar {
  min-height: 42px;
}

.sidebar-pane headerbar > windowhandle > box {
  padding: 3px;
}

.sidebar-pane headerbar > windowhandle > box > box.start:dir(ltr),
.sidebar-pane headerbar > windowhandle > box > box.end:dir(rtl), .sidebar-pane headerbar > windowhandle > box > widget > box.start:dir(ltr),
.sidebar-pane headerbar > windowhandle > box > widget > box.end:dir(rtl) {
  margin-right: 0;
}

.sidebar-pane headerbar > windowhandle > box > box.start:dir(rtl),
.sidebar-pane headerbar > windowhandle > box > box.end:dir(ltr), .sidebar-pane headerbar > windowhandle > box > widget > box.start:dir(rtl),
.sidebar-pane headerbar > windowhandle > box > widget > box.end:dir(ltr) {
  margin-left: 0;
}

.sidebar-pane headerbar windowcontrols:not(.empty).start:dir(ltr), .sidebar-pane headerbar windowcontrols:not(.empty).end:dir(rtl) {
  margin-right: 0;
  padding-left: 8px;
  padding-right: 0;
}

.sidebar-pane headerbar windowcontrols:not(.empty).start:dir(rtl), .sidebar-pane headerbar windowcontrols:not(.empty).end:dir(ltr) {
  margin-left: 0;
  padding-left: 0;
  padding-right: 8px;
}

.sidebar-pane headerbar windowcontrols button.close, .sidebar-pane headerbar windowcontrols button.maximize, .sidebar-pane headerbar windowcontrols button.minimize {
  margin: 0 1px;
}

.sidebar-pane toolbarview > .top-bar .collapse-spacing headerbar {
  min-height: 42px;
}

.sidebar-pane toolbarview > .top-bar .collapse-spacing headerbar > windowhandle > box {
  padding-top: 3px;
  padding-bottom: 3px;
}

.sidebar-pane toolbarview > .top-bar .collapse-spacing headerbar > windowhandle > box > widget > box.vertical {
  margin-top: -3px;
  margin-bottom: -3px;
}

.sidebar-pane toolbarview > .top-bar .collapse-spacing headerbar.default-decoration {
  min-height: 26px;
}

floating-sheet > dimming {
  background-color: rgba(0, 0, 0, 0.35);
}

floating-sheet > sheet {
  border-radius: 24px;
  outline: 1px solid rgba(255, 255, 255, 0.1);
  outline-offset: -1px;
  box-shadow: 0 3px 6px rgba(0, 0, 0, 0.2), 0 7px 12px rgba(0, 0, 0, 0.2), 0 12px 20px rgba(0, 0, 0, 0.2), 0 0 0 2px rgba(0, 0, 0, 0.1), 0 0 0 1px rgba(0, 0, 0, 0.75);
}

floating-sheet > sheet.background {
  background-color: rgba(10, 16, 42, 0.65);
}

bottom-sheet > sheet {
  border-radius: 24px 24px 0 0;
}

bottom-sheet > sheet.background {
  background-color: rgba(10, 16, 42, 0.65);
}

bottom-sheet > sheet > outline {
  border-radius: 24px 24px 0 0;
  box-shadow: 0 0 0 2px rgba(0, 0, 0, 0.1), 0 0 0 1px rgba(0, 0, 0, 0.75);
  border: 1px solid rgba(255, 255, 255, 0.1);
  border-bottom: none;
}

dialog.bottom-sheet:not(.narrow) sheet {
  margin-left: 30px;
  margin-right: 30px;
}

dialog.bottom-sheet:not(.narrow) sheet.flush-left > outline, dialog.bottom-sheet:not(.narrow) sheet.flush-right > outline, dialog.bottom-sheet:not(.narrow) sheet.flush-left.flush-right > outline {
  box-shadow: 0 0 0 2px rgba(0, 0, 0, 0.1), 0 0 0 1px rgba(0, 0, 0, 0.75);
}

dialog-host > dialog.background {
  background: none;
}

dialog-host > dialog.background sheet {
  background-color: rgba(12, 20, 48, 0.52);
  color: #e8edf8;
}

dialog-host > dialog.view {
  background: none;
}

dialog-host > dialog.osd:not(progressbar):not(button):not(menubutton):not(splitbutton) {
  background: none;
}

themeselector,
panelthemeselector {
  margin: 9px;
}

themeselector checkbutton,
panelthemeselector checkbutton {
  padding: 0;
  min-height: 44px;
  min-width: 44px;
  padding: 1px;
  background-clip: content-box;
  border-radius: 9999px;
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.13);
}

themeselector checkbutton.follow:checked, themeselector checkbutton.light:checked, themeselector checkbutton.dark:checked,
panelthemeselector checkbutton.follow:checked,
panelthemeselector checkbutton.light:checked,
panelthemeselector checkbutton.dark:checked {
  box-shadow: inset 0 0 0 2px #5271ad;
}

themeselector checkbutton.follow,
panelthemeselector checkbutton.follow {
  background-image: linear-gradient(to bottom right, #ffffff 50%, #202020 50%);
}

themeselector checkbutton.light,
panelthemeselector checkbutton.light {
  background-color: #ffffff;
}

themeselector checkbutton.dark,
panelthemeselector checkbutton.dark {
  background-color: #202020;
}

themeselector checkbutton.theme-selector radio,
panelthemeselector checkbutton.theme-selector radio {
  -gtk-icon-source: none;
  border: none;
  background: none;
  box-shadow: none;
  min-width: 12px;
  min-height: 12px;
  transform: translate(27px, 14px);
  padding: 3px;
}

themeselector checkbutton.theme-selector radio:hover, themeselector checkbutton.theme-selector radio:active, themeselector checkbutton.theme-selector radio:checked,
panelthemeselector checkbutton.theme-selector radio:hover,
panelthemeselector checkbutton.theme-selector radio:active,
panelthemeselector checkbutton.theme-selector radio:checked {
  background-color: transparent;
}

themeselector checkbutton.theme-selector radio:checked,
panelthemeselector checkbutton.theme-selector radio:checked {
  -gtk-icon-source: -gtk-icontheme("object-select-symbolic");
  color: white;
  background-color: #5271ad;
}

themeselector checkbutton.theme-selector radio:checked, themeselector checkbutton.theme-selector radio:checked:hover, themeselector checkbutton.theme-selector radio:checked:active,
panelthemeselector checkbutton.theme-selector radio:checked,
panelthemeselector checkbutton.theme-selector radio:checked:hover,
panelthemeselector checkbutton.theme-selector radio:checked:active {
  box-shadow: 0 2px 3px -1px rgba(0, 0, 0, 0.08), 0 1px 2px 0 rgba(0, 0, 0, 0.1);
}

themeswitcher {
  padding: 6px;
}

themeswitcher .check {
  min-height: 20px;
  min-width: 20px;
  background: none;
  padding: 0;
  margin: 0;
  border-radius: 9999px;
  color: white;
  background-color: #5271ad;
}

themeswitcher .check, themeswitcher .check:hover, themeswitcher .check:active {
  box-shadow: 0 2px 3px -1px rgba(0, 0, 0, 0.08), 0 1px 2px 0 rgba(0, 0, 0, 0.1);
}

themeswitcher checkbutton {
  padding: 0;
  min-height: 44px;
  min-width: 44px;
  padding: 1px;
  background-clip: content-box;
  border-radius: 9999px;
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.13);
}

themeswitcher checkbutton:checked {
  box-shadow: inset 0 0 0 2px #5271ad;
}

themeswitcher checkbutton radio, themeswitcher checkbutton radio:hover, themeswitcher checkbutton radio:active, themeswitcher checkbutton radio:checked, themeswitcher checkbutton radio:checked:hover, themeswitcher checkbutton radio:checked:active {
  background-color: transparent;
  border: none;
  background: none;
  box-shadow: none;
  color: transparent;
  -gtk-icon-source: none;
}

themeswitcher checkbutton.system {
  background: linear-gradient(-45deg, #1e1e1e 50%, white 50%);
}

themeswitcher checkbutton.light {
  color: alpha(black,0.8);
  background-color: white;
}

themeswitcher checkbutton.dark {
  color: white;
  background-color: #1e1e1e;
}

@define-color theme_bg_color rgba(12, 20, 48, 0.52);
@define-color theme_fg_color #e8edf8;
@define-color theme_base_color rgba(8, 14, 36, 0.42);
@define-color theme_text_color currentColor;
@define-color theme_selected_bg_color #5271ad;
@define-color theme_selected_fg_color #ffffff;
@define-color bg_color rgba(12, 20, 48, 0.52);
@define-color fg_color #e8edf8;
@define-color base_color rgba(8, 14, 36, 0.42);
@define-color text_color currentColor;
@define-color selected_bg_color #5271ad;
@define-color selected_fg_color #ffffff;
@define-color insensitive_bg_color mix(rgba(12, 20, 48, 0.52),rgba(8, 14, 36, 0.42),0.4);
@define-color insensitive_fg_color rgba(160, 180, 220, 0.4);
@define-color insensitive_base_color rgba(8, 14, 36, 0.42);
@define-color theme_unfocused_bg_color rgba(12, 20, 48, 0.52);
@define-color theme_unfocused_fg_color #e8edf8;
@define-color theme_unfocused_base_color rgba(8, 14, 36, 0.42);
@define-color theme_unfocused_text_color currentColor;
@define-color borders rgba(255, 255, 255, 0.13);
@define-color unfocused_insensitive_color mix(#e8edf8,rgba(12, 20, 48, 0.52),0.65);
@define-color unfocused_borders rgba(255, 255, 255, 0.13);
@define-color warning_color #d0846c;
@define-color error_color #c35b65;
@define-color success_color #82ac5d;
@define-color placeholder_text_color #d0846c;
@define-color link_color #5e81ac;
@define-color content_view_bg rgba(8, 14, 36, 0.42);
/* Very contrasty background for text views (@theme_text_color foreground) */
@define-color text_view_bg rgba(8, 14, 36, 0.42);
.background {
  background-color: rgba(8, 14, 36, 0.42);
  backdrop-filter: blur(24px) saturate(180%);
  -webkit-backdrop-filter: blur(24px) saturate(180%);
}

window.background {
  background-color: rgba(8, 14, 36, 0.42);
}

headerbar,
.titlebar,
headerbar.titlebar {
  background-color: rgba(10, 18, 45, 0.52);
  backdrop-filter: blur(24px) saturate(180%);
  -webkit-backdrop-filter: blur(24px) saturate(180%);
  border-color: rgba(255, 255, 255, 0.13);
  box-shadow: inset 0 1px 0 0 rgba(255, 255, 255, 0.1), inset 0 -1px 0 0 rgba(0, 0, 0, 0.07), 0 8px 32px rgba(0, 0, 0, 0.32), 0 2px 8px rgba(0, 0, 0, 0.18);
  border-bottom: 1px solid rgba(255, 255, 255, 0.13);
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.06) 0%, rgba(255, 255, 255, 0.01) 100%);
}

headerbar:backdrop,
.titlebar:backdrop {
  background-color: rgba(8, 14, 36, 0.3);
  backdrop-filter: blur(24px) saturate(120%);
  -webkit-backdrop-filter: blur(24px) saturate(120%);
  border-bottom-color: rgba(255, 255, 255, 0.07);
}

popover > contents {
  background-color: rgba(11, 19, 48, 0.6);
  backdrop-filter: blur(24px) saturate(180%);
  -webkit-backdrop-filter: blur(24px) saturate(180%);
  border-color: rgba(255, 255, 255, 0.13);
  box-shadow: inset 0 1px 0 0 rgba(255, 255, 255, 0.1), inset 0 -1px 0 0 rgba(0, 0, 0, 0.07), 0 8px 32px rgba(0, 0, 0, 0.32), 0 2px 8px rgba(0, 0, 0, 0.18);
  box-shadow: inset 0 1px 0 0 rgba(255, 255, 255, 0.1), inset 0 -1px 0 0 rgba(0, 0, 0, 0.07), 0 16px 48px rgba(0, 0, 0, 0.45), 0 4px 16px rgba(0, 0, 0, 0.25), 0 1px 3px rgba(0, 0, 0, 0.2);
  border-radius: 14px;
  border: 1px solid rgba(255, 255, 255, 0.13);
}

menu {
  background-color: rgba(11, 19, 48, 0.6);
  backdrop-filter: blur(24px) saturate(180%);
  -webkit-backdrop-filter: blur(24px) saturate(180%);
  border: 1px solid rgba(255, 255, 255, 0.13);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 16px 48px rgba(0, 0, 0, 0.5), 0 4px 16px rgba(0, 0, 0, 0.25);
}

menu menuitem:hover {
  background-color: rgba(136, 170, 255, 0.12);
}

window.dialog,
.dialog-content,
dialog {
  background-color: rgba(10, 16, 42, 0.65);
  backdrop-filter: blur(24px) saturate(180%);
  -webkit-backdrop-filter: blur(24px) saturate(180%);
  border: 1px solid rgba(255, 255, 255, 0.13);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 24px 64px rgba(0, 0, 0, 0.55), 0 8px 24px rgba(0, 0, 0, 0.3);
}

.dialog-content .response-area {
  background-color: rgba(255, 255, 255, 0.03);
  border-top: 1px solid rgba(255, 255, 255, 0.13);
}

.sidebar,
.navigation-sidebar,
stacksidebar > scrolledwindow,
stacksidebar > scrolledwindow > viewport > list,
.sidebar-pane {
  background-color: rgba(8, 13, 38, 0.48);
  backdrop-filter: blur(16px) saturate(180%);
  -webkit-backdrop-filter: blur(16px) saturate(180%);
  border-right: 1px solid rgba(255, 255, 255, 0.13);
}

.navigation-sidebar > row:hover,
.sidebar > row:hover {
  background-color: rgba(136, 170, 255, 0.08);
}

.navigation-sidebar > row:selected,
.navigation-sidebar > row.activatable:selected {
  background-color: rgba(136, 170, 255, 0.2);
}

.card {
  background-color: rgba(14, 22, 54, 0.4);
  background-color: rgba(14, 22, 54, 0.4);
  backdrop-filter: blur(16px) saturate(180%);
  -webkit-backdrop-filter: blur(16px) saturate(180%);
  border: 1px solid rgba(255, 255, 255, 0.13);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 4px 16px rgba(0, 0, 0, 0.2);
}

list.boxed-list {
  background-color: rgba(14, 22, 54, 0.4);
  backdrop-filter: blur(16px) saturate(180%);
  -webkit-backdrop-filter: blur(16px) saturate(180%);
  border: 1px solid rgba(255, 255, 255, 0.13);
}

list.boxed-list > row {
  background-color: transparent;
  border-bottom: 1px solid rgba(255, 255, 255, 0.05);
}

list.boxed-list > row:last-child {
  border-bottom: none;
}

list.boxed-list > row:hover {
  background-color: rgba(136, 170, 255, 0.08);
}

.osd {
  background-color: rgba(5, 10, 30, 0.72);
  backdrop-filter: blur(24px) saturate(180%);
  -webkit-backdrop-filter: blur(24px) saturate(180%);
  border-color: rgba(255, 255, 255, 0.18);
  box-shadow: inset 0 1px 0 0 rgba(255, 255, 255, 0.12), inset 0 -1px 0 0 rgba(0, 0, 0, 0.07), 0 8px 32px rgba(0, 0, 0, 0.32), 0 2px 8px rgba(0, 0, 0, 0.18);
  box-shadow: inset 0 1px 0 0 rgba(255, 255, 255, 0.12), inset 0 -1px 0 0 rgba(0, 0, 0, 0.07), 0 16px 48px rgba(0, 0, 0, 0.45), 0 4px 16px rgba(0, 0, 0, 0.25), 0 1px 3px rgba(0, 0, 0, 0.2);
  color: #e8edf8;
}

searchbar {
  background-color: rgba(10, 18, 45, 0.52);
  backdrop-filter: blur(24px) saturate(180%);
  -webkit-backdrop-filter: blur(24px) saturate(180%);
  border-bottom: 1px solid rgba(255, 255, 255, 0.13);
}

infobar {
  background-color: rgba(14, 22, 54, 0.55);
  backdrop-filter: blur(12px);
  border-bottom: 1px solid rgba(255, 255, 255, 0.13);
}

notebook > header {
  background-color: rgba(10, 18, 45, 0.52);
  backdrop-filter: blur(24px) saturate(180%);
  -webkit-backdrop-filter: blur(24px) saturate(180%);
  border-bottom: 1px solid rgba(255, 255, 255, 0.13);
}

textview,
textview > text {
  background-color: rgba(10, 16, 38, 0.55);
}

placessidebar {
  background-color: rgba(8, 13, 38, 0.48);
  backdrop-filter: blur(16px) saturate(180%);
  -webkit-backdrop-filter: blur(16px) saturate(180%);
}

placessidebar > viewport.frame {
  background-color: transparent;
}

separator {
  background-color: rgba(255, 255, 255, 0.13);
  min-height: 1px;
  min-width: 1px;
}

scrollbar {
  background-color: transparent;
}

scrollbar > range > trough {
  background-color: rgba(255, 255, 255, 0.04);
}

scrollbar > range > trough > slider {
  background-color: rgba(136, 170, 255, 0.28);
  border-radius: 99px;
  min-height: 6px;
  min-width: 6px;
}

scrollbar > range > trough > slider:hover {
  background-color: rgba(136, 170, 255, 0.45);
}

button:not(.flat):not(.close):not(.maximize):not(.minimize):not(.circular):not(.suggested-action):not(.destructive-action) {
  background-color: rgba(255, 255, 255, 0.07);
  backdrop-filter: blur(8px);
  border: 1px solid rgba(255, 255, 255, 0.13);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 4px rgba(0, 0, 0, 0.2);
}

button:not(.flat):not(.close):not(.maximize):not(.minimize):not(.circular):not(.suggested-action):not(.destructive-action):hover {
  background-color: rgba(255, 255, 255, 0.12);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 3px 10px rgba(0, 0, 0, 0.28);
}

button:not(.flat):not(.close):not(.maximize):not(.minimize):not(.circular):not(.suggested-action):not(.destructive-action):active {
  background-color: rgba(136, 170, 255, 0.22);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15);
}

entry {
  background-color: rgba(255, 255, 255, 0.07);
  backdrop-filter: blur(8px);
  border: 1px solid rgba(255, 255, 255, 0.13);
  box-shadow: inset 0 1px 3px rgba(0, 0, 0, 0.15);
}

entry:focus-within {
  background-color: rgba(136, 170, 255, 0.1);
  border-color: rgba(136, 170, 255, 0.4);
  box-shadow: inset 0 0 0 2px rgba(136, 170, 255, 0.2), inset 0 1px 3px rgba(0, 0, 0, 0.06);
}

switch {
  background-color: rgba(255, 255, 255, 0.1);
  border: 1px solid rgba(255, 255, 255, 0.13);
  backdrop-filter: blur(8px);
}

switch:checked {
  background-color: rgba(136, 170, 255, 0.6);
  border-color: rgba(136, 170, 255, 0.55);
}

switch > slider {
  background-color: rgba(255, 255, 255, 0.85);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.6), 0 2px 6px rgba(0, 0, 0, 0.25);
}

progressbar > trough {
  background-color: rgba(255, 255, 255, 0.06);
  border: 1px solid rgba(255, 255, 255, 0.13);
}

progressbar > trough > progress {
  background-color: rgba(136, 170, 255, 0.7);
  box-shadow: 0 0 12px rgba(136, 170, 255, 0.45);
}

tooltip {
  background-color: rgba(8, 14, 40, 0.88);
  backdrop-filter: blur(16px) saturate(180%);
  -webkit-backdrop-filter: blur(16px) saturate(180%);
  border: 1px solid rgba(255, 255, 255, 0.13);
  border-radius: 6px;
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 8px 24px rgba(0, 0, 0, 0.4);
}

tooltip > label {
  color: rgba(220, 230, 255, 0.92);
}

selection {
  background-color: rgba(136, 170, 255, 0.28);
  color: #e8edf8;
}
